@@ -49,16 +49,15 @@
 
 #include <stdint.h>
 #include <fcntl.h>
-#include <unistd.h>
 #include <time.h>
 
 #include <glib.h>
 #include "pbd/gstdio_compat.h"
 
-#include <gtkmm/accelmap.h>
-#include <gtkmm/messagedialog.h>
-#include <gtkmm/stock.h>
-#include <gtkmm/uimanager.h>
+#include <ytkmm/accelmap.h>
+#include <ytkmm/messagedialog.h>
+#include <ytkmm/stock.h>
+#include <ytkmm/uimanager.h>
 
 #include "pbd/error.h"
 #include "pbd/compose.h"
@@ -111,6 +110,10 @@
 
 #include "LuaBridge/LuaBridge.h"
 
+#ifdef PLATFORM_WINDOWS
+#include "pbd/windows_mmcss.h"
+#endif
+
 #ifdef WINDOWS_VST_SUPPORT
 #include <fst.h>
 #endif
@@ -169,6 +172,7 @@
 #include "recorder_ui.h"
 #include "route_time_axis.h"
 #include "route_params_ui.h"
+#include "rta_window.h"
 #include "save_as_dialog.h"
 #include "save_template_dialog.h"
 #include "script_selector.h"
@@ -180,7 +184,6 @@
 #include "splash.h"
 #include "template_dialog.h"
 #include "time_axis_view_item.h"
-#include "time_info_box.h"
 #include "timers.h"
 #include "transport_masters_dialog.h"
 #include "trigger_page.h"
@@ -206,13 +209,6 @@ ARDOUR_UI *ARDOUR_UI::theArdourUI = 0;
 sigc::signal<void, timepos_t> ARDOUR_UI::Clock;
 sigc::signal<void> ARDOUR_UI::CloseAllDialogs;
 
-static const gchar *_record_mode_strings[] = {
-	N_("Layered"),
-	N_("Non-Layered"),
-	N_("Snd on Snd"),
-	0
-};
-
 static bool
 ask_about_configuration_copy (string const & old_dir, string const & new_dir, int version)
 {
@@ -288,8 +284,8 @@ ARDOUR_UI::ARDOUR_UI (int *argcp, char **argvp[], const char* localedir)
 	: Gtkmm2ext::UI (PROGRAM_NAME, X_("gui"), argcp, argvp)
 	, session_load_in_progress (false)
 	, gui_object_state (new GUIObjectState)
-	, primary_clock   (new MainClock (X_("primary"),   X_("transport")))
-	, secondary_clock (new MainClock (X_("secondary"), X_("secondary")))
+	, primary_clock   (new MainClock (X_("primary"),   X_("transport"), MainClock::PrimaryClock))
+	, secondary_clock (new MainClock (X_("secondary"), X_("secondary"), MainClock::SecondaryClock))
 	, big_clock (new AudioClock (X_("bigclock"), false, "big", true, true, false, false))
 	, video_timeline(0)
 	, ignore_dual_punch (false)
@@ -304,21 +300,7 @@ ARDOUR_UI::ARDOUR_UI (int *argcp, char **argvp[], const char* localedir)
 	, _shared_popup_menu (0)
 	, _basic_ui (0)
 	, startup_fsm (0)
-	, secondary_clock_spacer (0)
-	, latency_disable_button (ArdourButton::led_default_elements)
-	, _cue_rec_enable (_("Rec Cues"), ArdourButton::led_default_elements)
-	, _cue_play_enable (_("Play Cues"), ArdourButton::led_default_elements)
-	, time_info_box (0)
-	, auto_return_button (ArdourButton::led_default_elements)
-	, follow_edits_button (ArdourButton::led_default_elements)
-	, auditioning_alert_button (_("Audition"))
-	, solo_alert_button (_("Solo"))
-	, feedback_alert_button (_("Feedback"))
 	, error_alert_button ( ArdourButton::just_led_default_elements )
-	, editor_meter_peak_display()
-	, editor_meter(0)
-	, _clear_editor_meter( true)
-	, _editor_meter_peaked (false)
 	, _numpad_locate_happening (false)
 	, _session_is_new (false)
 	, last_key_press_time (0)
@@ -339,25 +321,25 @@ ARDOUR_UI::ARDOUR_UI (int *argcp, char **argvp[], const char* localedir)
 	, plugin_dsp_load_window (X_("plugin-dsp-load"), _("Plugin DSP Load"))
 	, dsp_statistics_window (X_("dsp-statistics"), _("Performance Meters"))
 	, transport_masters_window (X_("transport-masters"), _("Transport Masters"))
-	, session_option_editor (X_("session-options-editor"), _("Properties"), boost::bind (&ARDOUR_UI::create_session_option_editor, this))
-	, add_video_dialog (X_("add-video"), _("Add Video"), boost::bind (&ARDOUR_UI::create_add_video_dialog, this))
-	, bundle_manager (X_("bundle-manager"), _("Bundle Manager"), boost::bind (&ARDOUR_UI::create_bundle_manager, this))
-	, big_clock_window (X_("big-clock"), _("Big Clock"), boost::bind (&ARDOUR_UI::create_big_clock_window, this))
-	, big_transport_window (X_("big-transport"), _("Transport Controls"), boost::bind (&ARDOUR_UI::create_big_transport_window, this))
-	, virtual_keyboard_window (X_("virtual-keyboard"), _("Virtual Keyboard"), boost::bind (&ARDOUR_UI::create_virtual_keyboard_window, this))
-	, library_download_window (X_("library-downloader"), _("Library Downloader"), boost::bind (&ARDOUR_UI::create_library_download_window, this))
-	, audio_port_matrix (X_("audio-connection-manager"), _("Audio Connections"), boost::bind (&ARDOUR_UI::create_global_port_matrix, this, ARDOUR::DataType::AUDIO))
-	, midi_port_matrix (X_("midi-connection-manager"), _("MIDI Connections"), boost::bind (&ARDOUR_UI::create_global_port_matrix, this, ARDOUR::DataType::MIDI))
-	, key_editor (X_("key-editor"), _("Keyboard Shortcuts"), boost::bind (&ARDOUR_UI::create_key_editor, this))
-	, luawindow (X_("luawindow"), S_("Window|Scripting"), boost::bind (&ARDOUR_UI::create_luawindow, this))
+	, session_option_editor (X_("session-options-editor"), _("Properties"), std::bind (&ARDOUR_UI::create_session_option_editor, this))
+	, add_video_dialog (X_("add-video"), _("Add Video"), std::bind (&ARDOUR_UI::create_add_video_dialog, this))
+	, bundle_manager (X_("bundle-manager"), _("Bundle Manager"), std::bind (&ARDOUR_UI::create_bundle_manager, this))
+	, big_clock_window (X_("big-clock"), _("Big Clock"), std::bind (&ARDOUR_UI::create_big_clock_window, this))
+	, big_transport_window (X_("big-transport"), _("Transport Controls"), std::bind (&ARDOUR_UI::create_big_transport_window, this))
+	, virtual_keyboard_window (X_("virtual-keyboard"), _("Virtual Keyboard"), std::bind (&ARDOUR_UI::create_virtual_keyboard_window, this))
+	, library_download_window (X_("library-downloader"), _("Library Downloader"), std::bind (&ARDOUR_UI::create_library_download_window, this))
+	, audio_port_matrix (X_("audio-connection-manager"), _("Audio Connections"), std::bind (&ARDOUR_UI::create_global_port_matrix, this, ARDOUR::DataType::AUDIO))
+	, midi_port_matrix (X_("midi-connection-manager"), _("MIDI Connections"), std::bind (&ARDOUR_UI::create_global_port_matrix, this, ARDOUR::DataType::MIDI))
+	, key_editor (X_("key-editor"), _("Keyboard Shortcuts"), std::bind (&ARDOUR_UI::create_key_editor, this))
+	, luawindow (X_("luawindow"), S_("Window|Scripting"), std::bind (&ARDOUR_UI::create_luawindow, this))
+	, rtawindow (X_("rtawindow"), S_("Window|Realtime Analyzer"), std::bind (&ARDOUR_UI::create_rtawindow, this))
 	, video_server_process (0)
 	, have_configure_timeout (false)
 	, last_configure_time (0)
 	, last_peak_grab (0)
 	, have_disk_speed_dialog_displayed (false)
+	, have_mmcss_error_dialog_displayed (false)
 	, _status_bar_visibility (X_("status-bar"))
-	, _feedback_exists (false)
-	, _ambiguous_latency (false)
 	, _log_not_acknowledged (LogLevelNone)
 	, duplicate_routes_dialog (0)
 	, editor_visibility_button (S_("Window|Edit"))
@@ -366,14 +348,13 @@ ARDOUR_UI::ARDOUR_UI (int *argcp, char **argvp[], const char* localedir)
 	, recorder_visibility_button (S_("Window|Rec"))
 	, trigger_page_visibility_button (S_("Window|Cue"))
 	, nsm_first_session_opened (false)
+	, _loading_session (false)
 {
 	Gtkmm2ext::init (localedir);
 
 	UIConfiguration::instance().post_gui_init ();
 
-	record_mode_strings = I18N (_record_mode_strings);
-
-	if (ARDOUR::handle_old_configuration_files (boost::bind (ask_about_configuration_copy, _1, _2, _3))) {
+	if (ARDOUR::handle_old_configuration_files (std::bind (ask_about_configuration_copy, _1, _2, _3))) {
 
 		{
 			/* "touch" the been-here-before path now that config has been migrated */
@@ -391,6 +372,7 @@ ARDOUR_UI::ARDOUR_UI (int *argcp, char **argvp[], const char* localedir)
 		_exit (EXIT_SUCCESS);
 	}
 
+	button_height_size_group = SizeGroup::create (Gtk::SIZE_GROUP_VERTICAL);
 
 	if (theArdourUI == 0) {
 		theArdourUI = this;
@@ -436,57 +418,48 @@ ARDOUR_UI::ARDOUR_UI (int *argcp, char **argvp[], const char* localedir)
 	install_actions ();
 
 	UIConfiguration::instance().ParameterChanged.connect (sigc::mem_fun (*this, &ARDOUR_UI::parameter_changed));
-	boost::function<void (string)> pc (boost::bind (&ARDOUR_UI::parameter_changed, this, _1));
+	std::function<void (string)> pc (std::bind (&ARDOUR_UI::parameter_changed, this, _1));
 	UIConfiguration::instance().map_parameters (pc);
 
-	transport_ctrl.setup (this);
+	ARDOUR::DiskWriter::Overrun.connect (forever_connections, MISSING_INVALIDATOR, std::bind (&ARDOUR_UI::disk_overrun_handler, this), gui_context());
+	ARDOUR::DiskReader::Underrun.connect (forever_connections, MISSING_INVALIDATOR, std::bind (&ARDOUR_UI::disk_underrun_handler, this), gui_context());
 
-	ARDOUR::DiskWriter::Overrun.connect (forever_connections, MISSING_INVALIDATOR, boost::bind (&ARDOUR_UI::disk_overrun_handler, this), gui_context());
-	ARDOUR::DiskReader::Underrun.connect (forever_connections, MISSING_INVALIDATOR, boost::bind (&ARDOUR_UI::disk_underrun_handler, this), gui_context());
+	ARDOUR::Session::VersionMismatch.connect (forever_connections, MISSING_INVALIDATOR, std::bind (&ARDOUR_UI::session_format_mismatch, this, _1, _2), gui_context());
 
-	ARDOUR::Session::VersionMismatch.connect (forever_connections, MISSING_INVALIDATOR, boost::bind (&ARDOUR_UI::session_format_mismatch, this, _1, _2), gui_context());
-
-	TriggerBox::CueRecordingChanged.connect (forever_connections, MISSING_INVALIDATOR, boost::bind (&ARDOUR_UI::cue_rec_state_changed, this), gui_context ());
-	cue_rec_state_changed();
+#ifdef PLATFORM_WINDOWS
+	PBD::MMCSS::MMCSSError.connect (forever_connections, MISSING_INVALIDATOR, std::bind (&ARDOUR_UI::mmcss_error_handler, this), gui_context());
+#endif
 
 	/* handle dialog requests */
 
-	ARDOUR::Session::Dialog.connect (forever_connections, MISSING_INVALIDATOR, boost::bind (&ARDOUR_UI::session_dialog, this, _1), gui_context());
+	ARDOUR::Session::Dialog.connect (forever_connections, MISSING_INVALIDATOR, std::bind (&ARDOUR_UI::session_dialog, this, _1), gui_context());
 
 	/* handle pending state with a dialog (PROBLEM: needs to return a value and thus cannot be x-thread) */
 
-	ARDOUR::Session::AskAboutPendingState.connect_same_thread (forever_connections, boost::bind (&ARDOUR_UI::pending_state_dialog, this));
+	ARDOUR::Session::AskAboutPendingState.connect_same_thread (forever_connections, std::bind (&ARDOUR_UI::pending_state_dialog, this));
 
 	/* handle sr mismatch with a dialog (PROBLEM: needs to return a value and thus cannot be x-thread) */
 
-	ARDOUR::Session::AskAboutSampleRateMismatch.connect_same_thread (forever_connections, boost::bind (&ARDOUR_UI::sr_mismatch_dialog, this, _1, _2));
+	ARDOUR::Session::AskAboutSampleRateMismatch.connect_same_thread (forever_connections, std::bind (&ARDOUR_UI::sr_mismatch_dialog, this, _1, _2));
 
 	/* handle sr mismatch with a dialog - cross-thread from engine */
-	ARDOUR::Session::NotifyAboutSampleRateMismatch.connect (forever_connections, MISSING_INVALIDATOR, boost::bind (&ARDOUR_UI::sr_mismatch_message, this, _1, _2), gui_context ());
+	ARDOUR::Session::NotifyAboutSampleRateMismatch.connect (forever_connections, MISSING_INVALIDATOR, std::bind (&ARDOUR_UI::sr_mismatch_message, this, _1, _2), gui_context ());
 
 	/* handle requests to quit (coming from JACK session) */
 
-	ARDOUR::Session::Quit.connect (forever_connections, MISSING_INVALIDATOR, boost::bind (&ARDOUR_UI::finish, this), gui_context ());
-
-	/* tell the user about feedback */
-
-	ARDOUR::Session::FeedbackDetected.connect (forever_connections, MISSING_INVALIDATOR, boost::bind (&ARDOUR_UI::feedback_detected, this), gui_context ());
-	ARDOUR::Session::SuccessfulGraphSort.connect (forever_connections, MISSING_INVALIDATOR, boost::bind (&ARDOUR_UI::successful_graph_sort, this), gui_context ());
-
-	/* indicate global latency compensation en/disable */
-	ARDOUR::Latent::DisableSwitchChanged.connect (forever_connections, MISSING_INVALIDATOR, boost::bind (&ARDOUR_UI::latency_switch_changed, this), gui_context ());
+	ARDOUR::Session::Quit.connect (forever_connections, MISSING_INVALIDATOR, std::bind (&ARDOUR_UI::finish, this), gui_context ());
 
 	/* handle requests to deal with missing files */
 
-	ARDOUR::Session::MissingFile.connect_same_thread (forever_connections, boost::bind (&ARDOUR_UI::missing_file, this, _1, _2, _3));
+	ARDOUR::Session::MissingFile.connect_same_thread (forever_connections, std::bind (&ARDOUR_UI::missing_file, this, _1, _2, _3));
 
 	/* and ambiguous files */
 
-	ARDOUR::FileSource::AmbiguousFileName.connect_same_thread (forever_connections, boost::bind (&ARDOUR_UI::ambiguous_file, this, _1, _2));
+	ARDOUR::FileSource::AmbiguousFileName.connect_same_thread (forever_connections, std::bind (&ARDOUR_UI::ambiguous_file, this, _1, _2));
 
-	ARDOUR::GUIIdle.connect (forever_connections, MISSING_INVALIDATOR, boost::bind(&ARDOUR_UI::gui_idle_handler, this), gui_context());
+	ARDOUR::GUIIdle.connect (forever_connections, MISSING_INVALIDATOR, std::bind(&ARDOUR_UI::gui_idle_handler, this), gui_context());
 
-	Config->ParameterChanged.connect ( forever_connections, MISSING_INVALIDATOR, boost::bind(&ARDOUR_UI::set_flat_buttons, this), gui_context() );
+	Config->ParameterChanged.connect ( forever_connections, MISSING_INVALIDATOR, std::bind(&ARDOUR_UI::set_flat_buttons, this), gui_context() );
 	set_flat_buttons();
 
 	theme_changed.connect (sigc::mem_fun(*this, &ARDOUR_UI::on_theme_changed));
@@ -523,6 +496,7 @@ ARDOUR_UI::ARDOUR_UI (int *argcp, char **argvp[], const char* localedir)
 		audio_port_matrix.set_state (*ui_xml, 0);
 		midi_port_matrix.set_state (*ui_xml, 0);
 		luawindow.set_state (*ui_xml, 0);
+		rtawindow.set_state (*ui_xml, 0);
 		export_video_dialog.set_state (*ui_xml, 0);
 		lua_script_window.set_state (*ui_xml, 0);
 		idleometer.set_state (*ui_xml, 0);
@@ -557,6 +531,7 @@ ARDOUR_UI::ARDOUR_UI (int *argcp, char **argvp[], const char* localedir)
 	WM::Manager::instance().register_window (&audio_port_matrix);
 	WM::Manager::instance().register_window (&midi_port_matrix);
 	WM::Manager::instance().register_window (&luawindow);
+	WM::Manager::instance().register_window (&rtawindow);
 	WM::Manager::instance().register_window (&idleometer);
 	WM::Manager::instance().register_window (&io_plugin_window);
 	WM::Manager::instance().register_window (&plugin_manager_ui);
@@ -596,7 +571,7 @@ ARDOUR_UI::attach_to_engine ()
 	if (!first_time) {
 		return;
 	}
-	AudioEngine::instance()->Running.connect (forever_connections, MISSING_INVALIDATOR, boost::bind (&ARDOUR_UI::engine_running, this, _1), gui_context());
+	AudioEngine::instance()->Running.connect (forever_connections, MISSING_INVALIDATOR, std::bind (&ARDOUR_UI::engine_running, this, _1), gui_context());
 	engine_running (0);
 	first_time = false;
 }
@@ -609,6 +584,7 @@ ARDOUR_UI::engine_stopped ()
 	ActionManager::set_sensitive (ActionManager::engine_opposite_sensitive_actions, true);
 	update_sample_rate ();
 	update_cpu_load ();
+	have_mmcss_error_dialog_displayed = false;
 }
 
 void
@@ -622,6 +598,7 @@ ARDOUR_UI::engine_running (uint32_t cnt)
 	update_cpu_load ();
 	update_sample_rate ();
 	update_timecode_format ();
+	session_latency_updated (true);
 	update_peak_thread_work ();
 	ActionManager::set_sensitive (ActionManager::engine_sensitive_actions, true);
 	ActionManager::set_sensitive (ActionManager::engine_opposite_sensitive_actions, false);
@@ -636,7 +613,7 @@ ARDOUR_UI::engine_halted (const char* reason, bool free_reason)
 		   free it later.
 		*/
 		char *copy = strdup (reason);
-		Gtkmm2ext::UI::instance()->call_slot (MISSING_INVALIDATOR, boost::bind (&ARDOUR_UI::engine_halted, this, copy, true));
+		Gtkmm2ext::UI::instance()->call_slot (MISSING_INVALIDATOR, std::bind (&ARDOUR_UI::engine_halted, this, copy, true));
 		return;
 	}
 
@@ -684,18 +661,16 @@ ARDOUR_UI::post_engine ()
 
 	/* connect to important signals */
 
-	AudioEngine::instance()->Stopped.connect (forever_connections, MISSING_INVALIDATOR, boost::bind (&ARDOUR_UI::engine_stopped, this), gui_context());
-	AudioEngine::instance()->SampleRateChanged.connect (forever_connections, MISSING_INVALIDATOR, boost::bind (&ARDOUR_UI::update_sample_rate, this), gui_context());
-	AudioEngine::instance()->BufferSizeChanged.connect (forever_connections, MISSING_INVALIDATOR, boost::bind (&ARDOUR_UI::update_sample_rate, this), gui_context());
-	AudioEngine::instance()->Halted.connect_same_thread (halt_connection, boost::bind (&ARDOUR_UI::engine_halted, this, _1, false));
-	AudioEngine::instance()->BecameSilent.connect (forever_connections, MISSING_INVALIDATOR, boost::bind (&ARDOUR_UI::audioengine_became_silent, this), gui_context());
+	AudioEngine::instance()->Stopped.connect (forever_connections, MISSING_INVALIDATOR, std::bind (&ARDOUR_UI::engine_stopped, this), gui_context());
+	AudioEngine::instance()->SampleRateChanged.connect (forever_connections, MISSING_INVALIDATOR, std::bind (&ARDOUR_UI::update_sample_rate, this), gui_context());
+	AudioEngine::instance()->BufferSizeChanged.connect (forever_connections, MISSING_INVALIDATOR, std::bind (&ARDOUR_UI::update_sample_rate, this), gui_context());
+	AudioEngine::instance()->Halted.connect_same_thread (halt_connection, std::bind (&ARDOUR_UI::engine_halted, this, _1, false));
+	AudioEngine::instance()->BecameSilent.connect (forever_connections, MISSING_INVALIDATOR, std::bind (&ARDOUR_UI::audioengine_became_silent, this), gui_context());
 
 	if (setup_windows ()) {
 		throw failed_constructor (); // TODO catch me if you can
 	}
 
-	transport_ctrl.map_actions ();
-
 	/* Do this after setup_windows (), as that's when the _status_bar_visibility is created */
 	XMLNode* n = Config->extra_xml (X_("UI"));
 	if (n) {
@@ -854,8 +829,8 @@ ARDOUR_UI::post_engine ()
 
 	{
 		DisplaySuspender ds;
-		Config->ParameterChanged.connect (forever_connections, MISSING_INVALIDATOR, boost::bind (&ARDOUR_UI::parameter_changed, this, _1), gui_context());
-		boost::function<void (string)> pc (boost::bind (&ARDOUR_UI::parameter_changed, this, _1));
+		Config->ParameterChanged.connect (forever_connections, MISSING_INVALIDATOR, std::bind (&ARDOUR_UI::parameter_changed, this, _1), gui_context());
+		std::function<void (string)> pc (std::bind (&ARDOUR_UI::parameter_changed, this, _1));
 		Config->map_parameters (pc);
 
 		UIConfiguration::instance().map_parameters (pc);
@@ -883,7 +858,6 @@ ARDOUR_UI::~ARDOUR_UI ()
 		delete primary_clock; primary_clock = 0;
 		delete secondary_clock; secondary_clock = 0;
 		delete _process_thread; _process_thread = 0;
-		delete time_info_box; time_info_box = 0;
 		delete meterbridge; meterbridge = 0;
 		delete duplicate_routes_dialog; duplicate_routes_dialog = 0;
 		delete trigger_page; trigger_page = 0;
@@ -972,9 +946,6 @@ ARDOUR_UI::set_transport_controllable_state (const XMLNode& node)
 	if (node.get_property ("rec", str)) {
 		rec_controllable->set_id (str);
 	}
-	if (node.get_property ("shuttle", str)) {
-		shuttle_box.controllable()->set_id (str);
-	}
 }
 
 XMLNode&
@@ -989,7 +960,6 @@ ARDOUR_UI::get_transport_controllable_state ()
 	node->set_property (X_("auto-loop"), auto_loop_controllable->id());
 	node->set_property (X_("play-selection"), play_selection_controllable->id());
 	node->set_property (X_("rec"), rec_controllable->id());
-	node->set_property (X_("shuttle"), shuttle_box.controllable()->id());
 
 	return *node;
 }
@@ -1084,7 +1054,6 @@ If you still wish to quit, please use the\n\n\
 
 		second_connection.disconnect ();
 		point_one_second_connection.disconnect ();
-		point_zero_something_second_connection.disconnect();
 		fps_connection.disconnect();
 	}
 
@@ -1154,7 +1123,7 @@ ARDOUR_UI::ask_about_scratch_deletion ()
 	msg.add_button (_("Delete this session (IRREVERSIBLE!)"), RESPONSE_OK);
 	msg.add_button (_("Do not delete"), RESPONSE_CANCEL);
 	msg.set_default_response (RESPONSE_CANCEL);
-	msg.set_position (Gtk::WIN_POS_MOUSE);
+	msg.set_position (UIConfiguration::instance().get_default_window_position());
 
 	int r = msg.run ();
 
@@ -1193,32 +1162,6 @@ ARDOUR_UI::every_point_one_seconds ()
 	if (editor) editor->build_region_boundary_cache();
 }
 
-void
-ARDOUR_UI::every_point_zero_something_seconds ()
-{
-	// august 2007: actual update frequency: 25Hz (40ms), not 100Hz
-
-	if (editor_meter && UIConfiguration::instance().get_show_editor_meter() && editor_meter_peak_display.get_mapped ()) {
-
-		if (_clear_editor_meter) {
-			editor_meter->clear_meters();
-			editor_meter_peak_display.set_active_state (Gtkmm2ext::Off);
-			_clear_editor_meter = false;
-			_editor_meter_peaked = false;
-		}
-
-		if (!UIConfiguration::instance().get_no_strobe()) {
-			const float mpeak = editor_meter->update_meters();
-			const bool peaking = mpeak > UIConfiguration::instance().get_meter_peak();
-
-			if (!_editor_meter_peaked && peaking) {
-				editor_meter_peak_display.set_active_state (Gtkmm2ext::ExplicitActive);
-				_editor_meter_peaked = true;
-			}
-		}
-	}
-}
-
 void
 ARDOUR_UI::set_fps_timeout_connection ()
 {
@@ -1459,7 +1402,7 @@ ARDOUR_UI::update_disk_space()
 		return;
 	}
 
-	boost::optional<samplecnt_t> opt_samples = _session->available_capture_duration();
+	std::optional<samplecnt_t> opt_samples = _session->available_capture_duration();
 	samplecnt_t fr = _session->sample_rate();
 
 	if (fr == 0) {
@@ -1498,7 +1441,12 @@ ARDOUR_UI::update_timecode_format ()
 		std::shared_ptr<TimecodeTransportMaster> tcmaster;
 		std::shared_ptr<TransportMaster> tm = TransportMasterManager::instance().current();
 
-		if ((tm->type() == LTC || tm->type() == MTC) && (tcmaster = std::dynamic_pointer_cast<TimecodeTransportMaster>(tm)) != 0 && tm->locked()) {
+		/* it should be impossible for tm to be NULL, but there anecdotal evidence
+		 * that it can be when re-starting the engine under some circumstances.
+		 */
+		assert (tm);
+
+		if (tm && (tm->type() == LTC || tm->type() == MTC) && (tcmaster = std::dynamic_pointer_cast<TimecodeTransportMaster>(tm)) != 0 && tm->locked()) {
 			matching = (tcmaster->apparent_timecode_format() == _session->config.get_timecode_format());
 		} else {
 			matching = true;
@@ -1515,6 +1463,35 @@ ARDOUR_UI::update_timecode_format ()
 
 }
 
+void
+ARDOUR_UI::session_latency_updated (bool for_playback)
+{
+	if (!for_playback) {
+		/* latency updates happen in pairs, in the following order:
+		 *  - for capture
+		 *  - for playback
+		 */
+		return;
+	}
+
+	if (!_session) {
+		pdc_info_label.set_text ("PDC: --");
+		latency_info_label.set_text ("I/O Latency: --");
+	} else {
+		samplecnt_t wrl = _session->worst_route_latency ();
+		samplecnt_t iol = _session->io_latency ();
+		float rate      = _session->nominal_sample_rate ();
+
+		pdc_info_label.set_text (string_compose ("PDC: %1", samples_as_time_string (wrl, rate)));
+
+		if (_session->engine().check_for_ambiguous_latency (true)) {
+			latency_info_label.set_markup ("I/O Latency: <span background=\"red\" foreground=\"white\">ambiguous</span>");
+		} else {
+			latency_info_label.set_text (string_compose ("I/O Latency: %1", samples_as_time_string (iol, rate)));
+		}
+	}
+}
+
 gint
 ARDOUR_UI::update_wall_clock ()
 {
@@ -1537,7 +1514,7 @@ ARDOUR_UI::update_wall_clock ()
 void
 ARDOUR_UI::session_add_midi_route (
 		bool disk,
-		RouteGroup* route_group,
+		std::shared_ptr<RouteGroup> route_group,
 		uint32_t how_many,
 		const string& name_template,
 		bool strict_io,
@@ -1591,7 +1568,7 @@ ARDOUR_UI::session_add_audio_route (
 	int32_t input_channels,
 	int32_t output_channels,
 	ARDOUR::TrackMode mode,
-	RouteGroup* route_group,
+	std::shared_ptr<RouteGroup> route_group,
 	uint32_t how_many,
 	string const & name_template,
 	bool strict_io,
@@ -1805,7 +1782,7 @@ ARDOUR_UI::transport_record (bool roll)
 {
 	if (_session) {
 		switch (_session->record_status()) {
-		case Session::Disabled:
+		case Disabled:
 			if (_session->ntracks() == 0) {
 				ArdourMessageDialog msg (_main_window, _("Please create one or more tracks before trying to record.\nYou can do this with the \"Add Track or Bus\" option in the Session menu."));
 				msg.run ();
@@ -1817,7 +1794,7 @@ ARDOUR_UI::transport_record (bool roll)
 				transport_roll ();
 			}
 			break;
-		case Session::Recording:
+		case Recording:
 			if (roll) {
 				_session->request_stop();
 			} else {
@@ -1825,7 +1802,7 @@ ARDOUR_UI::transport_record (bool roll)
 			}
 			break;
 
-		case Session::Enabled:
+		case Enabled:
 			if (roll) {
 				transport_roll();
 			} else {
@@ -1886,7 +1863,6 @@ ARDOUR_UI::get_smart_mode() const
 	return ( editor->get_smart_mode() );
 }
 
-
 void
 ARDOUR_UI::toggle_roll (bool with_abort, bool roll_out_of_bounded_mode)
 {
@@ -1894,6 +1870,13 @@ ARDOUR_UI::toggle_roll (bool with_abort, bool roll_out_of_bounded_mode)
 		return;
 	}
 
+	std::shared_ptr<TriggerBox> armed_tb = _session->armed_triggerbox();
+
+	if (armed_tb && _session->transport_rolling()) {
+		armed_tb->finish_recording ();
+		return;
+	}
+
 	if (_session->is_auditioning()) {
 		_session->cancel_audition ();
 		return;
@@ -1949,7 +1932,7 @@ ARDOUR_UI::toggle_roll (bool with_abort, bool roll_out_of_bounded_mode)
 		} else {
 			if (UIConfiguration::instance().get_follow_edits()) {
 				list<TimelineRange>& range = editor->get_selection().time;
-				if (range.front().start().samples() == _session->transport_sample()) { // if playhead is exactly at the start of a range, we assume it was placed there by follow_edits
+				if (!range.empty() && range.front().start().samples() == _session->transport_sample()) { // if playhead is exactly at the start of a range, we assume it was placed there by follow_edits
 					_session->request_play_range (&range, true);
 					_session->set_requested_return_sample (range.front().start().samples());  //force an auto-return here
 				}
@@ -2165,21 +2148,16 @@ void
 ARDOUR_UI::map_transport_state ()
 {
 	if (!_session) {
-		record_mode_selector.set_sensitive (false);
 		if (UIConfiguration::instance().get_screen_saver_mode () == InhibitWhileRecording) {
 			inhibit_screensaver (false);
 		}
 		return;
 	}
 
-	shuttle_box.map_transport_state ();
-
 	float sp = _session->transport_speed();
 
 	if (sp != 0.0f) {
-		record_mode_selector.set_sensitive (!_session->actively_recording ());
 	} else {
-		record_mode_selector.set_sensitive (true);
 		update_disk_space ();
 	}
 	if (UIConfiguration::instance().get_screen_saver_mode () == InhibitWhileRecording) {
@@ -2190,15 +2168,10 @@ ARDOUR_UI::map_transport_state ()
 void
 ARDOUR_UI::blink_handler (bool blink_on)
 {
-	sync_blink (blink_on);
-
 	if (UIConfiguration::instance().get_no_strobe() || !UIConfiguration::instance().get_blink_alert_indicators()) {
 		blink_on = true;
 	}
 	error_blink (blink_on);
-	solo_blink (blink_on);
-	audition_blink (blink_on);
-	feedback_blink (blink_on);
 }
 
 void
@@ -2230,6 +2203,16 @@ ARDOUR_UI::start_clocking ()
 	}
 }
 
+unsigned int
+ARDOUR_UI::clock_signal_interval ()
+{
+	if (UIConfiguration::instance().get_super_rapid_clock_update()) {
+		return Timers::fps_interval ();
+	} else {
+		return Timers::rapid_interval ();
+	}
+}
+
 void
 ARDOUR_UI::stop_clocking ()
 {
@@ -2272,40 +2255,20 @@ ARDOUR_UI::save_state_canfail (string name, bool switch_to_it)
 		if ((ret = _session->save_state (name, false, switch_to_it)) != 0) {
 			return ret;
 		}
+
+		std::string rus_path = Glib::build_filename (_session->session_directory().root_path(), "rus.xml");
+		region_ui_settings_manager.save (rus_path);
 	}
 
 	save_ardour_state (); /* XXX cannot fail? yeah, right ... */
 	return 0;
 }
 
-void
-ARDOUR_UI::primary_clock_value_changed ()
-{
-	if (_session) {
-		_session->request_locate (primary_clock->last_when ().samples());
-	}
-}
-
-void
-ARDOUR_UI::big_clock_value_changed ()
-{
-	if (_session) {
-		_session->request_locate (big_clock->last_when ().samples());
-	}
-}
-
-void
-ARDOUR_UI::secondary_clock_value_changed ()
-{
-	if (_session) {
-		_session->request_locate (secondary_clock->last_when ().samples());
-	}
-}
 void
 ARDOUR_UI::save_template_dialog_response (int response, SaveTemplateDialog* d)
 {
 	if (response == RESPONSE_ACCEPT) {
-		const string name = legalize_for_path (d->get_template_name ());
+		const string name = legalize_for_universal_path (d->get_template_name ());
 		const string desc = d->get_description ();
 
 		int failed = _session->save_template (name, desc);
@@ -2317,8 +2280,7 @@ ARDOUR_UI::save_template_dialog_response (int response, SaveTemplateDialog* d)
 
 			if (overwrite) {
 				_session->save_template (name, desc, true);
-			}
-			else {
+			}  else {
 				d->show ();
 				return;
 			}
@@ -2626,7 +2588,7 @@ will release an additional %3 %4bytes of disk space.\n", removed),
 	results.get_vbox()->pack_start (ddhbox, true, false, 5);
 	results.add_button (Stock::CLOSE, RESPONSE_CLOSE);
 	results.set_default_response (RESPONSE_CLOSE);
-	results.set_position (Gtk::WIN_POS_MOUSE);
+	results.set_position (UIConfiguration::instance().get_default_window_position());
 
 	results_display.show();
 	list_scroller.show();
@@ -2669,7 +2631,7 @@ Clean-up will move all unused files to a \"dead\" location."));
 
 	checker.set_name (_("CleanupDialog"));
 	checker.set_wmclass (X_("ardour_cleanup"), PROGRAM_NAME);
-	checker.set_position (Gtk::WIN_POS_MOUSE);
+	checker.set_position (UIConfiguration::instance().get_default_window_position());
 
 	switch (checker.run()) {
 	case RESPONSE_ACCEPT:
@@ -2820,7 +2782,7 @@ ARDOUR_UI::add_route ()
 		return;
 	}
 
-	add_route_dialog->set_position (WIN_POS_MOUSE);
+	add_route_dialog->set_position (UIConfiguration::instance().get_default_window_position());
 	add_route_dialog->present();
 }
 
@@ -2885,7 +2847,7 @@ ARDOUR_UI::add_route_dialog_response (int r)
 	ChanCount input_chan= add_route_dialog->channels ();
 	ChanCount output_chan;
 	PluginInfoPtr instrument = add_route_dialog->requested_instrument ();
-	RouteGroup* route_group = add_route_dialog->route_group ();
+	std::shared_ptr<RouteGroup> route_group = add_route_dialog->route_group ();
 	AutoConnectOption oac = Config->get_output_auto_connect();
 	bool strict_io = add_route_dialog->use_strict_io ();
 	bool trigger_visibility = add_route_dialog->show_on_cue_page ();
@@ -2910,7 +2872,7 @@ ARDOUR_UI::add_route_dialog_response (int r)
 		d.add_button(Stock::CANCEL, RESPONSE_CANCEL);
 		d.add_button(Stock::OK, RESPONSE_OK);
 		d.set_default_response (RESPONSE_OK);
-		d.set_position (WIN_POS_MOUSE);
+		d.set_position (UIConfiguration::instance().get_default_window_position());
 		d.show_all ();
 
 		if (d.run () == RESPONSE_OK) {
@@ -3005,6 +2967,33 @@ ARDOUR_UI::disk_speed_dialog_gone (int /*ignored_response*/, MessageDialog* msg)
 	delete msg;
 }
 
+void
+ARDOUR_UI::mmcss_error_handler ()
+{
+	ENSURE_GUI_THREAD (*this, &ARDOUR_UI::mmcss_error_handler)
+
+	if (!have_mmcss_error_dialog_displayed) {
+		have_mmcss_error_dialog_displayed = true;
+		ArdourMessageDialog msg (_("<b>MMCSS priority can not be set!</b>\n\n"
+		                           "Windows Multimedia Class Scheduler Service (MCSS) is used for time-critical audio processing. "
+		                           "By default, Microsoft has limited the number of MMCSS threads to 32, and this limit has been reached.\n\n"
+															 "You can reduce the number of process threads in Preferences &gt; Performance, but that may be insufficient, "
+		                           "because MCSS threads are also used for Audio and MIDI I/O.\n"
+		                           "One solution is to increase the number of available MCSS threads by modifying the windows registry. "
+															 "A tool to do that conveniently can be found <a href=\"https://helpcenter.steinberg.de/hc/en-us/articles/13338094735762-Error-message-on-Windows-MMCSS-priority-cannot-be-set\">here</a>."),
+		                     true, MESSAGE_ERROR);
+
+		for (auto const& w: msg.get_message_area ()->get_children ()) {
+			Gtk::Label* l = dynamic_cast<Gtk::Label*> (w);
+			if (l) {
+				l->property_track_visited_links() = false;
+				l->signal_activate_link().connect ([](std::string const& url) { std::cout << url << "\n"; return PBD::open_uri (url); }, false);
+			}
+		}
+		msg.run ();
+	}
+}
+
 void
 ARDOUR_UI::session_dialog (std::string msg)
 {
@@ -3065,18 +3054,6 @@ ARDOUR_UI::drop_process_buffers ()
 	_process_thread->drop_buffers ();
 }
 
-void
-ARDOUR_UI::feedback_detected ()
-{
-	_feedback_exists = true;
-}
-
-void
-ARDOUR_UI::successful_graph_sort ()
-{
-	_feedback_exists = false;
-}
-
 void
 ARDOUR_UI::midi_panic ()
 {
@@ -3085,31 +3062,6 @@ ARDOUR_UI::midi_panic ()
 	}
 }
 
-void
-ARDOUR_UI::reset_peak_display ()
-{
-	if (!_session || !_session->master_out() || !editor_meter) return;
-	_clear_editor_meter = true;
-}
-
-void
-ARDOUR_UI::reset_group_peak_display (RouteGroup* group)
-{
-	if (!_session || !_session->master_out()) return;
-	if (group == _session->master_out()->route_group()) {
-		reset_peak_display ();
-	}
-}
-
-void
-ARDOUR_UI::reset_route_peak_display (Route* route)
-{
-	if (!_session || !_session->master_out()) return;
-	if (_session->master_out().get() == route) {
-		reset_peak_display ();
-	}
-}
-
 void
 ARDOUR_UI::hide_application ()
 {
@@ -3198,4 +3150,3 @@ ARDOUR_UI::stop_cues (int col, bool immediately)
 {
 	_basic_ui->trigger_stop_col (col, immediately);
 }
-
