@@ -144,6 +144,12 @@ ARDOUR_UI::toggle_click ()
 	ActionManager::toggle_config_state ("Transport", "ToggleClick", &RCConfiguration::set_clicking, &RCConfiguration::get_clicking);
 }
 
+void
+ARDOUR_UI::toggle_click_on_rec ()
+{
+	ActionManager::toggle_config_state ("Transport", "ToggleClickOnRec", &RCConfiguration::set_click_record_only, &RCConfiguration::get_click_record_only);
+}
+
 void
 ARDOUR_UI::toggle_session_monitoring_in ()
 {
@@ -308,8 +314,8 @@ ARDOUR_UI::toggle_latency_switch ()
 void
 ARDOUR_UI::setup_session_options ()
 {
-	_session->config.ParameterChanged.connect (_session_connections, MISSING_INVALIDATOR, boost::bind (&ARDOUR_UI::parameter_changed, this, _1), gui_context());
-	boost::function<void (std::string)> pc (boost::bind (&ARDOUR_UI::parameter_changed, this, _1));
+	_session->config.ParameterChanged.connect (_session_connections, MISSING_INVALIDATOR, std::bind (&ARDOUR_UI::parameter_changed, this, _1), gui_context());
+	std::function<void (std::string)> pc (std::bind (&ARDOUR_UI::parameter_changed, this, _1));
 	_session->config.map_parameters (pc);
 }
 
@@ -323,7 +329,6 @@ ARDOUR_UI::parameter_changed (std::string p)
 		ActionManager::map_some_state ("Transport", "ToggleExternalSync", sigc::mem_fun (_session->config, &SessionConfiguration::get_external_sync));
 
 		if (!_session->config.get_external_sync()) {
-			sync_button.set_text (S_("SyncSource|Int."));
 			ActionManager::get_action ("Transport", "ToggleAutoPlay")->set_sensitive (true);
 			ActionManager::get_action ("Transport", "ToggleAutoReturn")->set_sensitive (true);
 			ActionManager::get_action ("Transport", "ToggleFollowEdits")->set_sensitive (true);
@@ -339,18 +344,8 @@ ARDOUR_UI::parameter_changed (std::string p)
 
 	} else if (p == "sync-source") {
 
-		/* app parameter (RC config) */
-
-		if (_session) {
-			if (!_session->config.get_external_sync()) {
-				sync_button.set_text (S_("SyncSource|Int."));
-			} else {
-				sync_button.set_text (TransportMasterManager::instance().current()->display_name());
-			}
-		} else {
-			/* changing sync source without a session is unlikely/impossible , except during startup */
-			sync_button.set_text (TransportMasterManager::instance().current()->display_name());
-		}
+		synchronize_sync_source_and_video_pullup ();
+		set_fps_timeout_connection ();
 
 	} else if (p == "follow-edits") {
 
@@ -392,17 +387,9 @@ ARDOUR_UI::parameter_changed (std::string p)
 		ActionManager::map_some_state ("Transport", "ToggleClick", &RCConfiguration::get_clicking);
 	} else if (p == "use-video-sync") {
 		ActionManager::map_some_state ("Transport",  "ToggleVideoSync", sigc::mem_fun (_session->config, &SessionConfiguration::get_use_video_sync));
-	} else if (p == "sync-source") {
-
-		synchronize_sync_source_and_video_pullup ();
-		set_fps_timeout_connection ();
 
 	} else if (p == "show-track-meters") {
 		if (editor) editor->toggle_meter_updating();
-	} else if (p == "primary-clock-delta-mode") {
-		primary_clock->set_display_delta_mode(UIConfiguration::instance().get_primary_clock_delta_mode());
-	} else if (p == "secondary-clock-delta-mode") {
-		secondary_clock->set_display_delta_mode(UIConfiguration::instance().get_secondary_clock_delta_mode());
 	} else if (p == "super-rapid-clock-update") {
 		if (_session) {
 			stop_clocking ();
@@ -417,28 +404,6 @@ ARDOUR_UI::parameter_changed (std::string p)
 		}
 	} else if (p == "waveform-gradient-depth") {
 		ArdourWaveView::WaveView::set_global_gradient_depth (UIConfiguration::instance().get_waveform_gradient_depth());
-	} else if (p == "show-mini-timeline") {
-		repack_transport_hbox ();
-	} else if (p == "show-dsp-load-info") {
-		repack_transport_hbox ();
-	} else if (p == "show-disk-space-info") {
-		repack_transport_hbox ();
-	} else if (p == "show-toolbar-recpunch") {
-		repack_transport_hbox ();
-	} else if (p == "show-toolbar-monitoring") {
-		repack_transport_hbox ();
-	} else if (p == "show-toolbar-selclock") {
-		repack_transport_hbox ();
-	} else if (p == "show-toolbar-latency") {
-		repack_transport_hbox ();
-	} else if (p == "show-toolbar-cuectrl") {
-		repack_transport_hbox ();
-	} else if (p == "show-toolbar-monitor-info") {
-		repack_transport_hbox ();
-	} else if (p == "show-editor-meter") {
-		repack_transport_hbox ();
-	} else if (p == "show-secondary-clock") {
-		update_clock_visibility ();
 	} else if (p == "waveform-scale") {
 		ArdourWaveView::WaveView::set_global_logscaled (UIConfiguration::instance().get_waveform_scale() == Logarithmic);
 	} else if (p == "widget-prelight") {
@@ -453,28 +418,6 @@ ARDOUR_UI::parameter_changed (std::string p)
 		ArdourWaveView::WaveView::set_image_cache_size (UIConfiguration::instance().get_waveform_cache_size() * 1048576);
 	} else if (p == "use-wm-visibility") {
 		VisibilityTracker::set_use_window_manager_visibility (UIConfiguration::instance().get_use_wm_visibility());
-	} else if (p == "action-table-columns") {
-		const uint32_t cols = UIConfiguration::instance().get_action_table_columns ();
-		for (int i = 0; i < MAX_LUA_ACTION_BUTTONS; ++i) {
-			const int col = i / 2;
-			if (cols & (1<<col)) {
-				action_script_call_btn[i].show();
-			} else {
-				action_script_call_btn[i].hide();
-			}
-		}
-		if (cols == 0) {
-			scripts_spacer.hide ();
-		} else {
-			scripts_spacer.show ();
-		}
-	} else if (p == "cue-behavior") {
-		CueBehavior cb (_session->config.get_cue_behavior());
-		_cue_play_enable.set_active (cb & ARDOUR::FollowCues);
-	} else if (p == "record-mode") {
-		size_t m = _session->config.get_record_mode ();
-		assert (m < record_mode_strings.size ());
-		record_mode_selector.set_active (record_mode_strings[m]);
 	} else if (p == "flat-buttons") {
 		bool flat = UIConfiguration::instance().get_flat_buttons();
 		if (ArdourButton::flat_buttons () != flat) {
@@ -566,14 +509,10 @@ ARDOUR_UI::synchronize_sync_source_and_video_pullup ()
 {
 	Glib::RefPtr<Action> act = ActionManager::get_action (X_("Transport"), X_("ToggleExternalSync"));
 
-	if (!act) {
+	if (!act || !_session) {
 		return;
 	}
 
-	if (!_session) {
-		goto just_label;
-	}
-
 	if (_session->config.get_video_pullup() == 0.0f) {
 		/* with no video pull up/down, any sync source is OK */
 		act->set_sensitive (true);
@@ -585,17 +524,4 @@ ARDOUR_UI::synchronize_sync_source_and_video_pullup ()
 			act->set_sensitive (true);
 		}
 	}
-
-	/* XXX should really be able to set the video pull up
-	   action to insensitive/sensitive, but there is no action.
-	   FIXME
-	*/
-
-  just_label:
-	if (act->get_sensitive ()) {
-		set_tip (sync_button, _("Enable/Disable external positional sync"));
-	} else {
-		set_tip (sync_button, _("Sync to JACK is not possible: video pull up/down is set"));
-	}
-
 }
