@@ -25,9 +25,7 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <sys/time.h>
 #include <errno.h>
-#include <unistd.h>
 #include <algorithm>
 
 #include <sndfile.h>
@@ -56,13 +54,11 @@
 
 #include "ardour_message.h"
 #include "ardour_ui.h"
-#include "cursor_context.h"
 #include "editor.h"
 #include "sfdb_ui.h"
 #include "editing.h"
 #include "audio_time_axis.h"
 #include "midi_time_axis.h"
-#include "session_import_dialog.h"
 #include "tempo_map_change.h"
 #include "gui_thread.h"
 #include "interthread_progress_window.h"
@@ -146,13 +142,6 @@ Editor::external_audio_dialog ()
 	sfbrowser->show_all ();
 }
 
-void
-Editor::session_import_dialog ()
-{
-	SessionImportDialog dialog (_session);
-	dialog.run ();
-}
-
 typedef std::map<PBD::ID,std::shared_ptr<ARDOUR::Source> > SourceMap;
 
 /**
@@ -279,58 +268,33 @@ Editor::import_smf_tempo_map (Evoral::SMF const & smf, timepos_t const & pos)
 		return;
 	}
 
-	const size_t num_tempos = smf.num_tempos ();
+	bool provided;
+	TempoMap::WritableSharedPtr new_map (smf.tempo_map (provided));
 
-	if (num_tempos == 0) {
+	if (!provided) {
 		return;
 	}
 
-	TempoMapChange tmc (*this, _("import SMF tempo map"));
+	TempoMap::WritableSharedPtr wmap = TempoMap::write_copy ();
+	TempoMapCutBuffer* tmcb;
+	// XMLNode& tm_before (wmap->get_state());
 
-	/* cannot create an empty TempoMap, so create one with "default" single
-	   values for tempo and meter, then overwrite them.
-	*/
+	tmcb = new_map->copy (timepos_t::zero (Temporal::AudioTime), timepos_t::from_superclock (new_map->duration(Temporal::AudioTime).superclocks()));
 
-	TempoMap::WritableSharedPtr new_map (new TempoMap (Tempo (120, 4), Meter (4, 4)));
-
-	Meter last_meter (4.0, 4.0);
-	bool have_initial_meter = false;
-
-	for (size_t n = 0; n < num_tempos; ++n) {
-
-		Evoral::SMF::Tempo* t = smf.nth_tempo (n);
-		assert (t);
-
-		Tempo tempo (t->tempo(), 32.0 / (double) t->notes_per_note);
-
-		cerr << "new tempo from SMF : " << tempo << endl;
-
-		Meter meter (t->numerator, t->denominator);
-
-		cerr << "new meter from SMF : " << meter << endl;
-
-
-		Temporal::BBT_Argument bbt; /* 1|1|0 which is correct for the no-meter case */
-
-		if (have_initial_meter) {
-
-			bbt = new_map->bbt_at (timepos_t (Temporal::Beats (int_div_round (t->time_pulses, (size_t) smf.ppqn()), 0)));
-			new_map->set_tempo (tempo, bbt);
-
-			if (!(meter == last_meter)) {
-				new_map->set_meter (meter, bbt);
-			}
-
-		} else {
-			new_map->set_meter (meter, bbt);
-			new_map->set_tempo (tempo, bbt);
-			have_initial_meter = true;
-		}
-
-		last_meter = meter;
+	if (tmcb && !tmcb->empty()) {
+		std::cerr << "CB\n";
+		tmcb->dump (std::cerr);
+		wmap->paste (*tmcb, pos, false, _("import"));
+		TempoMap::update (wmap);
+		std::cerr << "final map\n";
+		TempoMap::use()->dump (std::cerr);
+		delete tmcb;
+		// XMLNode& tm_after (wmap->get_state());
+		// _session->add_command (new TempoCommand (_("cut tempo map"), &tm_before, &tm_after));
+	} else {
+		// delete &tm_before;
+		TempoMap::abort_update ();
 	}
-
-	tmc.use_new_map (new_map);
 }
 
 void
@@ -604,8 +568,7 @@ Editor::import_sndfiles (vector<string>            paths,
 	import_status.track = track;
 	import_status.replace = replace;
 
-	CursorContext::Handle cursor_ctx = CursorContext::create(*this, _cursors->wait);
-	gdk_flush ();
+	CursorRAII cr (*this, _cursors->wait);
 
 	/* start import thread for this spec. this will ultimately call Session::import_files()
 	   which, if successful, will add the files as regions to the region list. its up to us
@@ -667,8 +630,7 @@ Editor::embed_sndfiles (vector<string>            paths,
 	/* skip periodic saves while importing */
 	Session::StateProtector sp (_session);
 
-	CursorContext::Handle cursor_ctx = CursorContext::create(*this, _cursors->wait);
-	gdk_flush ();
+	CursorRAII cr (*this, _cursors->wait);
 
 	for (vector<string>::iterator p = paths.begin(); p != paths.end(); ++p) {
 
@@ -781,13 +743,13 @@ Editor::embed_sndfiles (vector<string>            paths,
 
 int
 Editor::add_sources (vector<string>            paths,
-                     SourceList&               sources,
-                     timepos_t&              pos,
+                     SourceList&               possible_sources,
+                     timepos_t&                pos,
                      ImportDisposition         disposition,
                      ImportMode                mode,
                      int                       target_regions,
                      int                       target_tracks,
-                     std::shared_ptr<Track>& track,
+                     std::shared_ptr<Track>&   track,
                      std::string const&        pgroup_id,
                      bool                      /*add_channel_suffix*/,
                      ARDOUR::PluginInfoPtr     instrument)
@@ -801,6 +763,18 @@ Editor::add_sources (vector<string>            paths,
 
 	use_timestamp = (pos == timepos_t::max (pos.time_domain()));
 
+	SourceList sources;
+
+	for (auto const & s : possible_sources) {
+		if (!s->empty()) {
+			sources.push_back (s);
+		}
+	}
+
+	if (sources.empty()) {
+		return -1;
+	}
+
 	// kludge (for MIDI we're abusing "channel" for "track" here)
 	if (SMFSource::safe_midi_file_extension (paths.front())) {
 		target_regions = -1;
@@ -929,6 +903,7 @@ Editor::add_sources (vector<string>            paths,
 			}
 
 			regions.push_back (r);
+			++n;
 		}
 	}
 
@@ -998,6 +973,13 @@ Editor::add_sources (vector<string>            paths,
 			}
 		}
 
+		if (track_names.size() > 2 && current_interthread_info) {
+			import_status.current = n;
+			import_status.total = track_names.size ();
+			import_status.progress = 0.5;
+			import_status.doing_what = "Creating Tracks";
+			ARDOUR::GUIIdle ();
+		}
 		finish_bringing_in_material (*r, input_chan, output_chan, pos, mode, track, track_names[n], pgroup_id, instrument);
 
 		rlen = (*r)->length();
@@ -1059,6 +1041,7 @@ Editor::finish_bringing_in_material (std::shared_ptr<Region> region,
 
 		std::shared_ptr<Playlist> playlist = existing_track->playlist();
 		std::shared_ptr<Region> copy (RegionFactory::create (region, region->derive_properties ()));
+		copy->set_region_group(Region::get_retained_group_id());
 		playlist->clear_changes ();
 		playlist->clear_owned_changes ();
 		playlist->add_region (copy, pos);
@@ -1103,7 +1086,7 @@ Editor::finish_bringing_in_material (std::shared_ptr<Region> region,
 					                          ChanCount (DataType::MIDI, 1),
 					                          Config->get_strict_io () || Profile->get_mixbus (),
 					                          instrument, (Plugin::PresetRecord*) 0,
-					                          (RouteGroup*) 0,
+					                          nullptr,
 					                          1,
 					                          string(),
 					                          PresentationInfo::max_order,
@@ -1136,7 +1119,7 @@ Editor::finish_bringing_in_material (std::shared_ptr<Region> region,
 		if (mode == ImportAsTrigger) {
 			std::shared_ptr<Region> copy (RegionFactory::create (region, true));
 			for (int s = 0; s < TriggerBox::default_triggers_per_box; ++s) {
-				if (!existing_track->triggerbox ()->trigger (s)->region ()) {
+				if (!existing_track->triggerbox ()->trigger (s)->playable ()) {
 					existing_track->triggerbox ()->set_from_selection (s, copy);
 #if 1 /* assume drop from sidebar */
 					ARDOUR_UI_UTILS::copy_patch_changes (_session->the_auditioner (), existing_track->triggerbox ()->trigger (s));
