@@ -29,7 +29,7 @@
 #include <list>
 #include <vector>
 
-#include <gdk/gdk.h>
+#include <ydk/gdk.h>
 #include <stdint.h>
 
 #include "ardour/tempo.h"
@@ -41,7 +41,6 @@
 
 #include "gtkmm2ext/bindings.h"
 
-#include "cursor_context.h"
 #include "editor_items.h"
 #include "mouse_cursors.h"
 #include "editing.h"
@@ -65,10 +64,13 @@ namespace PBD {
 	class StatefulDiffCommand;
 }
 
+class CueEditor;
 class PatchChange;
+class EditingContext;
 class Editor;
 class EditorCursor;
 class TimeAxisView;
+class Pianoroll;
 class MidiTimeAxisView;
 class Drag;
 class NoteBase;
@@ -76,6 +78,7 @@ class TimeAxisView;
 class RouteTimeAxisView;
 class RegionSelection;
 class MidiRegionView;
+class MidiView;
 class MeterMarker;
 class ArdourMarker;
 class TempoMarker;
@@ -84,14 +87,14 @@ class ControlPoint;
 class AudioRegionView;
 class AutomationLine;
 class AutomationTimeAxisView;
-class VelocityGhostRegion;
+class VelocityDisplay;
 
 /** Class to manage current drags */
 class DragManager
 {
 public:
 
-	DragManager (Editor* e);
+	DragManager (EditingContext* e);
 	~DragManager ();
 
 	bool motion_handler (GdkEvent *, bool);
@@ -138,7 +141,7 @@ public:
 	bool preview_video () const;
 
 private:
-	Editor* _editor;
+	EditingContext* _editing_context;
 	std::list<Drag*> _drags;
 	bool _ending; ///< true if end_grab or abort is in progress, otherwise false
 	double _current_pointer_x; ///< canvas-coordinate space x of the current pointer
@@ -151,13 +154,17 @@ private:
 class Drag
 {
 public:
-	Drag (Editor *, ArdourCanvas::Item *, Temporal::TimeDomain td, bool trackview_only = true, bool hide_snapped_cursor = true);
+	Drag (EditingContext&, ArdourCanvas::Item *, Temporal::TimeDomain td, ArdourCanvas::Item const * bounding_item, bool hide_snapped_cursor = true);
 	virtual ~Drag ();
 
 	void set_manager (DragManager* m) {
 		_drags = m;
 	}
 
+	void set_bounding_item (ArdourCanvas::Item const * i) {
+		_bounding_item = i;
+	}
+
 	/** @return the canvas item being dragged */
 	ArdourCanvas::Item* item () const {
 		return _item;
@@ -216,9 +223,9 @@ public:
 	}
 
 	/** @return minimum number of samples (in x) and pixels (in y) that should be considered a movement */
-	std::pair<Temporal::timecnt_t,int> move_threshold () const {
-		return std::make_pair (Temporal::timecnt_t (1, Temporal::AudioTime), 1);
-	}
+	typedef std::pair<int,int> MoveThreshold;
+
+	virtual MoveThreshold move_threshold () const;
 
 	virtual bool allow_vertical_autoscroll () const {
 		return true;
@@ -268,7 +275,7 @@ protected:
 		return _grab_y;
 	}
 
-	Temporal::timepos_t pixel_to_time (double x) const;
+	Temporal::timepos_t pixel_duration_to_time (double x) const;
 
 	Temporal::timepos_t raw_grab_time () const {
 		return _raw_grab_time;
@@ -313,9 +320,10 @@ protected:
 	void show_verbose_cursor_text (std::string const &);
 	void show_view_preview (Temporal::timepos_t const &);
 
-	Editor* _editor; ///< our editor
+	EditingContext& editing_context;
 	DragManager* _drags;
 	ArdourCanvas::Item* _item; ///< our item
+	ArdourCanvas::Item const * _bounding_item; ///< our coordinate reference (normally null)
 	/** Offset from the mouse's position for the drag to the start of the thing that is being dragged */
 	Temporal::timecnt_t _pointer_offset;
 	Temporal::timecnt_t _video_offset;
@@ -324,6 +332,7 @@ protected:
 	bool _y_constrained; ///< true if y motion is constrained, otherwise false
 	bool _was_rolling; ///< true if the session was rolling before the drag started, otherwise false
 	ARDOUR::timepos_t _earliest_time_limit; ///< time we cannot drag before (defaults to 0, indicating no such limit)
+	bool _copy;
 
 private:
 	bool _trackview_only; ///< true if pointer y value should always be relative to the top of the trackview group
@@ -333,7 +342,7 @@ private:
 	bool _initially_vertical; ///< true if after move threshold is passed we appear to be moving vertically; undefined before that
 	bool _was_double_click; ///< true if drag initiated by a double click event
 	double _grab_x; ///< trackview x of the grab start position
-	double _grab_y; ///< y of the grab start position, possibly adjusted if _trackview_only is true
+	double _grab_y; ///< y of the grab start position, possibly adjusted if _bounding_itme is non-null
 	double _last_pointer_x; ///< trackview x of the pointer last time a motion occurred
 	double _last_pointer_y; ///< trackview y of the pointer last time a motion occurred
 	Temporal::timepos_t _raw_grab_time; ///< unsnapped time that the mouse was at when start_grab was called, or 0
@@ -345,13 +354,25 @@ private:
 	 *  samplepos. used for relative snap.
 	 */
 	Temporal::timecnt_t _snap_delta;
-	CursorContext::Handle _cursor_ctx; ///< cursor change context
 	bool _constraint_pressed; ///< if the keyboard indicated constraint modifier was pressed on start_grab()
 	int _grab_button;
 
 	Gtkmm2ext::Bindings::DragsBlockBindings binding_blocker;
 };
 
+/** EditorDrag:
+ *
+ * a base class for Drags that will need access to the full Editor, not just an
+ * Editing Context.
+ */
+class EditorDrag : public Drag
+{
+  public:
+	EditorDrag (Editor&, ArdourCanvas::Item *, Temporal::TimeDomain td, ArdourCanvas::Item const * bounding_item, bool hide_snapped_cursor = true);
+  protected:
+	Editor& _editor;
+};
+
 class RegionDrag;
 
 /** Container for details about a region being dragged */
@@ -379,10 +400,10 @@ public:
 };
 
 /** Abstract base class for drags that involve region(s) */
-class RegionDrag : public Drag, public sigc::trackable
+class RegionDrag : public EditorDrag, public sigc::trackable
 {
 public:
-	RegionDrag (Editor *, ArdourCanvas::Item *, RegionView *, std::list<RegionView*> const &, Temporal::TimeDomain, bool hide_snapped_cursor = true);
+	RegionDrag (Editor&, ArdourCanvas::Item *, RegionView *, std::list<RegionView*> const &, Temporal::TimeDomain, bool hide_snapped_cursor = true);
 	virtual ~RegionDrag () {}
 
 protected:
@@ -417,7 +438,7 @@ class RegionSlipContentsDrag : public RegionDrag
 {
 public:
 
-	RegionSlipContentsDrag (Editor *, ArdourCanvas::Item *, RegionView *, std::list<RegionView*> const &, Temporal::TimeDomain td);
+	RegionSlipContentsDrag (Editor&, ArdourCanvas::Item *, RegionView *, std::list<RegionView*> const &, Temporal::TimeDomain td);
 	virtual ~RegionSlipContentsDrag () {}
 
 	virtual void start_grab (GdkEvent *, Gdk::Cursor *);
@@ -430,7 +451,7 @@ public:
 class RegionBrushDrag : public RegionDrag
 {
 public:
-	RegionBrushDrag (Editor *, ArdourCanvas::Item *, RegionView *, std::list<RegionView*> const &, Temporal::TimeDomain td);
+	RegionBrushDrag (Editor&, ArdourCanvas::Item *, RegionView *, std::list<RegionView*> const &, Temporal::TimeDomain td);
 	virtual ~RegionBrushDrag () {}
 
 	virtual void start_grab (GdkEvent *, Gdk::Cursor *);
@@ -447,7 +468,7 @@ class RegionMotionDrag : public RegionDrag
 {
 public:
 
-	RegionMotionDrag (Editor *, ArdourCanvas::Item *, RegionView *, std::list<RegionView*> const &, Temporal::TimeDomain td);
+	RegionMotionDrag (Editor&, ArdourCanvas::Item *, RegionView *, std::list<RegionView*> const &, Temporal::TimeDomain td);
 	virtual ~RegionMotionDrag () {}
 
 	virtual void start_grab (GdkEvent *, Gdk::Cursor *);
@@ -486,7 +507,7 @@ private:
 class RegionMoveDrag : public RegionMotionDrag
 {
 public:
-	RegionMoveDrag (Editor *, ArdourCanvas::Item *, RegionView *, std::list<RegionView*> const &, bool, Temporal::TimeDomain);
+	RegionMoveDrag (Editor&, ArdourCanvas::Item *, RegionView *, std::list<RegionView*> const &, bool, Temporal::TimeDomain);
 	virtual ~RegionMoveDrag () {}
 
 	void motion (GdkEvent *, bool);
@@ -499,10 +520,6 @@ public:
 		return true;
 	}
 
-	std::pair<Temporal::timecnt_t,int> move_threshold () const {
-		return std::make_pair (Temporal::timecnt_t (4, Temporal::AudioTime), 4);
-	}
-
 	void setup_pointer_offset ();
 
 private:
@@ -538,7 +555,6 @@ private:
 	void collect_new_region_view (RegionView *);
 	RouteTimeAxisView* create_destination_time_axis (std::shared_ptr<ARDOUR::Region>, TimeAxisView* original);
 
-	bool _copy;
 	RegionView* _new_region_view;
 };
 
@@ -546,7 +562,7 @@ private:
 class RegionInsertDrag : public RegionMotionDrag
 {
 public:
-	RegionInsertDrag (Editor *, std::shared_ptr<ARDOUR::Region>, RouteTimeAxisView*, Temporal::timepos_t const &, Temporal::TimeDomain);
+	RegionInsertDrag (Editor&, std::shared_ptr<ARDOUR::Region>, RouteTimeAxisView*, Temporal::timepos_t const &, Temporal::TimeDomain);
 
 	void finished (GdkEvent *, bool);
 	void aborted (bool);
@@ -557,25 +573,23 @@ public:
 };
 
 /** "Drag" to cut a region (action only on button release) */
-class RegionCutDrag : public Drag
+class RegionCutDrag : public EditorDrag
 {
 public:
-	RegionCutDrag (Editor*, ArdourCanvas::Item*, samplepos_t);
+	RegionCutDrag (Editor&, ArdourCanvas::Item*, samplepos_t);
 	~RegionCutDrag ();
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent*, bool);
 	void finished (GdkEvent*, bool);
 	void aborted (bool);
-
-private:
 };
 
 /** Drags to create regions */
-class RegionCreateDrag : public Drag
+class RegionCreateDrag : public EditorDrag
 {
 public:
-	RegionCreateDrag (Editor *, ArdourCanvas::Item *, TimeAxisView *);
+	RegionCreateDrag (Editor&, ArdourCanvas::Item *, TimeAxisView *);
 
 	void motion (GdkEvent *, bool);
 	void finished (GdkEvent *, bool);
@@ -590,7 +604,7 @@ private:
 class NoteResizeDrag : public Drag
 {
 public:
-	NoteResizeDrag (Editor *, ArdourCanvas::Item *);
+	NoteResizeDrag (EditingContext&, ArdourCanvas::Item *);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
@@ -602,18 +616,18 @@ public:
 	}
 
 private:
-	MidiRegionView*     region;
-	bool                relative;
-	bool                at_front;
-	bool                _was_selected;
-	double              _snap_delta;
+	MidiView*     midi_view;
+	bool          relative;
+	bool          at_front;
+	bool         _was_selected;
+	double       _snap_delta;
 };
 
 /** Drags to move MIDI notes */
 class NoteDrag : public Drag
 {
 public:
-	NoteDrag (Editor*, ArdourCanvas::Item*);
+	NoteDrag (EditingContext&, ArdourCanvas::Item*);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
@@ -631,20 +645,19 @@ private:
 	Temporal::timecnt_t total_dx (GdkEvent * event) const; // total movement in quarter notes
 	int8_t total_dy () const;
 
-	MidiRegionView* _region;
+	MidiView* _view;
 	NoteBase* _primary;
 	Temporal::timecnt_t _cumulative_dx;
 	double _cumulative_dy;
 	Temporal::timepos_t  _earliest; // earliest note in note selection
 	bool   _was_selected;
 	double _note_height;
-	bool   _copy;
 };
 
 class NoteCreateDrag : public Drag
 {
 public:
-	NoteCreateDrag (Editor *, ArdourCanvas::Item *, MidiRegionView *);
+	NoteCreateDrag (EditingContext&, ArdourCanvas::Item *, MidiView *);
 	~NoteCreateDrag ();
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
@@ -668,12 +681,7 @@ private:
 	double y_to_region (double) const;
 	Temporal::Beats round_to_grid (Temporal::timepos_t const & pos, GdkEvent const * event) const;
 
-	/** @return minimum number of samples (in x) and pixels (in y) that should be considered a movement */
-	std::pair<Temporal::timecnt_t,int> move_threshold () const {
-		return std::make_pair (Temporal::timecnt_t (0, Temporal::AudioTime), 0);
-	}
-
-	MidiRegionView* _region_view;
+	MidiView* _midi_view;
 	ArdourCanvas::Rectangle* _drag_rect;
 	Temporal::timepos_t _note[2];
 };
@@ -681,7 +689,7 @@ private:
 class HitCreateDrag : public Drag
 {
 public:
-	HitCreateDrag (Editor *, ArdourCanvas::Item *, MidiRegionView *);
+	HitCreateDrag (EditingContext&, ArdourCanvas::Item *, MidiView *);
 	~HitCreateDrag ();
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
@@ -700,22 +708,50 @@ public:
 private:
 	double y_to_region (double) const;
 
-	/** @return minimum number of samples (in x) and pixels (in y) that should be considered a movement */
-	std::pair<Temporal::timecnt_t,int> move_threshold () const {
-		return std::make_pair (Temporal::timecnt_t::zero (Temporal::AudioTime), 0);
+	MidiView*           _midi_view;
+	int                 _y;
+
+};
+
+class NoteBrushDrag : public Drag
+{
+public:
+	NoteBrushDrag (EditingContext&, ArdourCanvas::Item *, MidiView *, Temporal::Beats specified_length = Temporal::Beats(), int stride_multiple = 1, int held_note = -1);
+	~NoteBrushDrag ();
+
+	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
+	void motion (GdkEvent *, bool);
+	void finished (GdkEvent *, bool);
+	void aborted (bool) {}
+
+	bool active (Editing::MouseMode mode) {
+		return mode == Editing::MouseDraw || mode == Editing::MouseContent;
 	}
 
-	MidiRegionView* _region_view;
-	Temporal::timepos_t _last_pos;
-	double          _y;
+	bool y_movement_matters () const {
+		return false;
+	}
 
+private:
+	double y_to_region (double) const;
+	Temporal::Beats get_stride (Temporal::Beats const & pos, Temporal::BBT_Offset const & quantization);
+
+	MidiView*           _midi_view;
+	Temporal::timepos_t _last_pos;
+	int                 _y;
+	Temporal::Beats      stride;
+	Temporal::Beats      next_grid;
+	bool                 added_notes;
+	Temporal::Beats      specified_length;
+	int                  stride_multiple;
+	int                  held_note;
 };
 
 /** Drag to move MIDI patch changes */
 class PatchChangeDrag : public Drag
 {
 public:
-	PatchChangeDrag (Editor *, PatchChange *, MidiRegionView *);
+	PatchChangeDrag (EditingContext&, PatchChange *, MidiView *);
 
 	void motion (GdkEvent *, bool);
 	void finished (GdkEvent *, bool);
@@ -732,7 +768,7 @@ public:
 	void setup_pointer_offset ();
 
 private:
-	MidiRegionView* _region_view;
+	MidiView* _region_view;
 	PatchChange* _patch_change;
 	double _cumulative_dx;
 };
@@ -748,10 +784,10 @@ public:
 };
 
 /** Drag of video offset */
-class VideoTimeLineDrag : public Drag
+class VideoTimeLineDrag : public EditorDrag
 {
 public:
-	VideoTimeLineDrag (Editor *e, ArdourCanvas::Item *i);
+	VideoTimeLineDrag (Editor&e, ArdourCanvas::Item *i);
 
 	void motion (GdkEvent *, bool);
 	void finished (GdkEvent *, bool);
@@ -785,7 +821,7 @@ public:
 		EndTrim
 	};
 
-	TrimDrag (Editor *, ArdourCanvas::Item *, RegionView*, std::list<RegionView*> const &, Temporal::TimeDomain td, bool preserve_fade_anchor = false);
+	TrimDrag (Editor&, ArdourCanvas::Item *, RegionView*, std::list<RegionView*> const &, Temporal::TimeDomain td, bool preserve_fade_anchor = false);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
@@ -813,10 +849,10 @@ private:
 };
 
 /** Meter marker drag */
-class MeterMarkerDrag : public Drag
+class MeterMarkerDrag : public EditorDrag
 {
 public:
-	MeterMarkerDrag (Editor *, ArdourCanvas::Item *, bool);
+	MeterMarkerDrag (Editor&, ArdourCanvas::Item *, bool);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
@@ -845,10 +881,10 @@ private:
 };
 
 /** Tempo curve drag */
-class TempoCurveDrag : public Drag
+class TempoCurveDrag : public EditorDrag
 {
 public:
-	TempoCurveDrag (Editor*, ArdourCanvas::Item*);
+	TempoCurveDrag (Editor&, ArdourCanvas::Item*);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
@@ -863,10 +899,10 @@ private:
 };
 
 /** Tempo marker drag */
-class TempoMarkerDrag : public Drag
+class TempoMarkerDrag : public EditorDrag
 {
 public:
-	TempoMarkerDrag (Editor *, ArdourCanvas::Item *);
+	TempoMarkerDrag (Editor&, ArdourCanvas::Item *);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
@@ -895,10 +931,10 @@ private:
 };
 
 /** Tempo marker drag */
-class BBTMarkerDrag : public Drag
+class BBTMarkerDrag : public EditorDrag
 {
 public:
-	BBTMarkerDrag (Editor *, ArdourCanvas::Item *);
+	BBTMarkerDrag (Editor&, ArdourCanvas::Item *);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
@@ -923,10 +959,10 @@ private:
 	XMLNode* _before_state;
 };
 
-class MappingEndDrag : public Drag
+class MappingEndDrag : public EditorDrag
 {
 public:
-	MappingEndDrag (Editor *, ArdourCanvas::Item *, Temporal::TempoMap::WritableSharedPtr&, Temporal::TempoPoint&, Temporal::TempoPoint& after, XMLNode& before_state);
+	MappingEndDrag (Editor&, ArdourCanvas::Item *, Temporal::TempoMap::WritableSharedPtr&, Temporal::TempoPoint&, Temporal::TempoPoint& after, XMLNode& before_state);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
@@ -957,10 +993,10 @@ private:
 	bool     _drag_valid;
 };
 
-class MappingTwistDrag : public Drag
+class MappingTwistDrag : public EditorDrag
 {
 public:
-	MappingTwistDrag (Editor *, ArdourCanvas::Item *, Temporal::TempoMap::WritableSharedPtr&,
+	MappingTwistDrag (Editor&, ArdourCanvas::Item *, Temporal::TempoMap::WritableSharedPtr&,
 	                  Temporal::TempoPoint& prev,
 	                  Temporal::TempoPoint& focus,
 	                  Temporal::TempoPoint& next,
@@ -1004,10 +1040,10 @@ private:
 
 
 /** tempo curve twist drag */
-class TempoTwistDrag : public Drag
+class TempoTwistDrag : public EditorDrag
 {
 public:
-	TempoTwistDrag (Editor *, ArdourCanvas::Item *);
+	TempoTwistDrag (Editor&, ArdourCanvas::Item *);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
@@ -1034,10 +1070,10 @@ private:
 };
 
 /** tempo curve twist drag */
-class TempoEndDrag : public Drag
+class TempoEndDrag : public EditorDrag
 {
 public:
-	TempoEndDrag (Editor *, ArdourCanvas::Item *);
+	TempoEndDrag (Editor&, ArdourCanvas::Item *);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
@@ -1065,10 +1101,10 @@ private:
 };
 
 /** Drag of the playhead cursor */
-class CursorDrag : public Drag
+class CursorDrag : public EditorDrag
 {
 public:
-	CursorDrag (Editor *, EditorCursor&, bool);
+	CursorDrag (Editor&, EditorCursor&, bool);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
@@ -1101,7 +1137,7 @@ private:
 class FadeInDrag : public RegionDrag
 {
 public:
-	FadeInDrag (Editor *, ArdourCanvas::Item *, RegionView *, std::list<RegionView*> const &, Temporal::TimeDomain);
+	FadeInDrag (Editor&, ArdourCanvas::Item *, RegionView *, std::list<RegionView*> const &, Temporal::TimeDomain);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
@@ -1123,7 +1159,7 @@ public:
 class FadeOutDrag : public RegionDrag
 {
 public:
-	FadeOutDrag (Editor *, ArdourCanvas::Item *, RegionView *, std::list<RegionView*> const &, Temporal::TimeDomain td);
+	FadeOutDrag (Editor&, ArdourCanvas::Item *, RegionView *, std::list<RegionView*> const &, Temporal::TimeDomain td);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
@@ -1142,10 +1178,10 @@ public:
 };
 
 /** Marker drag */
-class MarkerDrag : public Drag
+class MarkerDrag : public EditorDrag
 {
 public:
-	MarkerDrag (Editor *, ArdourCanvas::Item *);
+	MarkerDrag (Editor&, ArdourCanvas::Item *);
 	~MarkerDrag ();
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
@@ -1187,7 +1223,7 @@ private:
 class ControlPointDrag : public Drag
 {
 public:
-	ControlPointDrag (Editor *, ArdourCanvas::Item *);
+	ControlPointDrag (EditingContext&, ArdourCanvas::Item *);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
@@ -1218,7 +1254,7 @@ private:
 class LineDrag : public Drag
 {
 public:
-	LineDrag (Editor *e, ArdourCanvas::Item *i);
+	LineDrag (EditingContext &e, ArdourCanvas::Item *i, std::function<void(GdkEvent*,Temporal::timepos_t const &,double)>);
 	~LineDrag ();
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
@@ -1239,13 +1275,14 @@ private:
 	uint32_t _before;
 	uint32_t _after;
 	bool    have_command;
+	std::function<void(GdkEvent*,Temporal::timepos_t const &,double)> click_functor;
 };
 
 /** Transient feature line drags*/
 class FeatureLineDrag : public Drag
 {
 public:
-	FeatureLineDrag (Editor *e, ArdourCanvas::Item *i);
+	FeatureLineDrag (Editor&e, ArdourCanvas::Item *i);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
@@ -1268,17 +1305,13 @@ private:
 class RubberbandSelectDrag : public Drag
 {
 public:
-	RubberbandSelectDrag (Editor *, ArdourCanvas::Item *);
+	RubberbandSelectDrag (EditingContext&, ArdourCanvas::Item *, std::function<bool(GdkEvent*,Temporal::timepos_t const &)> click_functor);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
 	void finished (GdkEvent *, bool);
 	void aborted (bool);
 
-	std::pair<Temporal::timecnt_t,int> move_threshold () const {
-		return std::make_pair (Temporal::timecnt_t (8, Temporal::AudioTime), 1);
-	}
-
 	void do_select_things (GdkEvent *, bool);
 
 	/** Select some things within a rectangle.
@@ -1289,55 +1322,46 @@ public:
 	 *  @param y2 The bottom of the rectangle in trackview coordinates.
 	 *  @param drag_in_progress true if the drag is currently happening.
 	 */
-	virtual void select_things (int button_state, Temporal::timepos_t const & x1, Temporal::timepos_t const & x2, double y1, double y2, bool drag_in_progress) = 0;
-
-	virtual void deselect_things () = 0;
+	virtual void select_things (int button_state, Temporal::timepos_t const & x1, Temporal::timepos_t const & x2, double y1, double y2, bool drag_in_progress);
+	virtual void deselect_things ();
 
   protected:
 	bool _vertical_only;
-};
-
-/** A general editor RubberbandSelectDrag (for regions, automation points etc.) */
-class EditorRubberbandSelectDrag : public RubberbandSelectDrag
-{
-public:
-	EditorRubberbandSelectDrag (Editor *, ArdourCanvas::Item *);
-
-	void select_things (int, Temporal::timepos_t const &, Temporal::timepos_t const &, double, double, bool);
-	void deselect_things ();
+	std::function<bool(GdkEvent*,Temporal::timepos_t const &)> click_functor;
 };
 
 /** A RubberbandSelectDrag for selecting MIDI notes */
 class MidiRubberbandSelectDrag : public RubberbandSelectDrag
 {
-public:
-	MidiRubberbandSelectDrag (Editor *, MidiRegionView *);
+  public:
+	MidiRubberbandSelectDrag (EditingContext&, MidiView *);
 
 	void select_things (int, Temporal::timepos_t const &, Temporal::timepos_t const &, double, double, bool);
 	void deselect_things ();
+	void finished (GdkEvent *, bool);
 
-private:
-	MidiRegionView* _region_view;
+  private:
+	MidiView* _midi_view;
 };
 
 /** A RubberbandSelectDrag for selecting MIDI notes but with no horizontal component */
 class MidiVerticalSelectDrag : public RubberbandSelectDrag
 {
 public:
-	MidiVerticalSelectDrag (Editor *, MidiRegionView *);
+	MidiVerticalSelectDrag (EditingContext&, MidiView *);
 
 	void select_things (int, Temporal::timepos_t const &, Temporal::timepos_t const &, double, double, bool);
 	void deselect_things ();
 
 private:
-	MidiRegionView* _region_view;
+	MidiView* _midi_view;
 };
 
 /** Region drag in time-FX mode */
 class TimeFXDrag : public RegionDrag
 {
 public:
-	TimeFXDrag (Editor *, ArdourCanvas::Item *, RegionView *, std::list<RegionView*> const &, Temporal::TimeDomain td);
+	TimeFXDrag (Editor&, ArdourCanvas::Item *, RegionView *, std::list<RegionView*> const &, Temporal::TimeDomain td);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
@@ -1348,7 +1372,7 @@ private:
 };
 
 /** Drag in range select mode */
-class SelectionDrag : public Drag
+class SelectionDrag : public EditorDrag
 {
 public:
 	enum Operation {
@@ -1359,7 +1383,7 @@ public:
 		SelectionExtend
 	};
 
-	SelectionDrag (Editor *, ArdourCanvas::Item *, Operation);
+	SelectionDrag (Editor&, ArdourCanvas::Item *, Operation);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
@@ -1378,10 +1402,10 @@ private:
 };
 
 /** Drag time-selection markers */
-class SelectionMarkerDrag : public Drag
+class SelectionMarkerDrag : public EditorDrag
 {
 public:
-	SelectionMarkerDrag (Editor*, ArdourCanvas::Item*);
+	SelectionMarkerDrag (Editor&, ArdourCanvas::Item*);
 
 	void start_grab (GdkEvent*, Gdk::Cursor* c = 0);
 	void motion (GdkEvent*, bool);
@@ -1395,7 +1419,7 @@ private:
 };
 
 /** Range marker drag */
-class RangeMarkerBarDrag : public Drag
+class RangeMarkerBarDrag : public EditorDrag
 {
 public:
 	enum Operation {
@@ -1405,7 +1429,7 @@ public:
 		CreateCDMarker
 	};
 
-	RangeMarkerBarDrag (Editor *, ArdourCanvas::Item *, Operation);
+	RangeMarkerBarDrag (Editor&, ArdourCanvas::Item *, Operation);
 	~RangeMarkerBarDrag ();
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
@@ -1426,24 +1450,19 @@ private:
 
 	Operation _operation;
 	ArdourCanvas::Rectangle* _drag_rect;
-	bool _copy;
 };
 
 /** Drag of rectangle to set zoom */
-class MouseZoomDrag : public Drag
+class MouseZoomDrag : public EditorDrag
 {
 public:
-	MouseZoomDrag (Editor *, ArdourCanvas::Item *);
+	MouseZoomDrag (Editor&, ArdourCanvas::Item *);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
 	void finished (GdkEvent *, bool);
 	void aborted (bool);
 
-	std::pair<Temporal::timecnt_t,int> move_threshold () const {
-		return std::make_pair (Temporal::timecnt_t (4, Temporal::AudioTime), 4);
-	}
-
 private:
 	bool _zoom_out;
 };
@@ -1454,8 +1473,8 @@ private:
 class AutomationRangeDrag : public Drag
 {
 public:
-	AutomationRangeDrag (Editor *, AutomationTimeAxisView *, float initial_value, std::list<ARDOUR::TimelineRange> const &);
-	AutomationRangeDrag (Editor *, std::list<RegionView*> const &, std::list<ARDOUR::TimelineRange> const &, double y_origin, double y_height);
+	AutomationRangeDrag (EditingContext&, AutomationTimeAxisView *, float initial_value, std::list<ARDOUR::TimelineRange> const &);
+	AutomationRangeDrag (EditingContext&, std::list<RegionView*> const &, std::list<ARDOUR::TimelineRange> const &, double y_origin, double y_height);
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
 	void motion (GdkEvent *, bool);
@@ -1494,7 +1513,7 @@ private:
 class CrossfadeEdgeDrag : public Drag
 {
 public:
-	CrossfadeEdgeDrag (Editor*, AudioRegionView*, ArdourCanvas::Item*, bool start);
+	CrossfadeEdgeDrag (Editor&, AudioRegionView*, ArdourCanvas::Item*, bool start);
 
 	void start_grab (GdkEvent*, Gdk::Cursor* c = 0);
 	void motion (GdkEvent*, bool);
@@ -1505,10 +1524,6 @@ public:
 		return false;
 	}
 
-	std::pair<Temporal::timecnt_t,int> move_threshold () const {
-		return std::make_pair (Temporal::timecnt_t (4, Temporal::AudioTime), 4);
-	}
-
 private:
 	AudioRegionView* arv;
 	bool start;
@@ -1517,7 +1532,7 @@ private:
 class RegionMarkerDrag : public Drag
 {
   public:
-	RegionMarkerDrag (Editor*, RegionView*, ArdourCanvas::Item*);
+	RegionMarkerDrag (Editor&, RegionView*, ArdourCanvas::Item*);
 	~RegionMarkerDrag ();
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
@@ -1546,7 +1561,7 @@ class RegionMarkerDrag : public Drag
 class LollipopDrag : public Drag
 {
   public:
-	LollipopDrag (Editor*, ArdourCanvas::Item*);
+	LollipopDrag (EditingContext&, ArdourCanvas::Item*);
 	~LollipopDrag ();
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
@@ -1569,7 +1584,7 @@ class LollipopDrag : public Drag
 	void setup_pointer_offset ();
 
   private:
-	VelocityGhostRegion*      _region;
+	VelocityDisplay*          _display;
 	ArdourCanvas::Lollipop*   _primary;
 };
 
@@ -1577,7 +1592,7 @@ template<typename OrderedPointList, typename OrderedPoint>
 class FreehandLineDrag : public Drag
 {
   public:
-	FreehandLineDrag (Editor*, ArdourCanvas::Item*, ArdourCanvas::Rectangle&, Temporal::TimeDomain);
+	FreehandLineDrag (EditingContext&, ArdourCanvas::Item*, ArdourCanvas::Rectangle&, bool, Temporal::TimeDomain);
 	~FreehandLineDrag ();
 
 	void motion (GdkEvent*, bool);
@@ -1592,6 +1607,7 @@ class FreehandLineDrag : public Drag
 	ArdourCanvas::Item* parent; /* we do not own this. If null, use base_rect as the parent */
 	ArdourCanvas::Rectangle& base_rect; /* we do not own this */
 	ArdourCanvas::PolyLine* dragging_line;
+	bool horizontally_bounded;
 	int direction;
 	int edge_x;
 	bool did_snap;
@@ -1606,7 +1622,7 @@ class FreehandLineDrag : public Drag
 class AutomationDrawDrag : public FreehandLineDrag<Evoral::ControlList::OrderedPoints, Evoral::ControlList::OrderedPoint>
 {
   public:
-	AutomationDrawDrag (Editor*, ArdourCanvas::Item*, ArdourCanvas::Rectangle&, Temporal::TimeDomain);
+	AutomationDrawDrag (EditingContext&, ArdourCanvas::Item*, ArdourCanvas::Rectangle&, bool, Temporal::TimeDomain);
 	~AutomationDrawDrag ();
 
 	void finished (GdkEvent*, bool);
@@ -1616,7 +1632,7 @@ class AutomationDrawDrag : public FreehandLineDrag<Evoral::ControlList::OrderedP
 class VelocityLineDrag : public FreehandLineDrag<Evoral::ControlList::OrderedPoints, Evoral::ControlList::OrderedPoint>
 {
   public:
-	VelocityLineDrag (Editor*, ArdourCanvas::Rectangle&, Temporal::TimeDomain);
+	VelocityLineDrag (EditingContext&, ArdourCanvas::Rectangle&, bool, Temporal::TimeDomain);
 	~VelocityLineDrag ();
 
 	void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
@@ -1626,10 +1642,44 @@ class VelocityLineDrag : public FreehandLineDrag<Evoral::ControlList::OrderedPoi
 	void line_extended (ArdourCanvas::Duple const & from, ArdourCanvas::Duple const & to, ArdourCanvas::Rectangle const & r, double last_x);
 
  private:
-	VelocityGhostRegion* grv;
+	VelocityDisplay* vd;
 	bool drag_did_change;
 };
 
+class ClipStartDrag : public Drag
+{
+  public:
+	ClipStartDrag (CueEditor&, ArdourCanvas::Rectangle &);
+	~ClipStartDrag ();
 
+	void start_grab (GdkEvent*,Gdk::Cursor*);
+	bool end_grab (GdkEvent*);
+	void motion (GdkEvent*, bool);
+	void finished (GdkEvent*, bool);
+	void aborted (bool);
+
+  private:
+	CueEditor& ce;
+	ArdourCanvas::Rectangle* dragging_rect;
+	ArdourCanvas::Rect original_rect;
+};
+
+class ClipEndDrag : public Drag
+{
+  public:
+	ClipEndDrag (CueEditor&, ArdourCanvas::Rectangle &);
+	~ClipEndDrag ();
+
+	void start_grab (GdkEvent*,Gdk::Cursor*);
+	bool end_grab (GdkEvent*);
+	void motion (GdkEvent*, bool);
+	void finished (GdkEvent*, bool);
+	void aborted (bool);
+
+  private:
+	CueEditor& ce;
+	ArdourCanvas::Rectangle* dragging_rect;
+	ArdourCanvas::Rect original_rect;
+};
 
 #endif /* __gtk2_ardour_editor_drag_h_ */
