@@ -29,6 +29,7 @@
 
 #include "ardour/control_protocol_manager.h"
 #include "ardour/midi_region.h"
+#include "ardour/midi_track.h"
 #include "ardour/playlist.h"
 #include "ardour/profile.h"
 #include "ardour/route_group.h"
@@ -45,12 +46,15 @@
 #include "audio_time_axis.h"
 #include "audio_region_view.h"
 #include "audio_streamview.h"
-#include "automation_line.h"
+#include "editor_automation_line.h"
 #include "control_point.h"
 #include "editor_regions.h"
 #include "editor_cursors.h"
 #include "keyboard.h"
 #include "midi_region_view.h"
+#include "mixer_strip.h"
+#include "pianoroll.h"
+#include "selection_properties_box.h"
 #include "sfdb_ui.h"
 
 #include "pbd/i18n.h"
@@ -386,7 +390,7 @@ Editor::mapover_grouped_routes (sigc::slot<void, RouteUI&> sl, RouteUI* basis, P
 
 	routes.insert(basis);
 
-	RouteGroup* group = basis->route()->route_group();
+	std::shared_ptr<RouteGroup> group = basis->route()->route_group();
 
 	if (group && group->enabled_property(prop) && group->enabled_property (Properties::active.property_id)) {
 
@@ -475,7 +479,7 @@ Editor::mapover_tracks_with_unique_playlists (sigc::slot<void, RouteTimeAxisView
 	set<RouteTimeAxisView*> tracks;
 	tracks.insert (route_basis);
 
-	RouteGroup* group = route_basis->route()->route_group(); // could be null, not a problem
+	std::shared_ptr<RouteGroup> group = route_basis->route()->route_group(); // could be null, not a problem
 
 	if (group && group->enabled_property(prop) && group->enabled_property (Properties::active.property_id)) {
 
@@ -978,20 +982,6 @@ out:
 	return commit;
 }
 
-void
-Editor::set_selected_midi_region_view (MidiRegionView& mrv)
-{
-	/* clear note selection in all currently selected MidiRegionViews */
-
-	if (get_selection().regions.contains (&mrv) && get_selection().regions.size() == 1) {
-		/* Nothing to do */
-		return;
-	}
-
-	midi_action (&MidiRegionView::clear_note_selection);
-	get_selection().set (&mrv);
-}
-
 void
 Editor::set_selection (std::list<Selectable*> s, SelectionOperation op)
 {
@@ -1093,6 +1083,15 @@ Editor::set_selected_regionview_from_map_event (GdkEventAny* /*ev*/, StreamView*
 void
 Editor::presentation_info_changed (PropertyChange const & what_changed)
 {
+	if (!_session) {
+		/* static signal, that the editor c'tor subscribes to.
+		 * It may be received during connect_dependents_to_session() when
+		 * signals are processed in BootMessage -> GUIIdle, just
+		 * just before Editor::set_session();
+		 */
+		return;
+	}
+
 	uint32_t n_tracks = 0;
 	uint32_t n_busses = 0;
 	uint32_t n_vcas = 0;
@@ -1232,6 +1231,13 @@ Editor::presentation_info_changed (PropertyChange const & what_changed)
 		}
 	}
 
+	if (current_mixer_strip && what_changed.contains (Properties::hidden)) {
+		/* don't show hidden tracks in editor mixer */
+		if (current_mixer_strip->route()->is_hidden () && att_left_visible ()) {
+			show_editor_mixer (true);
+		}
+	}
+
 	/* STEP 4: update Editor::track_views */
 
 	PropertyChange soh;
@@ -1526,7 +1532,7 @@ Editor::sensitize_the_right_region_actions (bool because_canvas_crossing)
 
 	if (rs.size() > 1) {
 		_region_actions->get_action("show-region-list-editor")->set_sensitive (false);
-		_region_actions->get_action("show-region-properties")->set_sensitive (false);
+		_region_actions->get_action("edit-region-dedicated-window")->set_sensitive (false);
 		_region_actions->get_action("rename-region")->set_sensitive (false);
 		/* XXX need to check whether there is than 1 per
 		   playlist, because otherwise this makes no sense.
@@ -1721,11 +1727,96 @@ Editor::region_selection_changed ()
 		/* if in TimeFX mode and there's just 1 region selected
 		 * (i.e. we just clicked on it), leave things as they are
 		 */
-		if (selection->regions.size() > 1 || mouse_mode != Editing::MouseTimeFX) {
+		if (selection->regions.size() > 1 || current_mouse_mode() != Editing::MouseTimeFX) {
 			set_mouse_mode (MouseObject, false);
 		}
 	}
 	update_selection_markers ();
+
+	if (selection->regions.empty()) {
+		/* do nothing */
+	} else if (selection->regions.size () == 1)  {
+		RegionView* rv = (selection->regions.front ());
+		assert (rv);
+		maybe_edit_region_in_bottom_pane (*rv);
+	} else {
+		_bottom_hbox.set_child_packing (*_properties_box, true, true);
+		if (_pianoroll && _pianoroll->contents().get_parent()) {
+			_pianoroll->contents().unmap ();
+			_pianoroll->contents().get_parent()->remove (_pianoroll->contents());
+		}
+
+		RegionEditDisposition red (UIConfiguration::instance().get_region_edit_disposition());
+
+		switch (red) {
+		case OpenBottomPane:
+			show_att_bottom (false);
+			break;
+		default:
+			showhide_att_bottom (false);
+			break;
+		}
+	}
+}
+
+void
+Editor::maybe_edit_region_in_bottom_pane (RegionView& rv)
+{
+	RegionEditDisposition red (UIConfiguration::instance().get_region_edit_disposition());
+
+	if (red == Editing::NeverBottomPane) {
+		return;
+	}
+
+	MidiRegionView* mrv = dynamic_cast<MidiRegionView*> (&rv);
+
+	if (mrv) {
+
+		std::shared_ptr<ARDOUR::MidiTrack> mt = std::dynamic_pointer_cast<ARDOUR::MidiTrack> (mrv->midi_view()->track());
+		std::shared_ptr<MidiRegion> mr = std::dynamic_pointer_cast<MidiRegion>(mrv->region());
+
+		if (!mt || !mr) {
+			showhide_att_bottom (false);
+			return;
+		}
+
+		if (!_pianoroll) {
+			// XXX this should really not happen here
+			_pianoroll = new Pianoroll ("editor pianoroll", true);
+			_pianoroll->get_canvas_viewport()->set_size_request (-1, 120);
+			if (_session) {
+				_pianoroll->set_session (_session);
+			}
+		}
+
+		_pianoroll->set_track (mt);
+		_pianoroll->set_region (mr);
+
+		_bottom_hbox.set_child_packing (*_properties_box, false, false);
+
+		if (!_pianoroll->contents().get_parent()) {
+			_bottom_hbox.pack_start (_pianoroll->contents(), true, true);
+		}
+
+		_pianoroll->contents().hide (); // Why is this needed?
+		_pianoroll->contents().show_all ();
+
+	}
+
+	switch (red) {
+	case BottomPaneOnly:
+		/* If it's visible, it's visible; otherwise ... user choice */
+		break;
+	case OpenBottomPane:
+		show_att_bottom (true);
+		break;
+	case PreferBottomPane:
+		/* we're good: if it's visible, it's visible */
+		break;
+	case NeverBottomPane:
+		/* user may have made it visible anyway */
+		break;
+	}
 }
 
 void
@@ -1903,17 +1994,19 @@ Editor::invert_selection ()
  *  within the region are already selected.
  */
 void
-Editor::select_all_within (timepos_t const & start, timepos_t const & end, double top, double bot, const TrackViewList& tracklist, SelectionOperation op, bool preserve_if_selected)
+Editor::select_all_within (timepos_t const & start, timepos_t const & end, double top, double bot, std::list<SelectableOwner*> const & owners, SelectionOperation op, bool preserve_if_selected)
 {
 	list<Selectable*> found;
 
-	for (TrackViewList::const_iterator iter = tracklist.begin(); iter != tracklist.end(); ++iter) {
+	for (auto & owner : owners) {
 
-		if ((*iter)->hidden()) {
+		TimeAxisView* tav = dynamic_cast<TimeAxisView*> (owner);
+
+		if (tav && tav->hidden()) {
 			continue;
 		}
 
-		(*iter)->get_selectables (start, end, top, bot, found);
+		owner->get_selectables (start, end, top, bot, found);
 	}
 
 	if (found.empty()) {
@@ -1979,7 +2072,7 @@ Editor::set_selection_from_region ()
 
 	selection->set (tvl);
 
-	if (!get_smart_mode () || !(mouse_mode == Editing::MouseObject) ) {
+	if (!get_smart_mode () || !(current_mouse_mode() == Editing::MouseObject) ) {
 		set_mouse_mode (Editing::MouseRange, false);
 	}
 }
@@ -2022,7 +2115,7 @@ Editor::set_selection_from_range (Location& loc)
 
 	commit_reversible_selection_op ();
 
-	if (!get_smart_mode () || mouse_mode != Editing::MouseObject) {
+	if (!get_smart_mode () || current_mouse_mode() != Editing::MouseObject) {
 		set_mouse_mode (MouseRange, false);
 	}
 }
@@ -2293,7 +2386,7 @@ Editor::select_range_between ()
 		return;
 	}
 
-	if (!get_smart_mode () || mouse_mode != Editing::MouseObject) {
+	if (!get_smart_mode () || current_mouse_mode() != Editing::MouseObject) {
 		set_mouse_mode (MouseRange, false);
 	}
 
@@ -2307,16 +2400,16 @@ Editor::get_edit_op_range (timepos_t& start, timepos_t& end) const
 {
 	/* if an explicit range exists, use it */
 
-	if ((mouse_mode == MouseRange || get_smart_mode()) &&  !selection->time.empty()) {
+	if ((current_mouse_mode() == MouseRange || get_smart_mode()) &&  !selection->time.empty()) {
 		/* we know that these are ordered */
 		start = selection->time.start_time();
 		end = selection->time.end_time();
 		return true;
-	} else {
-		start = timepos_t ();
-		end = timepos_t ();
-		return false;
 	}
+
+	start = timepos_t ();
+	end = timepos_t ();
+	return false;
 }
 
 void
@@ -2489,3 +2582,20 @@ Editor::move_selected_tracks (bool up)
 		ensure_time_axis_view_is_visible (*scroll_to, false);
 	}
 }
+
+RegionSelection
+Editor::region_selection()
+{
+	return get_regions_from_selection_and_entered ();
+}
+
+std::list<SelectableOwner*>
+Editor::selectable_owners()
+{
+	std::list<SelectableOwner*> sl;
+	for (auto & tv : track_views) {
+		sl.push_back (tv);
+	}
+
+	return sl;
+}
