@@ -164,7 +164,7 @@ Editor::make_tempo_marker (Temporal::TempoPoint const * ts, TempoPoint const *&
 	const std::string tname (X_(""));
 	char const * color_name = X_("tempo marker");
 
-	tempo_marks.insert (before, new TempoMarker (*this, *tempo_group, color_name, tname, *ts, ts->sample (sr), tc_color));
+	tempo_marks.insert (before, new TempoMarker (*this, *tempo_group, color_name, tname, *ts, ts->sample_is_dangerous (sr), tc_color));
 
 	/* XXX the point of this code was "a jump in tempo by more than 1 ntpm results in a red
 	   tempo mark pointer."  (3a7bc1fd3f32f0)
@@ -202,6 +202,9 @@ Editor::reset_tempo_marks ()
 	TempoPoint const * prev_ts = 0;
 
 	for (auto & t : tempo_marks) {
+		if (entered_marker == t) {
+			entered_marker = 0;
+		}
 		delete t;
 	}
 
@@ -275,7 +278,7 @@ Editor::update_tempo_curves (double min_tempo, double max_tempo, samplecnt_t sr)
 
 		if (tmp != tempo_marks.end()) {
 			TempoMarker* nxt = static_cast<TempoMarker*>(*tmp);
-			curve.set_duration (nxt->tempo().sample(sr) - tm->tempo().sample(sr));
+			curve.set_duration (nxt->tempo().sample_is_dangerous (sr) - tm->tempo().sample_is_dangerous (sr));
 		} else {
 			curve.set_duration (samplecnt_t (UINT32_MAX));
 		}
@@ -300,8 +303,9 @@ Editor::tempo_map_changed ()
 
 	 reset_metric_marks ();
 	 update_tempo_based_rulers ();
+	 update_section_rects();
 	 update_all_marker_lanes ();
-	 maybe_draw_grid_lines ();
+	 maybe_draw_grid_lines (time_line_group);
 }
 
 void
@@ -359,7 +363,7 @@ Editor::compute_current_bbt_points (Temporal::TempoMapPoints& grid, samplepos_t
 	const samplecnt_t sr (_session->sample_rate());
 
 	float divisor;
-	switch (_grid_type) {
+	switch (grid_type()) {
 		case GridTypeBeatDiv3:
 		case GridTypeBeatDiv6:
 		case GridTypeBeatDiv12:
@@ -429,42 +433,6 @@ Editor::compute_current_bbt_points (Temporal::TempoMapPoints& grid, samplepos_t
 	}
 }
 
-void
-Editor::hide_grid_lines ()
-{
-	if (grid_lines) {
-		grid_lines->hide();
-	}
-}
-
-void
-Editor::maybe_draw_grid_lines ()
-{
-	if ( _session == 0 ) {
-		return;
-	}
-
-	if (grid_lines == 0) {
-		grid_lines = new GridLines (time_line_group, ArdourCanvas::LineSet::Vertical);
-	}
-
-	grid_marks.clear();
-	samplepos_t rightmost_sample = _leftmost_sample + current_page_samples();
-
-	if ( grid_musical() ) {
-		 metric_get_bbt (grid_marks, _leftmost_sample, rightmost_sample, 12);
-	} else if (_grid_type== GridTypeTimecode) {
-		 metric_get_timecode (grid_marks, _leftmost_sample, rightmost_sample, 12);
-	} else if (_grid_type == GridTypeCDFrame) {
-		metric_get_minsec (grid_marks, _leftmost_sample, rightmost_sample, 12);
-	} else if (_grid_type == GridTypeMinSec) {
-		metric_get_minsec (grid_marks, _leftmost_sample, rightmost_sample, 12);
-	}
-
-	grid_lines->draw (grid_marks);
-	grid_lines->show();
-}
-
 void
 Editor::mouse_add_new_tempo_event (timepos_t pos)
 {
@@ -504,9 +472,12 @@ Editor::mouse_add_new_meter_event (timepos_t pos)
 
 	Temporal::BBT_Time r;
 	meter_dialog.get_bbt_time (r);
-	Temporal::BBT_Argument requested (superclock_t (0), r);
 
 	TempoMapChange tmc (*this, _("add time signature"));
+	superclock_t sc (tmc.map().previous_bbt_reference_at_superclock (samples_to_superclock (pos.samples(), TEMPORAL_SAMPLE_RATE)));
+
+	Temporal::BBT_Argument requested (sc, r);
+
 	pos = timepos_t (tmc.map().quarters_at (requested));
 	tmc.map().set_meter (Meter (bpb, note_type), pos);
 }
@@ -608,7 +579,7 @@ Editor::edit_meter_section (Temporal::MeterPoint& section)
 		return;
 	}
 
-	Temporal::TempoMetric tm (TempoMap::use()->metric_at (timepos_t (section.sample(TEMPORAL_SAMPLE_RATE))));
+	Temporal::TempoMetric tm (TempoMap::use()->metric_at (timepos_t::from_superclock (section.sclock())));
 	Temporal::MeterPoint const * mpp (TempoMap::use()->previous_meter (tm.meter()));
 
 	double bpb = meter_dialog.get_bpb ();
@@ -665,8 +636,9 @@ Editor::edit_meter_section (Temporal::MeterPoint& section)
 }
 
 void
-Editor::edit_bbt (MusicTimePoint& point)
+Editor::edit_bbt (BBTMarker& bm)
 {
+	MusicTimePoint const & point (bm.mt_point());
 	BBTMarkerDialog dialog (point);
 
 	switch (dialog.run ()) {
@@ -677,16 +649,24 @@ Editor::edit_bbt (MusicTimePoint& point)
 		return;
 	}
 
-	if (dialog.bbt_value() == point.bbt()) {
-		/* just a name change, no need to modify the map */
-		point.set_name (dialog.name());
-		/* XXX need to update marker label */
-		return;
-	}
+	BBT_Time bbt (dialog.bbt_value());
+	Temporal::timepos_t pos (dialog.position());
+	std::string name (dialog.name());
 
-	TempoMapChange tmc (*this, _("edit tempo"));
-	tmc.map().remove_bartime (point);
-	tmc.map().set_bartime (dialog.bbt_value(), dialog.position(), dialog.name());
+	if (bbt != point.bbt() ||
+	    pos.superclocks() != point.sclock() ||
+	    name != point.name()) {
+		TempoMapChange tmc (*this, _("edit tempo"));
+		tmc.map().remove_bartime (point);
+		tmc.map().set_bartime (bbt, pos, name);
+
+		/* XXX this ought to be set via MVC-style design, but currently
+		 * there is no signal to notify anyone that the
+		 * MusicTimePoint's name has been changed.
+		 */
+
+		bm.set_name (name);
+	}
 }
 
 void
@@ -701,7 +681,7 @@ Editor::edit_tempo_section (TempoPoint& section)
 		return;
 	}
 
-	Temporal::TempoMetric tm (TempoMap::use()->metric_at (timepos_t (section.sample (TEMPORAL_SAMPLE_RATE))));
+	Temporal::TempoMetric tm (TempoMap::use()->metric_at (timepos_t::from_superclock (section.sclock())));
 	Temporal::TempoPoint const * tpp (TempoMap::use()->previous_tempo (tm.tempo()));
 
 	double bpm = tempo_dialog.get_bpm ();
@@ -774,7 +754,7 @@ Editor::edit_meter_marker (MeterMarker& mm)
 void
 Editor::edit_bbt_marker (BBTMarker& bm)
 {
-	edit_bbt (const_cast<Temporal::MusicTimePoint&>(bm.mt_point()));
+	edit_bbt (bm);
 }
 
 gint
@@ -939,7 +919,7 @@ Editor::mid_tempo_change (MidTempoChanges what_changed)
 	}
 
 	update_tempo_based_rulers ();
-	maybe_draw_grid_lines ();
+	maybe_draw_grid_lines (time_line_group);
 
 	if (!(what_changed & (MappingChanged|BBTChanged))) {
 		/* Nothing changes in tracks when it is a tempo mapping
