@@ -20,9 +20,9 @@
 #include <algorithm>
 
 #include <pangomm/layout.h>
-#include <gtkmm/label.h>
-#include <gtkmm/table.h>
-#include <gtkmm/stock.h>
+#include <ytkmm/label.h>
+#include <ytkmm/table.h>
+#include <ytkmm/stock.h>
 
 #include "pbd/openuri.h"
 #include "pbd/basename.h"
@@ -597,7 +597,7 @@ ExportReport::init (const AnalysisResults & ar, bool with_file)
 
 		if (channels > 0 && file_length > 0 && sample_rate > 0)
 		{
-			/* Time Axis  -- re-use waveform width */
+			/* Time Axis  -- reuse waveform width */
 			const size_t width = p->width;
 			Cairo::RefPtr<Cairo::ImageSurface> ytme = ArdourGraphs::time_axis (get_pango_context (), width, m_l, start_off, file_length, sample_rate);
 
@@ -832,8 +832,8 @@ ExportReport::init (const AnalysisResults & ar, bool with_file)
 	get_vbox ()->pack_start (pages, false, false);
 
 	if (_session && _session->the_auditioner()) {
-		_session->AuditionActive.connect(auditioner_connections, invalidator (*this), boost::bind (&ExportReport::audition_active, this, _1), gui_context());
-		_session->the_auditioner()->AuditionProgress.connect(auditioner_connections, invalidator (*this), boost::bind (&ExportReport::audition_progress, this, _1, _2), gui_context());
+		_session->AuditionActive.connect(auditioner_connections, invalidator (*this), std::bind (&ExportReport::audition_active, this, _1), gui_context());
+		_session->the_auditioner()->AuditionProgress.connect(auditioner_connections, invalidator (*this), std::bind (&ExportReport::audition_progress, this, _1, _2), gui_context());
 	}
 
 	if (_session && with_file && _session->the_auditioner()) {
