@@ -29,13 +29,14 @@
 
 #include <pangomm.h>
 
-#include <gtkmm/alignment.h>
-#include <gdkmm/color.h>
-#include <gtkmm/style.h>
+#include <ytkmm/alignment.h>
+#include <ydkmm/color.h>
+#include <ytkmm/style.h>
 
 #include "ardour/amp.h"
 #include "ardour/control_group.h"
 #include "ardour/logmeter.h"
+#include "ardour/rc_configuration.h"
 #include "ardour/route_group.h"
 #include "ardour/selection.h"
 #include "ardour/session_route.h"
@@ -111,6 +112,8 @@ GainMeterBase::GainMeterBase (Session* s, bool horizontal, int fader_length, int
 	, _data_type (DataType::AUDIO)
 	, _clear_meters (true)
 	, _meter_peaked (false)
+	, _unscaled_fader_length (fader_length)
+	, _unscaled_fader_girth (fader_girth)
 {
 	using namespace Menu_Helpers;
 
@@ -134,7 +137,7 @@ GainMeterBase::GainMeterBase (Session* s, bool horizontal, int fader_length, int
 
 	level_meter = new LevelMeterHBox(_session);
 
-	level_meter->ButtonPress.connect_same_thread (_level_meter_connection, boost::bind (&GainMeterBase::level_meter_button_press, this, _1));
+	level_meter->ButtonPress.connect_same_thread (_level_meter_connection, std::bind (&GainMeterBase::level_meter_button_press, this, _1));
 	meter_metric_area.signal_button_press_event().connect (sigc::mem_fun (*this, &GainMeterBase::level_meter_button_press));
 	meter_metric_area.add_events (Gdk::BUTTON_PRESS_MASK);
 
@@ -217,8 +220,8 @@ GainMeterBase::GainMeterBase (Session* s, bool horizontal, int fader_length, int
 	RedrawMetrics.connect (sigc::mem_fun(*this, &GainMeterBase::redraw_metrics));
 
 	UI::instance()->theme_changed.connect (sigc::mem_fun(*this, &GainMeterBase::on_theme_changed));
-	UIConfiguration::instance().ColorsChanged.connect (sigc::bind(sigc::mem_fun (*this, &GainMeterBase::color_handler), false));
-	UIConfiguration::instance().DPIReset.connect (sigc::bind(sigc::mem_fun (*this, &GainMeterBase::color_handler), true));
+	UIConfiguration::instance().ColorsChanged.connect (sigc::mem_fun (*this, &GainMeterBase::color_handler));
+	UIConfiguration::instance().DPIReset.connect (sigc::mem_fun (*this, &GainMeterBase::reset_dpi));
 }
 
 GainMeterBase::~GainMeterBase ()
@@ -258,7 +261,7 @@ GainMeterBase::set_controls (std::shared_ptr<Stripable> s,
 
 	if (amp) {
 		amp->ConfigurationChanged.connect (
-			model_connections, invalidator (*this), boost::bind (&GainMeterBase::setup_gain_adjustment, this), gui_context ()
+			model_connections, invalidator (*this), std::bind (&GainMeterBase::setup_gain_adjustment, this), gui_context ()
 			);
 	}
 
@@ -284,12 +287,12 @@ GainMeterBase::set_controls (std::shared_ptr<Stripable> s,
 		connections.push_back (gain_automation_state_button.signal_button_press_event().connect (sigc::mem_fun(*this, &GainMeterBase::gain_automation_state_button_event), false));
 		connections.push_back (ChangeGainAutomationState.connect (sigc::mem_fun(*this, &GainMeterBase::set_gain_astate)));
 
-		_control->alist()->automation_state_changed.connect (model_connections, invalidator (*this), boost::bind (&GainMeter::gain_automation_state_changed, this), gui_context());
+		_control->alist()->automation_state_changed.connect (model_connections, invalidator (*this), std::bind (&GainMeter::gain_automation_state_changed, this), gui_context());
 
 		gain_automation_state_changed ();
 	}
 
-	_control->Changed.connect (model_connections, invalidator (*this), boost::bind (&GainMeterBase::gain_changed, this), gui_context());
+	_control->Changed.connect (model_connections, invalidator (*this), std::bind (&GainMeterBase::gain_changed, this), gui_context());
 
 	gain_changed ();
 	show_gain ();
@@ -383,7 +386,7 @@ GainMeterBase::setup_meters (int len)
 	if (len == 0) {
 		assert (gain_slider);
 		Gtk::Requisition sz;
-		sz = gain_slider->size_request ();
+		sz = gain_slider->size_request (); // XXX
 		len = gain_slider->orientation () == FaderWidget::VERT ? sz.height : sz.width;
 	}
 
@@ -485,7 +488,7 @@ GainMeterBase::reset_route_peak_display (Route* r)
 }
 
 void
-GainMeterBase::reset_group_peak_display (RouteGroup* group)
+GainMeterBase::reset_group_peak_display (std::shared_ptr<RouteGroup> group)
 {
 	if (route() && group == route()->route_group()) {
 		reset_peak_display ();
@@ -536,10 +539,11 @@ GainMeterBase::gain_activated ()
 
 	/* clamp to displayable values */
 	if (_data_type == DataType::AUDIO) {
-		f = min (f, 6.0f);
+		float max_dB = accurate_coefficient_to_dB (Config->get_max_gain());
+		f = min (f, max_dB);
 		_control->set_value (dB_to_coefficient(f), Controllable::UseGroup);
 	} else {
-		f = min (fabs (f), 2.0f);
+		f = min (fabs (f), Config->get_max_gain());
 		_control->set_value (f, Controllable::UseGroup);
 	}
 
@@ -740,10 +744,10 @@ GainMeterBase::set_meter_point (Route& route, MeterPoint mp)
 void
 GainMeterBase::set_route_group_meter_point (Route& route, MeterPoint mp)
 {
-	RouteGroup* route_group;
+	std::shared_ptr<RouteGroup> route_group;
 
 	if ((route_group = route.route_group ()) != 0) {
-		route_group->foreach_route (boost::bind (&Route::set_meter_point, _1, mp));
+		route_group->foreach_route (std::bind (&Route::set_meter_point, _1, mp));
 	} else {
 		route.set_meter_point (mp);
 	}
@@ -925,11 +929,22 @@ GainMeterBase::update_meters()
 	}
 }
 
-void GainMeterBase::color_handler(bool /*dpi*/)
+void
+GainMeterBase::color_handler()
 {
 	setup_meters();
 }
 
+void
+GainMeterBase::reset_dpi ()
+{
+	int length = rint (_unscaled_fader_length * UIConfiguration::instance().get_ui_scale());
+	int girth = rint (_unscaled_fader_girth * UIConfiguration::instance().get_ui_scale());
+	dynamic_cast<ArdourFader*>(gain_slider)->update_min_size (length, girth);
+
+	setup_meters();
+}
+
 void
 GainMeterBase::set_width (Width w, int len)
 {
@@ -979,7 +994,6 @@ GainMeter::GainMeter (Session* s, int fader_length)
 	gain_display_box.pack_start (peak_display, true, true);
 
 	meter_metric_area.set_name ("AudioTrackMetrics");
-	meter_metric_area.set_size_request(PX_SCALE(24, 24), -1);
 
 	gain_automation_state_button.set_name ("mixer strip button");
 
@@ -987,8 +1001,6 @@ GainMeter::GainMeter (Session* s, int fader_length)
 
 	gain_automation_state_button.set_can_focus (false);
 
-	gain_automation_state_button.set_size_request (PX_SCALE(12, 15), PX_SCALE(12, 15));
-
 	fader_vbox.set_spacing (0);
 	fader_vbox.pack_start (*gain_slider, true, true);
 
@@ -997,20 +1009,17 @@ GainMeter::GainMeter (Session* s, int fader_length)
 
 	hbox.pack_start (fader_alignment, true, true);
 
-	set_spacing (PX_SCALE(2, 2));
-
 	pack_start (gain_display_box, Gtk::PACK_SHRINK);
 	pack_start (hbox, true, true);
 
 	meter_alignment.set (0.5, 0.5, 0.0, 1.0);
 	meter_alignment.add (*level_meter);
 
+	reset_dpi ();
+
 	meter_metric_area.signal_expose_event().connect (
 		sigc::mem_fun(*this, &GainMeter::meter_metrics_expose));
 
-	meter_ticks1_area.set_size_request (PX_SCALE(3, 3), -1);
-	meter_ticks2_area.set_size_request (PX_SCALE(3, 3), -1);
-
 	meter_ticks1_area.signal_expose_event().connect (
 			sigc::mem_fun(*this, &GainMeter::meter_ticks1_expose));
 	meter_ticks2_area.signal_expose_event().connect (
@@ -1023,6 +1032,20 @@ GainMeter::GainMeter (Session* s, int fader_length)
 
 	meter_metric_area.set_no_show_all ();
 }
+
+void
+GainMeter::reset_dpi ()
+{
+	meter_metric_area.set_size_request(PX_SCALE(24, 24), -1);
+	gain_automation_state_button.set_size_request (PX_SCALE(12, 15), PX_SCALE(12, 15));
+	set_spacing (PX_SCALE(2, 2));
+	meter_ticks1_area.set_size_request (PX_SCALE(3, 3), -1);
+	meter_ticks2_area.set_size_request (PX_SCALE(3, 3), -1);
+	if (route()) {
+		GainMeterBase::reset_dpi ();
+	}
+}
+
 #undef PX_SCALE
 
 GainMeter::~GainMeter () { }
@@ -1045,10 +1068,10 @@ GainMeter::set_controls (std::shared_ptr<Stripable> s,
 
 	if (_meter) {
 		_meter->ConfigurationChanged.connect (
-			model_connections, invalidator (*this), boost::bind (&GainMeter::meter_configuration_changed, this, _1), gui_context()
+			model_connections, invalidator (*this), std::bind (&GainMeter::meter_configuration_changed, this, _1), gui_context()
 			);
 		_meter->MeterTypeChanged.connect (
-			model_connections, invalidator (*this), boost::bind (&GainMeter::redraw_metrics, this), gui_context()
+			model_connections, invalidator (*this), std::bind (&GainMeter::redraw_metrics, this), gui_context()
 			);
 
 		meter_configuration_changed (_meter->input_streams ());
@@ -1056,7 +1079,7 @@ GainMeter::set_controls (std::shared_ptr<Stripable> s,
 
 
 	if (route()) {
-		route()->active_changed.connect (model_connections, invalidator (*this), boost::bind (&GainMeter::route_active_changed, this), gui_context ());
+		route()->active_changed.connect (model_connections, invalidator (*this), std::bind (&GainMeter::route_active_changed, this), gui_context ());
 	}
 
 	hbox.pack_start (meter_hbox, true, true);
