@@ -16,16 +16,18 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef __ardour_grid_lines_h__
-#define __ardour_grid_lines_h__
+#pragma once
 
+#include "canvas/container.h"
 #include "canvas/line_set.h"
 #include "canvas/ruler.h"
 #include "ardour/tempo.h"
 
+class EditingContext;
+
 class GridLines {
 public:
-	GridLines (ArdourCanvas::Container* group, double screen_height);
+	GridLines (EditingContext&, ArdourCanvas::Container* group, double screen_height);
 	~GridLines ();
 
 	void draw (std::vector<ArdourCanvas::Ruler::Mark> const & marks);
@@ -34,8 +36,7 @@ public:
 	void hide();
 
 private:
-
+	EditingContext& _editing_context;
 	ArdourCanvas::LineSet lines;
 };
 
-#endif /* __ardour_grid_lines_h__ */
