@@ -17,14 +17,17 @@
  */
 #ifndef _luasignal_h_
 #define _luasignal_h_
+
+#include <string>
+
 namespace LuaSignal {
 
-#define ENGINE(name,c,p) name,
-#define STATIC(name,c,p) name,
-#define SESSION(name,c,p) name,
+#define ENGINE(name,c) name,
+#define STATIC(name,c) name,
+#define SESSION(name,c) name,
 
 	enum LuaSignal {
-#		include "luasignal_syms.h"
+#		include "luasignal_syms.inc.h"
 		LAST_SIGNAL
 	};
 
