@@ -25,12 +25,12 @@
 #include <cmath>
 #include <utility>
 
-#include <gtkmm.h>
+#include <ytkmm/ytkmm.h>
 
 #include <gtkmm2ext/gtk_ui.h>
 
-#include "canvas/line_set.h"
 #include "canvas/rectangle.h"
+#include "canvas/rect_set.h"
 
 #include "ardour/midi_region.h"
 #include "ardour/midi_source.h"
@@ -64,14 +64,7 @@ using namespace Editing;
 
 MidiStreamView::MidiStreamView (MidiTimeAxisView& tv)
 	: StreamView (tv)
-	, note_range_adjustment(0.0f, 0.0f, 0.0f)
-	, _range_dirty(false)
-	, _range_sum_cache(-1.0)
-	, _lowest_note(UIConfiguration::instance().get_default_lower_midi_note())
-	, _highest_note(UIConfiguration::instance().get_default_upper_midi_note())
-	, _data_note_min(60)
-	, _data_note_max(71)
-	, _note_lines (0)
+	, MidiViewBackground (_canvas_group, tv.editor())
 	, _updates_suspended (false)
 {
 	/* use a dedicated group for MIDI regions (on top of the grid and lines) */
@@ -82,39 +75,38 @@ MidiStreamView::MidiStreamView (MidiTimeAxisView& tv)
 	/* put the note lines in the timeaxisview's group, so it
 	   can be put below ghost regions from MIDI underlays
 	*/
-	_note_lines = new ArdourCanvas::LineSet (_canvas_group, ArdourCanvas::LineSet::Horizontal);
-
 	_note_lines->Event.connect(
 		sigc::bind(sigc::mem_fun(_trackview.editor(),
 		                         &PublicEditor::canvas_stream_view_event),
 		           _note_lines, &_trackview));
 
-	_note_lines->lower_to_bottom();
 
 	color_handler ();
 
 	UIConfiguration::instance().ColorsChanged.connect(sigc::mem_fun(*this, &MidiStreamView::color_handler));
 	UIConfiguration::instance().ParameterChanged.connect(sigc::mem_fun(*this, &MidiStreamView::parameter_changed));
-
-	note_range_adjustment.set_page_size(_highest_note - _lowest_note);
-	note_range_adjustment.set_value(_lowest_note);
-
-	note_range_adjustment.signal_value_changed().connect(
-		sigc::mem_fun(*this, &MidiStreamView::note_range_adjustment_changed));
 }
 
 MidiStreamView::~MidiStreamView ()
 {
+	undisplay_track ();
+}
+
+InstrumentInfo*
+MidiStreamView::instrument_info() const
+{
+	std::shared_ptr<Route> r = _trackview.route();
+	if (!r) {
+		return nullptr;
+	}
+
+	return &r->instrument_info();
 }
 
 void
 MidiStreamView::parameter_changed (string const & param)
 {
-	if (param == X_("max-note-height")) {
-		apply_note_range (_lowest_note, _highest_note, true);
-	} else {
-		StreamView::parameter_changed (param);
-	}
+	StreamView::parameter_changed (param);
 }
 
 RegionView*
@@ -129,12 +121,12 @@ MidiStreamView::create_region_view (std::shared_ptr<Region> r, bool /*wfd*/, boo
 	RegionView* region_view = NULL;
 	if (recording) {
 		region_view = new MidiRegionView (
-			_region_group, _trackview, region,
-			_samples_per_pixel, region_color, recording,
+			_region_group, _trackview.editor(), _trackview, region,
+			_samples_per_pixel, _region_color, recording,
 			TimeAxisViewItem::Visibility(TimeAxisViewItem::ShowFrame));
 	} else {
-		region_view = new MidiRegionView (_region_group, _trackview, region,
-		                                  _samples_per_pixel, region_color);
+		region_view = new MidiRegionView (_region_group, _trackview.editor(), _trackview, region,
+		                                  _samples_per_pixel, _region_color);
 	}
 
 	region_view->init (false);
@@ -179,13 +171,13 @@ MidiStreamView::add_region_view_internal (std::shared_ptr<Region> r, bool wait_f
 		/* fit note range if we are importing */
 		if (_trackview.session()->operation_in_progress (Operations::insert_file)) {
 			/* this will call display_region() */
-			set_note_range (ContentsRange);
+			set_note_visibility_range_style (ContentsRange);
 		}
 	}
 
 	/* catch regionview going away */
 	std::weak_ptr<Region> wr (region); // make this explicit
-	region->DropReferences.connect (*this, invalidator (*this), boost::bind (&MidiStreamView::remove_region_view, this, wr), gui_context());
+	region->DropReferences.connect (*this, invalidator (*this), std::bind (&MidiStreamView::remove_region_view, this, wr), gui_context());
 
 	RegionViewAdded (region_view);
 
@@ -215,7 +207,9 @@ MidiStreamView::display_region (MidiRegionView* region_view, bool)
 		return;
 	}
 
-	_range_dirty = update_data_note_range (source->model()->lowest_note(), source->model()->highest_note());
+	if (!source->model()->empty()) {
+		_range_dirty = update_data_note_range (source->model()->lowest_note(), source->model()->highest_note());
+	}
 
 	// Display region contents
 	region_view->display_model (source->model());
@@ -227,11 +221,18 @@ MidiStreamView::display_track (std::shared_ptr<Track> tr)
 {
 	StreamView::display_track (tr);
 
-	draw_note_lines();
+	setup_note_lines();
 
 	NoteRangeChanged(); /* EMIT SIGNAL*/
 }
 
+void
+MidiStreamView::update_contents_height ()
+{
+	StreamView::update_contents_height();
+	MidiViewBackground::update_contents_height ();
+}
+
 void
 MidiStreamView::update_contents_metrics(std::shared_ptr<Region> r)
 {
@@ -243,21 +244,6 @@ MidiStreamView::update_contents_metrics(std::shared_ptr<Region> r)
 	}
 }
 
-bool
-MidiStreamView::update_data_note_range(uint8_t min, uint8_t max)
-{
-	bool dirty = false;
-	if (min < _data_note_min) {
-		_data_note_min = min;
-		dirty = true;
-	}
-	if (max > _data_note_max) {
-		_data_note_max = max;
-		dirty = true;
-	}
-	return dirty;
-}
-
 void
 MidiStreamView::set_layer_display (LayerDisplay d)
 {
@@ -314,140 +300,7 @@ MidiStreamView::redisplay_track ()
 }
 
 void
-MidiStreamView::update_contents_height ()
-{
-	StreamView::update_contents_height();
-
-	_note_lines->set_extent (ArdourCanvas::COORD_MAX);
-
-	apply_note_range (lowest_note(), highest_note(), true);
-}
-
-void
-MidiStreamView::draw_note_lines()
-{
-	if (!_note_lines || _updates_suspended) {
-		return;
-	}
-
-	double y;
-	double prev_y = 0.;
-	Gtkmm2ext::Color black = UIConfiguration::instance().color_mod ("piano roll black", "piano roll black");
-	Gtkmm2ext::Color white = UIConfiguration::instance().color_mod ("piano roll white", "piano roll white");
-	Gtkmm2ext::Color outline = UIConfiguration::instance().color ("piano roll black outline");
-	Gtkmm2ext::Color color;
-
-	ArdourCanvas::LineSet::ResetRAII lr (*_note_lines);
-
-	if (child_height() < 140 || note_height() < 3) {
-		/* track is too small for note lines, or there are too many */
-		return;
-	}
-
-	/* do this is order of highest ... lowest since that matches the
-	 * coordinate system in which y=0 is at the top
-	 */
-
-	for (int i = highest_note() + 1; i >= lowest_note(); --i) {
-
-		y = floor (note_to_y (i));
-
-		/* add a thicker line/bar which covers the entire vertical height of this note. */
-
-		switch (i % 12) {
-		case 1:
-		case 3:
-		case 6:
-		case 8:
-		case 10:
-			color = black;
-			break;
-		case 4:
-		case 11:
-			/* this is the line actually corresponding to the division between B & C and E & F */
-			_note_lines->add_coord (y, 1.0, outline);
-			/* fallthrough */
-		default:
-			color = white;
-			break;
-		}
-
-		double h = y - prev_y;
-		double middle = y + (h/2.0);
-
-		if (!fmod (h, 2.) && !fmod (middle, 1.)) {
-			middle += 0.5;
-		}
-
-		if (middle >= 0 && h > 1.0) {
-			_note_lines->add_coord (middle, h, color);
-		}
-
-		prev_y = y;
-	}
-}
-
-void
-MidiStreamView::set_note_range(VisibleNoteRange r)
-{
-	if (r == FullRange) {
-		_lowest_note = 0;
-		_highest_note = 127;
-	} else {
-		_lowest_note = _data_note_min;
-		_highest_note = _data_note_max;
-	}
-
-	apply_note_range(_lowest_note, _highest_note, true);
-}
-
-void
-MidiStreamView::apply_note_range(uint8_t lowest, uint8_t highest, bool to_region_views)
-{
-	_highest_note = highest;
-	_lowest_note = lowest;
-
-	float uiscale = UIConfiguration::instance().get_ui_scale();
-	uiscale = expf (uiscale) / expf (1.f);
-
-	const int mnh = UIConfiguration::instance().get_max_note_height();
-	int const max_note_height = std::max<int> (mnh, mnh * uiscale);
-	int const range = _highest_note - _lowest_note;
-
-	int const available_note_range = floor (child_height() / max_note_height);
-	int additional_notes = available_note_range - range;
-
-	/* distribute additional notes to higher and lower ranges, clamp at 0 and 127 */
-	for (int i = 0; i < additional_notes; i++){
-
-		if (i % 2 && _highest_note < 127){
-			_highest_note++;
-		}
-		else if (i % 2) {
-			_lowest_note--;
-		}
-		else if (_lowest_note > 0){
-			_lowest_note--;
-		}
-		else {
-			_highest_note++;
-		}
-	}
-
-	note_range_adjustment.set_page_size (_highest_note - _lowest_note);
-	note_range_adjustment.set_value (_lowest_note);
-
-	draw_note_lines();
-
-	if (to_region_views) {
-		apply_note_range_to_regions ();
-	}
-
-	NoteRangeChanged(); /* EMIT SIGNAL*/
-}
-
-void
-MidiStreamView::apply_note_range_to_regions ()
+MidiStreamView::apply_note_range_to_children ()
 {
 	if (!_updates_suspended) {
 		for (list<RegionView*>::iterator i = region_views.begin(); i != region_views.end(); ++i) {
@@ -456,13 +309,6 @@ MidiStreamView::apply_note_range_to_regions ()
 	}
 }
 
-void
-MidiStreamView::update_note_range(uint8_t note_num)
-{
-	_data_note_min = min(_data_note_min, note_num);
-	_data_note_max = max(_data_note_max, note_num);
-}
-
 void
 MidiStreamView::setup_rec_box ()
 {
@@ -472,7 +318,7 @@ MidiStreamView::setup_rec_box ()
 	    (_trackview.session()->transport_rolling() || _trackview.session()->get_record_enabled())) {
 
 		if (!rec_active &&
-		    _trackview.session()->record_status() == Session::Recording &&
+		    _trackview.session()->record_status() == Recording &&
 		    _trackview.track()->rec_enable_control()->get_value()) {
 
 			if (UIConfiguration::instance().get_show_waveforms_while_recording() && rec_regions.size() == rec_rects.size()) {
@@ -541,7 +387,7 @@ MidiStreamView::setup_rec_box ()
 			create_rec_box (_trackview.midi_track()->current_capture_start(), 0);
 
 		} else if (rec_active &&
-		           (_trackview.session()->record_status() != Session::Recording ||
+		           (_trackview.session()->record_status() != Recording ||
 		            !_trackview.track()->rec_enable_control()->get_value())) {
 			screen_update_connection.disconnect();
 			rec_active = false;
@@ -559,8 +405,9 @@ MidiStreamView::setup_rec_box ()
 void
 MidiStreamView::color_handler ()
 {
+	MidiViewBackground::color_handler ();
+
 	_region_group->set_render_with_alpha (UIConfiguration::instance().modifier ("region alpha").a());
-	draw_note_lines ();
 
 	if (_trackview.is_midi_track()) {
 		canvas_rect->set_fill_color (UIConfiguration::instance().color_mod ("midi track base", "midi track base"));
@@ -573,34 +420,6 @@ MidiStreamView::color_handler ()
 	}
 }
 
-void
-MidiStreamView::note_range_adjustment_changed()
-{
-	double sum = note_range_adjustment.get_value() + note_range_adjustment.get_page_size();
-	int lowest = (int) floor(note_range_adjustment.get_value());
-	int highest;
-
-	if (sum == _range_sum_cache) {
-		//cerr << "cached" << endl;
-		highest = (int) floor(sum);
-	} else {
-		//cerr << "recalc" << endl;
-		highest = lowest + (int) floor(note_range_adjustment.get_page_size());
-		_range_sum_cache = sum;
-	}
-
-	if (lowest == _lowest_note && highest == _highest_note) {
-		return;
-	}
-
-	//cerr << "note range adjustment changed: " << lowest << " " << highest << endl;
-	//cerr << "  val=" << v_zoom_adjustment.get_value() << " page=" << v_zoom_adjustment.get_page_size() << " sum=" << v_zoom_adjustment.get_value() + v_zoom_adjustment.get_page_size() << endl;
-
-	_lowest_note = lowest;
-	_highest_note = highest;
-	apply_note_range(lowest, highest, true);
-}
-
 void
 MidiStreamView::update_rec_box ()
 {
@@ -615,24 +434,9 @@ MidiStreamView::update_rec_box ()
 	region->set_length (timecnt_t (_trackview.track()->current_capture_end () - _trackview.track()->current_capture_start()));
 
 	MidiRegionView* mrv = dynamic_cast<MidiRegionView*> (rec_regions.back().second);
-	mrv->extend_active_notes ();
+	mrv->extend_unfinished_live_notes ();
 }
 
-uint8_t
-MidiStreamView::y_to_note (double y) const
-{
-	int const n = ((contents_height() - y) / contents_height() * (double)contents_note_range())
-		+ lowest_note();
-
-	if (n < 0) {
-		return 0;
-	} else if (n > 127) {
-		return 127;
-	}
-
-	/* min due to rounding and/or off-by-one errors */
-	return min ((uint8_t) n, highest_note());
-}
 
 /** Suspend updates to the regions' note ranges and our
  *  note lines until resume_updates() is called.
@@ -651,8 +455,8 @@ MidiStreamView::resume_updates ()
 {
 	_updates_suspended = false;
 
-	draw_note_lines ();
-	apply_note_range_to_regions ();
+	setup_note_lines ();
+	apply_note_range_to_children ();
 
 	_canvas_group->redraw ();
 }
@@ -710,3 +514,22 @@ MidiStreamView::get_regions_with_selected_data (RegionSelection& rs)
 		}
 	}
 }
+
+void
+MidiStreamView::set_note_highlight (uint8_t note)
+{
+	dynamic_cast<MidiTimeAxisView*> (&_trackview)->set_note_highlight (note);
+}
+
+uint8_t
+MidiStreamView::get_preferred_midi_channel () const
+{
+	return dynamic_cast<MidiTimeAxisView*> (&_trackview)->get_preferred_midi_channel();
+}
+
+void
+MidiStreamView::record_layer_check (std::shared_ptr<ARDOUR::Region> r, samplepos_t t)
+{
+	check_record_layers (r, t);
+}
+
