@@ -35,7 +35,7 @@
 
 #include <sigc++/bind.h>
 
-#include <gtkmm/messagedialog.h>
+#include <ytkmm/messagedialog.h>
 
 #include "pbd/convert.h"
 #include "pbd/enumwriter.h"
@@ -89,6 +89,7 @@
 #include "gui_thread.h"
 #include "route_group_menu.h"
 #include "meter_patterns.h"
+#include "rta_manager.h"
 #include "ui_config.h"
 #include "triggerbox_ui.h"
 
@@ -103,7 +104,8 @@ using namespace std;
 using namespace ArdourMeter;
 
 MixerStrip* MixerStrip::_entered_mixer_strip;
-PBD::Signal1<void,MixerStrip*> MixerStrip::CatchDeletion;
+PBD::Signal<void(MixerStrip*)> MixerStrip::CatchDeletion;
+int MixerStrip::_scrollbar_spacer_height = 0;
 
 #define PX_SCALE(px) std::max((float)px, rintf((float)px * UIConfiguration::instance().get_ui_scale()))
 
@@ -112,16 +114,15 @@ MixerStrip::MixerStrip (Mixer_UI& mx, Session* sess, bool in_mixer)
 	, RouteUI (sess)
 	, _mixer(mx)
 	, _mixer_owned (in_mixer)
-	, processor_box (sess, boost::bind (&MixerStrip::plugin_selector, this), mx.selection(), this, in_mixer)
+	, processor_box (sess, std::bind (&MixerStrip::plugin_selector, this), mx.selection(), this, in_mixer)
 	, gpm (sess, 250)
 	, panners (sess)
-	, trigger_display (-1., TriggerBox::default_triggers_per_box*16.)
 	, button_size_group (Gtk::SizeGroup::create (Gtk::SIZE_GROUP_HORIZONTAL))
 	, rec_mon_table (2, 2)
 	, solo_iso_table (1, 2)
 	, mute_solo_table (1, 2)
 	, master_volume_table (2, 2)
-	, bottom_button_table (1, 3)
+	, bottom_button_table (2, 2)
 	, input_button (true)
 	, output_button (false)
 	, monitor_section_button (0)
@@ -150,16 +151,15 @@ MixerStrip::MixerStrip (Mixer_UI& mx, Session* sess, std::shared_ptr<Route> rt,
 	, RouteUI (sess)
 	, _mixer(mx)
 	, _mixer_owned (in_mixer)
-	, processor_box (sess, boost::bind (&MixerStrip::plugin_selector, this), mx.selection(), this, in_mixer)
+	, processor_box (sess, std::bind (&MixerStrip::plugin_selector, this), mx.selection(), this, in_mixer)
 	, gpm (sess, 250)
 	, panners (sess)
-	, trigger_display (-1., 8*16.)
 	, button_size_group (Gtk::SizeGroup::create (Gtk::SIZE_GROUP_HORIZONTAL))
 	, rec_mon_table (2, 2)
 	, solo_iso_table (1, 2)
 	, mute_solo_table (1, 2)
 	, master_volume_table (1, 2)
-	, bottom_button_table (1, 3)
+	, bottom_button_table (2, 2)
 	, input_button (true)
 	, output_button (false)
 	, monitor_section_button (0)
@@ -177,9 +177,6 @@ MixerStrip::MixerStrip (Mixer_UI& mx, Session* sess, std::shared_ptr<Route> rt,
 
 	if (is_master () && !_route->comment().empty () && _session->config.get_show_master_bus_comment_on_load () && self_destruct) {
 		open_comment_editor ();
-		_comment_window->hide ();
-		_comment_window->set_position (Gtk::WIN_POS_CENTER_ON_PARENT);
-		_comment_window->present ();
 		/* show only once */
 		_session->config.set_show_master_bus_comment_on_load (false);
 	}
@@ -214,7 +211,7 @@ MixerStrip::init ()
 	input_button_box.set_spacing(2);
 	input_button_box.pack_start (input_button, true, true);
 
-	bottom_button_table.attach (gpm.meter_point_button, 2, 3, 0, 1);
+	bottom_button_table.attach (gpm.meter_point_button, 1, 2, 0, 1);
 
 	hide_button.set_events (hide_button.get_events() & ~(Gdk::ENTER_NOTIFY_MASK|Gdk::LEAVE_NOTIFY_MASK));
 
@@ -281,8 +278,9 @@ MixerStrip::init ()
 
 	bottom_button_table.set_spacings (2);
 	bottom_button_table.set_homogeneous (true);
-	bottom_button_table.attach (group_button, 1, 2, 0, 1);
 	bottom_button_table.attach (gpm.gain_automation_state_button, 0, 1, 0, 1);
+	bottom_button_table.attach (group_button, 0, 1, 1, 2);
+	bottom_button_table.attach (*rta_button,   1, 2, 1, 2);
 
 	name_button.set_name ("mixer strip button");
 	name_button.set_text_ellipsize (Pango::ELLIPSIZE_END);
@@ -291,8 +289,12 @@ MixerStrip::init ()
 	set_tooltip (&group_button, _("Mix group"));
 	group_button.set_name ("mixer strip button");
 
+	set_tooltip (rta_button, _("Realtime Analyzer\nLeft-click to toggle track analysis\nRight-click to toggle RTA window visibility"));
+	rta_button->set_name ("mixer strip button");
+
 	Gtk::Requisition mpb_size = gpm.meter_point_button.size_request();
 	group_button.set_size_request (mpb_size.width, mpb_size.height);
+	rta_button->set_size_request (mpb_size.width, mpb_size.height);
 
 	_comment_button.set_name (X_("mixer strip button"));
 	_comment_button.set_text_ellipsize (Pango::ELLIPSIZE_END);
@@ -307,7 +309,7 @@ MixerStrip::init ()
 
 	global_vpacker.set_no_show_all ();
 	global_vpacker.set_border_width (1);
-	global_vpacker.set_spacing (0);
+	global_vpacker.set_spacing (2);
 
 	width_button.set_name ("mixer strip button");
 	hide_button.set_name ("mixer strip button");
@@ -330,12 +332,10 @@ MixerStrip::init ()
 	number_label.set_tweaks (ArdourButton::OccasionalText);
 	set_tooltip (&number_label, _("Double-click to edit the route color.\nRight-click to show the route operations context menu."));
 
-	global_vpacker.set_spacing (2);
 	global_vpacker.pack_start (width_hide_box, Gtk::PACK_SHRINK);
 	global_vpacker.pack_start (name_button, Gtk::PACK_SHRINK);
 	global_vpacker.pack_start (input_button_box, Gtk::PACK_SHRINK);
 	global_vpacker.pack_start (invert_button_box, Gtk::PACK_SHRINK);
-	global_vpacker.pack_start (trigger_display, Gtk::PACK_SHRINK);
 	global_vpacker.pack_start (_tmaster_widget, Gtk::PACK_SHRINK);
 	global_vpacker.pack_start (processor_box, true, true);
 	global_vpacker.pack_start (panners, Gtk::PACK_SHRINK);
@@ -357,23 +357,10 @@ MixerStrip::init ()
 	midi_input_enable_button.signal_button_release_event().connect (sigc::mem_fun (*this, &MixerStrip::input_active_button_release), false);
 	set_tooltip (midi_input_enable_button, _("Enable/Disable MIDI input"));
 
-#ifndef MIXBUS
-	//add a spacer underneath the master bus;
-	//this fills the area that is taken up by the scrollbar on the tracks;
-	//and therefore keeps the faders "even" across the bottom
-	int scrollbar_height = 0;
-	{
-		Gtk::Window window (WINDOW_TOPLEVEL);
-		HScrollbar scrollbar;
-		window.add (scrollbar);
-		scrollbar.set_name ("MixerWindow");
-		scrollbar.ensure_style();
-		Gtk::Requisition requisition(scrollbar.size_request ());
-		scrollbar_height = requisition.height;
-		scrollbar_height += 3; // track_display_frame border/shadow
-	}
-	spacer.set_size_request (-1, scrollbar_height);
+	update_spacer ();
 	spacer.set_name ("AudioBusStripBase");
+
+#ifndef MIXBUS
 	global_vpacker.pack_end (spacer, false, false);
 #endif
 
@@ -420,24 +407,24 @@ MixerStrip::init ()
 	*/
 	_visibility.add (&input_button_box, X_("Input"), _("Input"), false);
 	_visibility.add (&invert_button_box, X_("PhaseInvert"), _("Phase Invert"), false);
-	_visibility.add (&rec_mon_table, X_("RecMon"), _("Record & Monitor"), false, boost::bind (&MixerStrip::override_rec_mon_visibility, this));
+	_visibility.add (&rec_mon_table, X_("RecMon"), _("Record & Monitor"), false, std::bind (&MixerStrip::override_rec_mon_visibility, this));
 	_visibility.add (&solo_iso_table, X_("SoloIsoLock"), _("Solo Iso / Lock"), false);
 	_visibility.add (&output_button, X_("Output"), _("Output"), false);
 	_visibility.add (&_comment_button, X_("Comments"), _("Comments"), false);
 	_visibility.add (&control_slave_ui, X_("VCA"), _("VCA Assigns"), false);
-	_visibility.add (&trigger_display, X_("TriggerGrid"), _("Trigger Grid"), false);
 	_visibility.add (&_tmaster_widget, X_("TriggerMaster"), _("Trigger Master"), false);
 
 	parameter_changed (X_("mixer-element-visibility"));
 	UIConfiguration::instance().ParameterChanged.connect (sigc::mem_fun (*this, &MixerStrip::parameter_changed));
-	 Config->ParameterChanged.connect (_config_connection, invalidator (*this), boost::bind (&MixerStrip::parameter_changed, this, _1), gui_context());
-	 _session->config.ParameterChanged.connect (_config_connection, invalidator (*this), boost::bind (&MixerStrip::parameter_changed, this, _1), gui_context());
+	UIConfiguration::instance().DPIReset.connect (sigc::mem_fun (*this, &MixerStrip::dpi_reset));
+	 Config->ParameterChanged.connect (_config_connection, invalidator (*this), std::bind (&MixerStrip::parameter_changed, this, _1), gui_context());
+	 _session->config.ParameterChanged.connect (_config_connection, invalidator (*this), std::bind (&MixerStrip::parameter_changed, this, _1), gui_context());
 
 	//watch for mouse enter/exit so we can do some stuff
 	signal_enter_notify_event().connect (sigc::mem_fun(*this, &MixerStrip::mixer_strip_enter_event ));
 	signal_leave_notify_event().connect (sigc::mem_fun(*this, &MixerStrip::mixer_strip_leave_event ));
 
-	gpm.LevelMeterButtonPress.connect_same_thread (_level_meter_connection, boost::bind (&MixerStrip::level_meter_button_press, this, _1));
+	gpm.LevelMeterButtonPress.connect_same_thread (_level_meter_connection, std::bind (&MixerStrip::level_meter_button_press, this, _1));
 }
 
 MixerStrip::~MixerStrip ()
@@ -455,17 +442,19 @@ MixerStrip::~MixerStrip ()
 void
 MixerStrip::vca_assign (std::shared_ptr<ARDOUR::VCA> vca)
 {
-	std::shared_ptr<Slavable> sl = std::dynamic_pointer_cast<Slavable> ( route() );
-	if (sl)
+	std::shared_ptr<Slavable> sl = std::dynamic_pointer_cast<Slavable> (route());
+	if (sl) {
 		sl->assign(vca);
+	}
 }
 
 void
 MixerStrip::vca_unassign (std::shared_ptr<ARDOUR::VCA> vca)
 {
-	std::shared_ptr<Slavable> sl = std::dynamic_pointer_cast<Slavable> ( route() );
-	if (sl)
+	std::shared_ptr<Slavable> sl = std::dynamic_pointer_cast<Slavable> (route());
+	if (sl) {
 		sl->unassign(vca);
+	}
 }
 
 bool
@@ -480,7 +469,7 @@ bool
 MixerStrip::mixer_strip_leave_event (GdkEventCrossing *ev)
 {
 	//if we have moved outside our strip, but not into a child view, then deselect ourselves
-	if ( !(ev->detail == GDK_NOTIFY_INFERIOR) ) {
+	if (ev->detail != GDK_NOTIFY_INFERIOR) {
 		_entered_mixer_strip= 0;
 
 		//clear keyboard focus in the gain display.  this is cheesy but fixes a longstanding "bug" where the user starts typing in the gain entry, and leaves it active, thereby prohibiting other keybindings from working
@@ -531,19 +520,20 @@ MixerStrip::set_route (std::shared_ptr<Route> rt)
 		rec_mon_table.remove (*rec_enable_button);
 	}
 	if (monitor_input_button->get_parent()) {
-		rec_mon_table.remove (*monitor_input_button);
+		monitor_input_button->get_parent()->remove (*monitor_input_button);
 	}
 	if (monitor_disk_button->get_parent()) {
-		rec_mon_table.remove (*monitor_disk_button);
+		monitor_disk_button->get_parent()->remove (*monitor_disk_button);
 	}
 	if (group_button.get_parent()) {
 		bottom_button_table.remove (group_button);
 	}
+	if (rta_button->get_parent()) {
+		rta_button->get_parent()->remove (*rta_button);
+	}
 
 	RouteUI::set_route (rt);
 
-	set_trigger_display (rt->triggerbox());
-
 	control_slave_ui.set_stripable (std::dynamic_pointer_cast<Stripable> (rt));
 
 	/* ProcessorBox needs access to _route so that it can read
@@ -579,14 +569,15 @@ MixerStrip::set_route (std::shared_ptr<Route> rt)
 		solo_button->hide ();
 		mute_button->show ();
 		mute_solo_table.attach (*mute_button, 0, 2, 0, 1);
+		bottom_button_table.attach (*rta_button,   1, 2, 1, 2);
 		if (Config->get_use_master_volume ()) {
 			master_volume_table.show ();
 		}
 
 		if (monitor_section_button == 0 && _mixer_owned) {
 			Glib::RefPtr<Action> act = ActionManager::get_action ("Mixer", "ToggleMonitorSection");
-			_session->MonitorChanged.connect (route_connections, invalidator (*this), boost::bind (&MixerStrip::monitor_changed, this), gui_context());
-			_session->MonitorBusAddedOrRemoved.connect (route_connections, invalidator (*this), boost::bind (&MixerStrip::monitor_section_added_or_removed, this), gui_context());
+			_session->MonitorChanged.connect (route_connections, invalidator (*this), std::bind (&MixerStrip::monitor_changed, this), gui_context());
+			_session->MonitorBusAddedOrRemoved.connect (route_connections, invalidator (*this), std::bind (&MixerStrip::monitor_section_added_or_removed, this), gui_context());
 
 			monitor_section_button = manage (new ArdourButton);
 			monitor_changed ();
@@ -600,7 +591,8 @@ MixerStrip::set_route (std::shared_ptr<Route> rt)
 		mute_button->show ();
 		master_volume_table.hide ();
 	} else {
-		bottom_button_table.attach (group_button, 1, 2, 0, 1);
+		bottom_button_table.attach (group_button, 0, 1, 1, 2);
+		bottom_button_table.attach (*rta_button,   1, 2, 1, 2);
 		mute_solo_table.attach (*mute_button, 0, 1, 0, 1);
 		mute_solo_table.attach (*solo_button, 1, 2, 0, 1);
 		mute_button->show ();
@@ -630,8 +622,12 @@ MixerStrip::set_route (std::shared_ptr<Route> rt)
 
 		_loudess_analysis_button->show ();
 		_volume_controller->show ();
+		if (Config->get_use_master_volume ()) {
+			master_volume_table.show ();
+		}
 #ifdef MIXBUS
 	} else if (!route()->is_master()) {
+		/* mixbus has/had a show_all, empty table still adds some pixel padding */
 		master_volume_table.hide ();
 #endif
 	}
@@ -659,7 +655,7 @@ MixerStrip::set_route (std::shared_ptr<Route> rt)
 		midi_input_status_changed ();
 
 		/* follow changes */
-		midi_track()->InputActiveChanged.connect (route_connections, invalidator (*this), boost::bind (&MixerStrip::midi_input_status_changed, this), gui_context());
+		midi_track()->InputActiveChanged.connect (route_connections, invalidator (*this), std::bind (&MixerStrip::midi_input_status_changed, this), gui_context());
 	} else {
 		if (midi_input_enable_button.get_parent()) {
 			input_button_box.remove (midi_input_enable_button);
@@ -668,7 +664,7 @@ MixerStrip::set_route (std::shared_ptr<Route> rt)
 
 	if (is_audio_track()) {
 		std::shared_ptr<AudioTrack> at = audio_track();
-		at->FreezeChange.connect (route_connections, invalidator (*this), boost::bind (&MixerStrip::map_frozen, this), gui_context());
+		at->FreezeChange.connect (route_connections, invalidator (*this), std::bind (&MixerStrip::map_frozen, this), gui_context());
 	}
 
 	if (is_track ()) {
@@ -712,25 +708,24 @@ MixerStrip::set_route (std::shared_ptr<Route> rt)
 	route_ops_menu = 0;
 
 	_route->meter_change.connect (route_connections, invalidator (*this), bind (&MixerStrip::meter_changed, this), gui_context());
-	_route->input()->changed.connect (*this, invalidator (*this), boost::bind (&MixerStrip::update_input_display, this), gui_context());
-	_route->output()->changed.connect (*this, invalidator (*this), boost::bind (&MixerStrip::update_output_display, this), gui_context());
-	_route->route_group_changed.connect (route_connections, invalidator (*this), boost::bind (&MixerStrip::route_group_changed, this), gui_context());
+	_route->input()->changed.connect (*this, invalidator (*this), std::bind (&MixerStrip::update_input_display, this), gui_context());
+	_route->output()->changed.connect (*this, invalidator (*this), std::bind (&MixerStrip::update_output_display, this), gui_context());
+	_route->route_group_changed.connect (route_connections, invalidator (*this), std::bind (&MixerStrip::route_group_changed, this), gui_context());
 
-	_route->io_changed.connect (route_connections, invalidator (*this), boost::bind (&MixerStrip::io_changed_proxy, this), gui_context ());
+	_route->io_changed.connect (route_connections, invalidator (*this), std::bind (&MixerStrip::io_changed_proxy, this), gui_context ());
 
 	if (_route->panner_shell()) {
 		update_panner_choices();
-		_route->panner_shell()->Changed.connect (route_connections, invalidator (*this), boost::bind (&MixerStrip::connect_to_pan, this), gui_context());
+		_route->panner_shell()->Changed.connect (route_connections, invalidator (*this), std::bind (&MixerStrip::connect_to_pan, this), gui_context());
 	}
 
-	_route->comment_changed.connect (route_connections, invalidator (*this), boost::bind (&MixerStrip::setup_comment_button, this), gui_context());
+	_route->comment_changed.connect (route_connections, invalidator (*this), std::bind (&MixerStrip::setup_comment_button, this), gui_context());
 
 	set_stuff_from_route ();
 
 	/* now force an update of all the various elements */
 
 	name_changed ();
-	comment_changed ();
 	route_group_changed ();
 	update_track_number_visibility ();
 
@@ -774,6 +769,7 @@ MixerStrip::set_route (std::shared_ptr<Route> rt)
 	name_button.show();
 	_comment_button.show();
 	group_button.show();
+	rta_button->show();
 	gpm.gain_automation_state_button.show();
 
 	parameter_changed ("mixer-element-visibility");
@@ -794,6 +790,38 @@ MixerStrip::set_stuff_from_route ()
 	}
 }
 
+void
+MixerStrip::update_spacer ()
+{
+	if (_scrollbar_spacer_height == 0) {
+		Gtk::Window window (WINDOW_TOPLEVEL);
+		Gtk::ScrolledWindow scroller;
+		scroller.set_policy (Gtk::POLICY_ALWAYS, Gtk::POLICY_ALWAYS);
+		scroller.set_name ("MixerWindow");
+		window.add (scroller);
+		scroller.ensure_style();
+
+		const Scrollbar* scrollbar = scroller.get_hscrollbar();
+		Gtk::Requisition requisition(scrollbar->size_request ());
+		_scrollbar_spacer_height = requisition.height;
+
+		gint scrollbar_spacing = 0;
+		gtk_widget_style_get (GTK_WIDGET (scroller.gobj()), "scrollbar-spacing", &scrollbar_spacing, NULL);
+		_scrollbar_spacer_height += scrollbar_spacing;
+
+		_scrollbar_spacer_height += 6; // track_display_frame border/shadow
+	}
+	spacer.set_size_request (-1, _scrollbar_spacer_height);
+}
+
+void
+MixerStrip::dpi_reset ()
+{
+	set_width_enum (_width, _width_owner);
+	_scrollbar_spacer_height = 0;
+	update_spacer ();
+}
+
 void
 MixerStrip::set_width_enum (Width w, void* owner)
 {
@@ -884,7 +912,7 @@ MixerStrip::connect_to_pan ()
 
 	std::shared_ptr<Pannable> p = _route->pannable ();
 
-	p->automation_state_changed.connect (panstate_connection, invalidator (*this), boost::bind (&PannerUI::pan_automation_state_changed, &panners), gui_context());
+	p->automation_state_changed.connect (panstate_connection, invalidator (*this), std::bind (&PannerUI::pan_automation_state_changed, &panners), gui_context());
 
 	/* This call reduncant, PannerUI::set_panner() connects to _panshell->Changed itself
 	 * However, that only works a panner was previously set.
@@ -1003,7 +1031,7 @@ MixerStrip::select_route_group (GdkEventButton *ev)
 		r.push_back (route ());
 		group_menu->build (r);
 
-		RouteGroup *rg = _route->route_group();
+		std::shared_ptr<RouteGroup> rg = _route->route_group();
 
 		Gtkmm2ext::anchored_menu_popup(group_menu->menu(), &group_button,
 		                               rg ? rg->name() : _("No Group"),
@@ -1016,9 +1044,9 @@ MixerStrip::select_route_group (GdkEventButton *ev)
 void
 MixerStrip::route_group_changed ()
 {
-	ENSURE_GUI_THREAD (*this, &MixerStrip::route_group_changed)
+	ENSURE_GUI_THREAD (*this, &MixerStrip::route_group_changed);
 
-	RouteGroup *rg = _route->route_group();
+	std::shared_ptr<RouteGroup> rg (_route->route_group());
 
 	if (rg) {
 		group_button.set_text (PBD::short_version (rg->name(), 5));
@@ -1039,7 +1067,8 @@ MixerStrip::route_color_changed ()
 {
 	using namespace ARDOUR_UI_UTILS;
 	name_button.modify_bg (STATE_NORMAL, color());
-	number_label.set_fixed_colors (gdk_color_to_rgba (color()), gdk_color_to_rgba (color()));
+	Gtkmm2ext::Color c (gdk_color_to_rgba (color()));
+	number_label.set_fixed_colors (c, c);
 	reset_strip_style ();
 }
 
@@ -1061,8 +1090,9 @@ MixerStrip::build_route_ops_menu ()
 	MenuList& items = route_ops_menu->items();
 
 	if (active) {
+		Gtk::Window* top = dynamic_cast<Gtk::Window*> (get_toplevel());
 
-		items.push_back (MenuElem (_("Color..."), sigc::mem_fun (*this, &RouteUI::choose_color)));
+		items.push_back (MenuElem (_("Color..."), sigc::bind (sigc::mem_fun (*this, &RouteUI::choose_color), top)));
 
 		items.push_back (MenuElem (_("Comments..."), sigc::mem_fun (*this, &RouteUI::open_comment_editor)));
 
@@ -1121,7 +1151,7 @@ MixerStrip::build_route_ops_menu ()
 	}
 
 	uint32_t plugin_insert_cnt = 0;
-	_route->foreach_processor (boost::bind (RouteUI::help_count_plugins, _1, & plugin_insert_cnt));
+	_route->foreach_processor (std::bind (RouteUI::help_count_plugins, _1, & plugin_insert_cnt));
 	if (active && plugin_insert_cnt > 0) {
 		items.push_back (MenuElem (_("Pin Connections..."), sigc::mem_fun (*this, &RouteUI::manage_pins)));
 	}
@@ -1132,6 +1162,21 @@ MixerStrip::build_route_ops_menu ()
 		denormal_menu_item->set_active (_route->denormal_protection());
 	}
 
+	if (active && !_route->presentation_info().special (false)) {
+		items.push_back (CheckMenuElem (_("RTA")));
+		Gtk::CheckMenuItem* i = dynamic_cast<Gtk::CheckMenuItem *> (&items.back());
+		bool attached = RTAManager::instance ()->attached (_route);
+		i->set_active (attached);
+		i->signal_activate().connect ([this, attached]() {
+				if (attached) {
+					RTAManager::instance ()->remove (_route);
+				} else {
+					RTAManager::instance ()->attach (_route);
+					ARDOUR_UI::instance()->show_realtime_analyzer ();
+				}
+			});
+	}
+
 	/* Disk I/O */
 
 	if (active && is_track()) {
@@ -1163,7 +1208,7 @@ MixerStrip::build_route_ops_menu ()
 	 * sane thing for users anyway.
 	 */
 	StripableTimeAxisView* stav = PublicEditor::instance().get_stripable_time_axis_by_id (_route->id());
-	if (active && stav) {
+	if (stav) {
 		Selection& selection (PublicEditor::instance().get_selection());
 		if (!selection.selected (stav)) {
 			selection.set (stav);
@@ -1175,13 +1220,16 @@ MixerStrip::build_route_ops_menu ()
 			return;
 		}
 #endif
+		if (_route->is_singleton ()) {
+			return;
+		}
 
-		if (!_route->is_singleton ()) {
+		if (active) {
 			items.push_back (SeparatorElem());
 			items.push_back (MenuElem (_("Duplicate..."), sigc::mem_fun (*this, &RouteUI::duplicate_selected_routes)));
-			items.push_back (SeparatorElem());
-			items.push_back (MenuElem (_("Remove"), sigc::mem_fun(PublicEditor::instance(), &PublicEditor::remove_tracks)));
 		}
+		items.push_back (SeparatorElem());
+		items.push_back (MenuElem (_("Remove"), sigc::mem_fun(PublicEditor::instance(), &PublicEditor::remove_tracks)));
 	}
 }
 
@@ -1222,7 +1270,7 @@ gboolean
 MixerStrip::number_button_button_press (GdkEventButton* ev)
 {
 	if (ev->type == GDK_2BUTTON_PRESS) {
-		choose_color ();
+		choose_color (dynamic_cast<Gtk::Window*> (get_toplevel()));
 		return true;
 	}
 
@@ -1644,7 +1692,7 @@ MixerStrip::show_send (std::shared_ptr<Send> send)
 
 	send->meter()->set_meter_type (_route->meter_type ());
 	send->set_metering (true);
-	_current_delivery->DropReferences.connect (send_gone_connection, invalidator (*this), boost::bind (&MixerStrip::revert_to_default_display, this), gui_context());
+	_current_delivery->DropReferences.connect (send_gone_connection, invalidator (*this), std::bind (&MixerStrip::revert_to_default_display, this), gui_context());
 
 	gain_meter().set_controls (_route, send->meter(), send->amp(), send->gain_control());
 	gain_meter().setup_meters ();
@@ -1683,8 +1731,6 @@ MixerStrip::revert_to_default_display ()
 	}
 
 	reset_strip_style ();
-
-	set_trigger_display (_route->triggerbox());
 }
 
 void
@@ -1846,24 +1892,24 @@ MixerStrip::parameter_changed (string p)
  *
  *  @return optional value that is present if visibility state should be overridden.
  */
-boost::optional<bool>
+std::optional<bool>
 MixerStrip::override_solo_visibility () const
 {
 	if (is_master ()) {
-		return boost::optional<bool> (false);
+		return std::optional<bool> (false);
 	}
 
-	return boost::optional<bool> ();
+	return std::optional<bool> ();
 }
 
-boost::optional<bool>
+std::optional<bool>
 MixerStrip::override_rec_mon_visibility () const
 {
 	if (is_master ()) {
-		return boost::optional<bool> (false);
+		return std::optional<bool> (false);
 	}
 
-	return boost::optional<bool> ();
+	return std::optional<bool> ();
 }
 
 
@@ -1904,6 +1950,7 @@ MixerStrip::update_sensitivity ()
 
 	input_button.set_sensitive (en && !send);
 	group_button.set_sensitive (en && !send);
+	rta_button->set_sensitive (en && !send);
 	gpm.meter_point_button.set_sensitive (en && !send);
 	mute_button->set_sensitive (en && !send);
 	solo_button->set_sensitive (en && !send);
@@ -2140,9 +2187,3 @@ MixerStrip::hide_master_spacer (bool yn)
 	}
 }
 
-void
-MixerStrip::set_trigger_display (std::shared_ptr<TriggerBox> tb)
-{
-	_tmaster->set_triggerbox (tb);
-	trigger_display.set_triggerbox (tb.get());
-}
