@@ -28,13 +28,15 @@
 #include "canvas/text.h"
 
 #include "note_base.h"
-#include "public_editor.h"
+#include "editing_context.h"
+#include "editing_syms.inc.h"
 #include "keyboard.h"
-#include "midi_region_view.h"
+#include "midi_view.h"
+#include "time_axis_view.h"
 
 /* clang-format off */
 // Include last, when GRIDTYPE has been defined by editing.h via midi_region_view.h
-#include "editing_syms.h"
+#include "editing_syms.inc.h"
 /* clang-format on */
 
 using namespace std;
@@ -65,8 +67,8 @@ NoteBase::set_colors ()
 	color_modifier = UIConfiguration::instance().modifier ("midi note");
 }
 
-NoteBase::NoteBase(MidiRegionView& region, bool with_events, const std::shared_ptr<NoteType> note)
-	: _region(region)
+NoteBase::NoteBase(MidiView& v, bool with_events, const std::shared_ptr<NoteType> note)
+	: _view (v)
 	, _item (0)
 	, _text(0)
 	, _state(None)
@@ -85,8 +87,7 @@ NoteBase::NoteBase(MidiRegionView& region, bool with_events, const std::shared_p
 
 NoteBase::~NoteBase()
 {
-	_region.note_deleted (this);
-
+	_view.note_deleted (this);
 	delete _text;
 }
 
@@ -156,13 +157,6 @@ NoteBase::on_channel_selection_change(uint16_t selection)
 	_item->show();
 }
 
-void
-NoteBase::on_channel_change(uint8_t channel)
-{
-	_region.note_selected(this, true);
-	_region.change_channel(channel);
-}
-
 void
 NoteBase::set_selected(bool selected)
 {
@@ -187,7 +181,7 @@ NoteBase::set_selected(bool selected)
 uint32_t
 NoteBase::base_color ()
 {
-	return base_color (_note->velocity(), _region.color_mode(), _region.midi_stream_view()->get_region_color(), _note->channel(), selected());
+	return base_color (_note->velocity(), _view.midi_context().color_mode(), _view.midi_context().region_color(), _note->channel(), selected());
 }
 
 uint32_t
@@ -202,21 +196,18 @@ NoteBase::base_color (int velocity, ARDOUR::ColorMode color_mode, Gtkmm2ext::Col
 	case TrackColor:
 	{
 		const uint32_t region_color = default_color;
-		return UINT_INTERPOLATE (UINT_RGBA_CHANGE_A (region_color, opacity), _selected_col,
-					 0.5);
+		return UINT_INTERPOLATE (UINT_RGBA_CHANGE_A (region_color, opacity), _selected_col, 0.5);
 	}
 
 	case ChannelColors:
-		return UINT_INTERPOLATE (UINT_RGBA_CHANGE_A (NoteBase::midi_channel_colors[channel], opacity),
-		                          _selected_col, 0.5);
+		return UINT_INTERPOLATE (UINT_RGBA_CHANGE_A (NoteBase::midi_channel_colors[channel], opacity), _selected_col, 0.5);
 
 	default:
 		if (UIConfiguration::instance().get_use_note_color_for_velocity()) {
 			return meter_style_fill_color(velocity, selected);
 		} else {
 			const uint32_t region_color = default_color;
-			return UINT_INTERPOLATE (UINT_RGBA_CHANGE_A (region_color, opacity), _selected_col,
-			                         0.5);
+			return UINT_INTERPOLATE (UINT_RGBA_CHANGE_A (region_color, opacity), _selected_col, 0.5);
 		}
 	};
 
@@ -251,7 +242,7 @@ NoteBase::set_mouse_fractions (GdkEvent* ev)
 		return;
 	}
 
-	boost::optional<ArdourCanvas::Rect> bbox = _item->bounding_box ();
+	std::optional<ArdourCanvas::Rect> bbox = _item->bounding_box ();
 	assert (bbox);
 
 	_item->canvas_to_item (ix, iy);
@@ -259,16 +250,16 @@ NoteBase::set_mouse_fractions (GdkEvent* ev)
 	/* hmm, something wrong here. w2i should give item-local coordinates
 	   but it doesn't. for now, finesse this.
 	*/
-	ix = ix - bbox.get().x0;
-	iy = iy - bbox.get().y0;
+	ix = ix - bbox.value().x0;
+	iy = iy - bbox.value().y0;
 
 	/* fraction of width/height */
 	double xf;
 	double yf;
 	bool notify = false;
 
-	xf = ix / bbox.get().width ();
-	yf = iy / bbox.get().height ();
+	xf = ix / bbox.value().width ();
+	yf = iy / bbox.value().height ();
 
 	if (xf != _mouse_x_fraction || yf != _mouse_y_fraction) {
 		notify = true;
@@ -279,12 +270,12 @@ NoteBase::set_mouse_fractions (GdkEvent* ev)
 
 	if (notify) {
 		if (big_enough_to_trim()) {
-			_region.note_mouse_position (_mouse_x_fraction, _mouse_y_fraction, set_cursor);
+			_view.note_mouse_position (_mouse_x_fraction, _mouse_y_fraction, set_cursor);
 		} else {
 			/* pretend the mouse is in the middle, because this is not big enough
 			   to trim right now.
 			*/
-			_region.note_mouse_position (0.5, 0.5, set_cursor);
+			_view.note_mouse_position (0.5, 0.5, set_cursor);
 		}
 	}
 }
@@ -292,28 +283,30 @@ NoteBase::set_mouse_fractions (GdkEvent* ev)
 bool
 NoteBase::event_handler (GdkEvent* ev)
 {
-	PublicEditor& editor = _region.get_time_axis_view().editor();
+	EditingContext& editor = _view.editing_context();
 	if (!editor.internal_editing()) {
 		return false;
 	}
 
-	if (_region.get_time_axis_view ().layer_display () == Stacked) {
-		/* only allow edting notes in the topmost layer */
-		if (_region.region()->layer() != _region.region()->playlist()->top_layer ()) {
-			/* this stll allows the draw tool to work, and edit cursor is updated */
-			return false;
+	RegionView* rv;
+	if ((rv = dynamic_cast<RegionView*> (&_view))) {
+		if (rv->get_time_axis_view ().layer_display () == Stacked) {
+			/* only allow edting notes in the topmost layer */
+			if (rv->region()->layer() != rv->region()->playlist()->top_layer ()) {
+				/* this stll allows the draw tool to work, and edit cursor is updated */
+				return false;
+			}
 		}
 	}
 
 	switch (ev->type) {
 	case GDK_ENTER_NOTIFY:
-		_region.note_entered (this);
+		_view.note_entered (this);
 		set_mouse_fractions (ev);
 		break;
 
 	case GDK_LEAVE_NOTIFY:
-		set_mouse_fractions (ev);
-		_region.note_left (this);
+		_view.note_left (this);
 		break;
 
 	case GDK_MOTION_NOTIFY:
