@@ -22,14 +22,14 @@
 #ifndef _gtk_ardour_region_list_base_h_
 #define _gtk_ardour_region_list_base_h_
 
-#include <boost/unordered_map.hpp>
+#include <unordered_map>
 
-#include <gtkmm/celleditable.h>
-#include <gtkmm/frame.h>
-#include <gtkmm/scrolledwindow.h>
-#include <gtkmm/treemodel.h>
-#include <gtkmm/treerowreference.h>
-#include <gtkmm/treestore.h>
+#include <ytkmm/celleditable.h>
+#include <ytkmm/frame.h>
+#include <ytkmm/scrolledwindow.h>
+#include <ytkmm/treemodel.h>
+#include <ytkmm/treerowreference.h>
+#include <ytkmm/treestore.h>
 
 #include "gtkmm2ext/utils.h"
 
@@ -92,14 +92,15 @@ protected:
 		{
 			add (name);     // 0
 			add (channels); // 1
-			add (tags);     // 2
-			add (start);    // 3
-			add (length);   // 3
-			add (end);      // 5
-			add (sync);     // 6
-			add (fadein);   // 7
-			add (fadeout);  // 8
-			add (locked);   // 9
+			add (regionfx); // 2
+			add (tags);     // 3
+			add (start);    // 4
+			add (length);   // 5
+			add (end);      // 6
+			add (sync);     // 7
+			add (fadein);   // 8
+			add (fadeout);  // 9
+			add (locked);   // 10
 			add (muted);    // 11
 			add (opaque);   // 12
 			add (path);     // 13
@@ -111,11 +112,12 @@ protected:
 			add (take_id);     // 18
 			add (natural_pos); // 19
 			add (natural_s);   // 20
-			add (captd_xruns);
+			add (captd_xruns); // 21
 		}
 
 		Gtk::TreeModelColumn<std::string>                       name;
 		Gtk::TreeModelColumn<int>                               channels;
+		Gtk::TreeModelColumn<size_t>                            regionfx;
 		Gtk::TreeModelColumn<std::string>                       tags;
 		Gtk::TreeModelColumn<Temporal::timepos_t>               position;
 		Gtk::TreeModelColumn<std::string>                       start;
@@ -128,7 +130,7 @@ protected:
 		Gtk::TreeModelColumn<bool>                              muted;
 		Gtk::TreeModelColumn<bool>                              opaque;
 		Gtk::TreeModelColumn<std::string>                       path;
-		Gtk::TreeModelColumn<std::shared_ptr<ARDOUR::Region>> region;
+		Gtk::TreeModelColumn<std::shared_ptr<ARDOUR::Region>>   region;
 		Gtk::TreeModelColumn<Gdk::Color>                        color_;
 		Gtk::TreeModelColumn<std::string>                       captd_for;
 		Gtk::TreeModelColumn<std::string>                       take_id;
@@ -209,6 +211,7 @@ protected:
 	void populate_row_length (std::shared_ptr<ARDOUR::Region> region, Gtk::TreeModel::Row const& row);
 	void populate_row_name (std::shared_ptr<ARDOUR::Region> region, Gtk::TreeModel::Row const& row);
 	void populate_row_source (std::shared_ptr<ARDOUR::Region> region, Gtk::TreeModel::Row const& row);
+	void populate_row_regionfx (std::shared_ptr<ARDOUR::Region> region, Gtk::TreeModel::Row const& row);
 
 	void clock_format_changed ();
 
@@ -236,7 +239,7 @@ protected:
 
 	bool _no_redisplay;
 
-	typedef boost::unordered_map<std::shared_ptr<ARDOUR::Region>, Gtk::TreeModel::iterator> RegionRowMap;
+	typedef std::unordered_map<std::shared_ptr<ARDOUR::Region>, Gtk::TreeModel::iterator> RegionRowMap;
 
 	RegionRowMap region_row_map;
 
