@@ -21,8 +21,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef __gtk_ardour_region_view_h__
-#define __gtk_ardour_region_view_h__
+#pragma once
 
 #ifdef interface
 #undef interface
@@ -36,12 +35,12 @@
 #include "canvas/fwd.h"
 
 #include "time_axis_view_item.h"
-#include "automation_line.h"
+#include "editor_automation_line.h"
 #include "enums.h"
 #include "marker.h"
 
 class TimeAxisView;
-class RegionEditor;
+class ArdourWindow;
 class GhostRegion;
 class AutomationTimeAxisView;
 class AutomationRegionView;
@@ -89,7 +88,7 @@ public:
 	bool set_position(Temporal::timepos_t const & pos, void* src, double* delta = 0);
 
 	virtual void show_region_editor ();
-	void hide_region_editor ();
+	virtual void hide_region_editor ();
 
 	virtual void region_changed (const PBD::PropertyChange&);
 
@@ -101,12 +100,13 @@ public:
 	virtual void exited () {}
 
 	bool display_enabled() const;
-	void redisplay (bool view_only = true) {
-		_redisplay (view_only);
+	virtual void redisplay (bool) = 0;
+	void redisplay () {
+		redisplay (true);
 	}
 
 	virtual void tempo_map_changed () {
-		_redisplay (true);
+		redisplay (true);
 	}
 
 	struct DisplaySuspender {
@@ -127,7 +127,7 @@ public:
 
 	virtual void update_coverage_frame (LayerDisplay);
 
-	static PBD::Signal1<void,RegionView*> RegionViewGoingAway;
+	static PBD::Signal<void(RegionView*)> RegionViewGoingAway;
 
 	/** Called when a front trim is about to begin */
 	virtual void trim_front_starting () {}
@@ -202,7 +202,7 @@ protected:
 	ArdourCanvas::Polygon* sync_mark; ///< polygon for sync position
 	ArdourCanvas::Line* sync_line; ///< polygon for sync position
 
-	RegionEditor* editor;
+	ArdourWindow* _editor;
 
 	std::vector<ControlPoint *> control_points;
 	double current_visible_sync_position;
@@ -251,7 +251,6 @@ private:
 	typedef std::list<ViewCueMarker*> ViewCueMarkers;
 	ViewCueMarkers _cue_markers;
 	bool _cue_markers_visible;
-	virtual void _redisplay (bool) = 0;
 
   private:
 	friend struct DisplaySuspender;
@@ -260,4 +259,3 @@ private:
 
 };
 
-#endif /* __gtk_ardour_region_view_h__ */
