@@ -17,9 +17,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef __gtk_ardour_rgb_macros_h__
-#define __gtk_ardour_rgb_macros_h__
+#pragma once
 
 #include "gtkmm2ext/rgb_macros.h"
 
-#endif /* __gtk_ardour_rgb_macros_h__ */
