@@ -37,9 +37,9 @@
 
 #include <sigc++/bind.h>
 
-#include <gtkmm/menu.h>
-#include <gtkmm/menuitem.h>
-#include <gtkmm/stock.h>
+#include <ytkmm/menu.h>
+#include <ytkmm/menuitem.h>
+#include <ytkmm/stock.h>
 
 #include "pbd/error.h"
 #include "pbd/whitespace.h"
@@ -127,11 +127,11 @@ RouteTimeAxisView::RouteTimeAxisView (PublicEditor& ed, Session* sess, ArdourCan
 	number_label.set_alignment(.5, .5);
 	number_label.set_fallthrough_to_parent (true);
 
-	sess->config.ParameterChanged.connect (*this, invalidator (*this), boost::bind (&RouteTimeAxisView::parameter_changed, this, _1), gui_context());
+	sess->config.ParameterChanged.connect (*this, invalidator (*this), std::bind (&RouteTimeAxisView::parameter_changed, this, _1), gui_context());
 	UIConfiguration::instance().ParameterChanged.connect (sigc::mem_fun (*this, &RouteTimeAxisView::parameter_changed));
 
 	Controllable::ControlTouched.connect (
-			ctrl_touched_connection, invalidator (*this), boost::bind (&RouteTimeAxisView::show_touched_automation, this, _1), gui_context ()
+			ctrl_touched_connection, invalidator (*this), std::bind (&RouteTimeAxisView::show_touched_automation, this, _1), gui_context ()
     );
 
 	parameter_changed ("editor-stereo-only-meters");
@@ -225,9 +225,9 @@ RouteTimeAxisView::set_route (std::shared_ptr<Route> rt)
 	}
 
 	_route->meter_change.connect (*this, invalidator (*this), bind (&RouteTimeAxisView::meter_changed, this), gui_context());
-	_route->input()->changed.connect (*this, invalidator (*this), boost::bind (&RouteTimeAxisView::io_changed, this, _1, _2), gui_context());
-	_route->output()->changed.connect (*this, invalidator (*this), boost::bind (&RouteTimeAxisView::io_changed, this, _1, _2), gui_context());
-	_route->track_number_changed.connect (*this, invalidator (*this), boost::bind (&RouteTimeAxisView::label_view, this), gui_context());
+	_route->input()->changed.connect (*this, invalidator (*this), std::bind (&RouteTimeAxisView::io_changed, this, _1, _2), gui_context());
+	_route->output()->changed.connect (*this, invalidator (*this), std::bind (&RouteTimeAxisView::io_changed, this, _1, _2), gui_context());
+	_route->track_number_changed.connect (*this, invalidator (*this), std::bind (&RouteTimeAxisView::label_view, this), gui_context());
 
 	if (ARDOUR::Profile->get_mixbus()) {
 		controls_table.attach (*mute_button, 1, 2, 0, 1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
@@ -300,7 +300,7 @@ RouteTimeAxisView::set_route (std::shared_ptr<Route> rt)
 
 	_y_position = -1;
 
-	_route->processors_changed.connect (*this, invalidator (*this), boost::bind (&RouteTimeAxisView::processors_changed, this, _1), gui_context());
+	_route->processors_changed.connect (*this, invalidator (*this), std::bind (&RouteTimeAxisView::processors_changed, this, _1), gui_context());
 
 	if (is_track()) {
 
@@ -309,10 +309,10 @@ RouteTimeAxisView::set_route (std::shared_ptr<Route> rt)
 			set_layer_display (layer_display);
 		}
 
-		track()->FreezeChange.connect (*this, invalidator (*this), boost::bind (&RouteTimeAxisView::map_frozen, this), gui_context());
-		track()->SpeedChanged.connect (*this, invalidator (*this), boost::bind (&RouteTimeAxisView::speed_changed, this), gui_context());
+		track()->FreezeChange.connect (*this, invalidator (*this), std::bind (&RouteTimeAxisView::map_frozen, this), gui_context());
+		track()->SpeedChanged.connect (*this, invalidator (*this), std::bind (&RouteTimeAxisView::speed_changed, this), gui_context());
 
-		track()->ChanCountChanged.connect (*this, invalidator (*this), boost::bind (&RouteTimeAxisView::chan_count_changed, this), gui_context());
+		track()->ChanCountChanged.connect (*this, invalidator (*this), std::bind (&RouteTimeAxisView::chan_count_changed, this), gui_context());
 
 		/* pick up the correct freeze state */
 		map_frozen ();
@@ -342,9 +342,6 @@ RouteTimeAxisView::~RouteTimeAxisView ()
 
 	delete automation_action_menu;
 
-	delete _view;
-	_view = 0;
-
 	_automation_tracks.clear ();
 
 	delete route_group_menu;
@@ -630,6 +627,10 @@ RouteTimeAxisView::build_display_menu ()
 		detach_menu (*automation_action_menu);
 	}
 
+	if (route_group_menu) {
+		route_group_menu->detach ();
+	}
+
 	TimeAxisView::build_display_menu ();
 
 	bool active = _route->active ();
@@ -638,7 +639,7 @@ RouteTimeAxisView::build_display_menu ()
 
 	/* now fill it with our stuff */
 	if (active) {
-		items.push_back (MenuElem (_("Color..."), sigc::mem_fun (*this, &RouteUI::choose_color)));
+		items.push_back (MenuElem (_("Color..."), sigc::bind (sigc::mem_fun (*this, &RouteUI::choose_color), PublicEditor::instance ().current_toplevel())));
 
 		items.push_back (MenuElem (_("Comments..."), sigc::mem_fun (*this, &RouteUI::open_comment_editor)));
 
@@ -815,7 +816,6 @@ RouteTimeAxisView::build_display_menu ()
 		}
 
 		if (!_route->is_singleton ()) {
-			route_group_menu->detach ();
 			route_group_menu->build (r);
 			items.push_back (MenuElem (_("Group"), *route_group_menu->menu ()));
 		}
@@ -895,13 +895,16 @@ RouteTimeAxisView::build_display_menu ()
 	items.push_back (SeparatorElem());
 	items.push_back (MenuElem (_("Hide"), sigc::bind (sigc::mem_fun(_editor, &PublicEditor::hide_track_in_display), this, !_editor.get_selection().tracks.empty ())));
 
-	if (active && _route && !_route->is_singleton ()) {
-		items.push_back (SeparatorElem());
-		items.push_back (MenuElem (_("Duplicate..."), boost::bind (&ARDOUR_UI::start_duplicate_routes, ARDOUR_UI::instance())));
-
-		items.push_back (SeparatorElem());
-		items.push_back (MenuElem (_("Remove"), sigc::mem_fun(_editor, &PublicEditor::remove_tracks)));
+	if (!_route || _route->is_singleton ()) {
+		return;
 	}
+
+	if (active) {
+		items.push_back (SeparatorElem());
+		items.push_back (MenuElem (_("Duplicate..."), std::bind (&ARDOUR_UI::start_duplicate_routes, ARDOUR_UI::instance())));
+	}
+	items.push_back (SeparatorElem());
+	items.push_back (MenuElem (_("Remove"), sigc::mem_fun(_editor, &PublicEditor::remove_tracks)));
 }
 
 void
@@ -1105,7 +1108,7 @@ RouteTimeAxisView::set_align_choice (RadioMenuItem* mitem, AlignChoice choice, b
 	}
 
 	if (apply_to_selection) {
-		_editor.get_selection().tracks.foreach_route_time_axis (boost::bind (&RouteTimeAxisView::set_align_choice, _1, mitem, choice, false));
+		_editor.get_selection().tracks.foreach_route_time_axis (std::bind (&RouteTimeAxisView::set_align_choice, _1, mitem, choice, false));
 	} else {
 		if (track ()) {
 			track()->set_align_choice (choice);
@@ -1116,7 +1119,7 @@ RouteTimeAxisView::set_align_choice (RadioMenuItem* mitem, AlignChoice choice, b
 void
 RouteTimeAxisView::speed_changed ()
 {
-	Gtkmm2ext::UI::instance()->call_slot (invalidator (*this), boost::bind (&RouteTimeAxisView::reset_samples_per_pixel, this));
+	Gtkmm2ext::UI::instance()->call_slot (invalidator (*this), std::bind (&RouteTimeAxisView::reset_samples_per_pixel, this));
 }
 
 void
@@ -1206,7 +1209,7 @@ RouteTimeAxisView::set_selected_regionviews (RegionSelection& regions)
  * @param results List to add things to.
  */
 void
-RouteTimeAxisView::get_selectables (timepos_t const & start, timepos_t const & end, double top, double bot, list<Selectable*>& results, bool within)
+RouteTimeAxisView::_get_selectables (timepos_t const & start, timepos_t const & end, double top, double bot, list<Selectable*>& results, bool within)
 {
 	if ((_view && ((top < 0.0 && bot < 0.0))) || touched (top, bot)) {
 		_view->get_selectables (start, end, top, bot, results, within);
@@ -1239,7 +1242,7 @@ RouteTimeAxisView::get_regionviews_at_or_after (timepos_t const & pos, RegionSel
 	_view->get_regionviews_at_or_after (pos, regions);
 }
 
-RouteGroup*
+std::shared_ptr<RouteGroup>
 RouteTimeAxisView::route_group () const
 {
 	return _route->route_group();
@@ -1431,7 +1434,7 @@ RouteTimeAxisView::paste (timepos_t const & pos, const Selection& selection, Pas
 void
 RouteTimeAxisView::update_playlist_tip ()
 {
-	RouteGroup* rg = route_group ();
+	std::shared_ptr<RouteGroup> rg = route_group ();
 	if (rg && rg->is_active() && rg->enabled_property (ARDOUR::Properties::group_select.property_id)) {
 		string group_string = "." + rg->name() + ".";
 
@@ -1596,7 +1599,7 @@ RouteTimeAxisView::ensure_pan_views (bool show)
 		}
 	}
 
-	/* remove ATAV of no longer relevant pan ctrls (e.g. witdh, height); */
+	/* remove ATAV of no longer relevant pan ctrls (e.g. width, height); */
 	bool removed_one;
 	do {
 		removed_one = false;
@@ -1621,7 +1624,7 @@ void
 RouteTimeAxisView::show_all_automation (bool apply_to_selection)
 {
 	if (apply_to_selection) {
-		_editor.get_selection().tracks.foreach_route_time_axis (boost::bind (&RouteTimeAxisView::show_all_automation, _1, false));
+		_editor.get_selection().tracks.foreach_route_time_axis (std::bind (&RouteTimeAxisView::show_all_automation, _1, false));
 	} else {
 		no_redraw = true;
 
@@ -1651,7 +1654,7 @@ void
 RouteTimeAxisView::show_existing_automation (bool apply_to_selection)
 {
 	if (apply_to_selection) {
-		_editor.get_selection().tracks.foreach_route_time_axis (boost::bind (&RouteTimeAxisView::show_existing_automation, _1, false));
+		_editor.get_selection().tracks.foreach_route_time_axis (std::bind (&RouteTimeAxisView::show_existing_automation, _1, false));
 	} else {
 		no_redraw = true;
 
@@ -1772,7 +1775,7 @@ void
 RouteTimeAxisView::hide_all_automation (bool apply_to_selection)
 {
 	if (apply_to_selection) {
-		_editor.get_selection().tracks.foreach_route_time_axis (boost::bind (&RouteTimeAxisView::hide_all_automation, _1, false));
+		_editor.get_selection().tracks.foreach_route_time_axis (std::bind (&RouteTimeAxisView::hide_all_automation, _1, false));
 	} else {
 		no_redraw = true;
 		StripableTimeAxisView::hide_all_automation ();
@@ -1971,7 +1974,7 @@ RouteTimeAxisView::add_existing_processor_automation_curves (std::weak_ptr<Proce
 	for (set<Evoral::Parameter>::iterator i = existing.begin(); i != existing.end(); ++i) {
 
 		Evoral::Parameter param (*i);
-		std::shared_ptr<AutomationLine> al;
+		std::shared_ptr<EditorAutomationLine> al;
 
 		std::shared_ptr<AutomationControl> control = std::dynamic_pointer_cast<AutomationControl>(processor->control(*i, false));
 		if (!control || control->flags () & Controllable::HiddenControl) {
@@ -2182,10 +2185,10 @@ RouteTimeAxisView::processors_changed (RouteProcessorChange c)
 		if (pi && pi->plugin ()->has_midnam ()) {
 			midnam_connection.drop_connections ();
 			the_instrument->DropReferences.connect (midnam_connection, invalidator (*this),
-					boost::bind (&RouteTimeAxisView::drop_instrument_ref, this),
+					std::bind (&RouteTimeAxisView::drop_instrument_ref, this),
 					gui_context());
 			pi->plugin()->UpdateMidnam.connect (midnam_connection, invalidator (*this),
-					boost::bind (&RouteTimeAxisView::reread_midnam, this),
+					std::bind (&RouteTimeAxisView::reread_midnam, this),
 					gui_context());
 
 			reread_midnam ();
@@ -2230,7 +2233,7 @@ RouteTimeAxisView::processors_changed (RouteProcessorChange c)
 	}
 }
 
-std::shared_ptr<AutomationLine>
+std::shared_ptr<EditorAutomationLine>
 RouteTimeAxisView::find_processor_automation_curve (std::shared_ptr<Processor> processor, Evoral::Parameter what)
 {
 	ProcessorAutomationNode* pan;
@@ -2241,7 +2244,7 @@ RouteTimeAxisView::find_processor_automation_curve (std::shared_ptr<Processor> p
 		}
 	}
 
-	return std::shared_ptr<AutomationLine>();
+	return std::shared_ptr<EditorAutomationLine>();
 }
 
 void
@@ -2618,10 +2621,9 @@ RouteTimeAxisView::automation_child_by_alist_id (PBD::ID alist_id)
 			if (!atv) {
 				continue;
 			}
-			list<std::shared_ptr<AutomationLine> > lines = atv->lines();
-			for (list<std::shared_ptr<AutomationLine> >::const_iterator li = lines.begin(); li != lines.end(); ++li) {
-				if ((*li)->the_list()->id() == alist_id) {
-					return *li;
+			for (auto & line : atv->lines()) {
+				if (line->the_list()->id() == alist_id) {
+					return line;
 				}
 			}
 		}
