@@ -48,7 +48,7 @@ StepEditor::StepEditor (PublicEditor& e, std::shared_ptr<MidiTrack> t, MidiTimeA
 	step_edit_region_view = 0;
 
 	_track->PlaylistChanged.connect (*this, invalidator (*this),
-	                                 boost::bind (&StepEditor::playlist_changed, this),
+	                                 std::bind (&StepEditor::playlist_changed, this),
 	                                 gui_context());
 	playlist_changed ();
 }
@@ -66,8 +66,9 @@ StepEditor::start_step_editing ()
 	_step_edit_chord_duration = Temporal::Beats();
 	step_edit_region.reset ();
 	step_edit_region_view = 0;
-	last_added_pitch = -1;
-	last_added_end = Temporal::Beats();
+	_last_added_beat = Temporal::Beats();
+	_tracker.reset ();
+	_chord_tracker.reset ();
 
 	resync_step_edit_position ();
 	prepare_step_edit_region ();
@@ -203,9 +204,16 @@ StepEditor::check_step_edit ()
 			break;
 		}
 
+		_tracker.track (buf);
+
 		if ((buf[0] & 0xf0) == MIDI_CMD_NOTE_ON && size == 3) {
 			step_add_note (buf[0] & 0xf, buf[1], buf[2], Temporal::Beats());
 		}
+
+		/* note-off w/chord .. move to next beat */
+		if ((buf[0] & 0xf0) == MIDI_CMD_NOTE_OFF && size == 3 && _tracker.empty ()) {
+			step_to_next_chord ();
+		}
 	}
 	delete [] buf;
 }
@@ -270,13 +278,6 @@ StepEditor::step_add_note (uint8_t channel, uint8_t pitch, uint8_t velocity, Tem
 
 	if (beat_duration == 0.0) {
 		beat_duration = StepEntry::instance().note_length();
-	} else if (beat_duration == 0.0) {
-		bool success;
-		beat_duration = _editor.get_draw_length_as_beats (success, step_edit_insert_position);
-
-		if (!success) {
-			return -1;
-		}
 	}
 
 	MidiStreamView* msv = _mtv.midi_view();
@@ -284,8 +285,8 @@ StepEditor::step_add_note (uint8_t channel, uint8_t pitch, uint8_t velocity, Tem
 	/* make sure its visible on the vertical axis */
 
 	if (pitch < msv->lowest_note() || pitch > msv->highest_note()) {
-		msv->update_note_range (pitch);
-		msv->set_note_range (MidiStreamView::ContentsRange);
+		msv->maybe_extend_note_range (pitch);
+		msv->set_note_visibility_range_style (MidiStreamView::ContentsRange);
 	}
 
 	/* make sure its visible on the horizontal axis */
@@ -299,20 +300,18 @@ StepEditor::step_add_note (uint8_t channel, uint8_t pitch, uint8_t velocity, Tem
 	Temporal::Beats at = step_edit_beat_pos;
 	Temporal::Beats len = beat_duration;
 
-	if ((last_added_pitch >= 0) && (pitch == last_added_pitch) && (last_added_end == step_edit_beat_pos)) {
-
-		/* avoid any apparent note overlap - move the start of this note
-		   up by 1 tick from where the last note ended
-		*/
-
-		at  += Temporal::Beats::ticks(1);
-		len -= Temporal::Beats::ticks(1);
+	if (_last_added_beat != step_edit_beat_pos) {
+		_chord_tracker.reset ();
+		_last_added_beat = step_edit_beat_pos;
 	}
 
-	step_edit_region_view->step_add_note (channel, pitch, velocity, at, len);
+	if (!_step_edit_within_chord || !_chord_tracker.active (pitch, channel)) {
+		step_edit_region_view->step_add_note (channel, pitch, velocity, at, len);
+	}
 
-	last_added_pitch = pitch;
-	last_added_end = at+len;
+	if (_step_edit_within_chord) {
+		_chord_tracker.add (pitch, channel);
+	}
 
 	if (_step_edit_triplet_countdown > 0) {
 		_step_edit_triplet_countdown--;
@@ -326,7 +325,6 @@ StepEditor::step_add_note (uint8_t channel, uint8_t pitch, uint8_t velocity, Tem
 		step_edit_beat_pos += beat_duration;
 		step_edit_region_view->move_step_edit_cursor (step_edit_beat_pos);
 	} else {
-		step_edit_beat_pos += Temporal::Beats::ticks(1); // tiny, but no longer overlapping
 		_step_edit_chord_duration = max (_step_edit_chord_duration, beat_duration);
 	}
 
@@ -335,6 +333,17 @@ StepEditor::step_add_note (uint8_t channel, uint8_t pitch, uint8_t velocity, Tem
 	return 0;
 }
 
+void
+StepEditor::step_to_next_chord ()
+{
+	if (!step_edit_region_view || !_step_edit_within_chord) {
+		return;
+	}
+	step_edit_beat_pos += _step_edit_chord_duration;
+	step_edit_region_view->move_step_edit_cursor (step_edit_beat_pos);
+	_chord_tracker.reset ();
+}
+
 void
 StepEditor::set_step_edit_cursor_width (Temporal::Beats beats)
 {
@@ -370,14 +379,13 @@ void
 StepEditor::step_edit_toggle_chord ()
 {
 	if (_step_edit_within_chord) {
+		step_to_next_chord ();
 		_step_edit_within_chord = false;
-		if (step_edit_region_view) {
-			step_edit_beat_pos += _step_edit_chord_duration;
-			step_edit_region_view->move_step_edit_cursor (step_edit_beat_pos);
-		}
+		_step_edit_chord_duration = Temporal::Beats();
 	} else {
 		_step_edit_triplet_countdown = 0;
 		_step_edit_within_chord = true;
+		_chord_tracker.reset ();
 	}
 }
 
@@ -420,7 +428,7 @@ StepEditor::step_edit_bar_sync ()
 
 	/* have to go to BBT to round up to bar, unfortunately */
 	TempoMap::SharedPtr tmap (TempoMap::use());
-	BBT_Argument bbt (tmap->bbt_at (pos).round_up_to_bar ());
+	BBT_Argument bbt (tmap->meter_at (pos).round_up_to_bar (tmap->bbt_at (pos)));
 
 	/* now back to beats */
 	pos = timepos_t (tmap->quarters_at (bbt));
@@ -433,7 +441,7 @@ StepEditor::playlist_changed ()
 {
 	step_edit_region_connection.disconnect ();
 	_track->playlist()->RegionRemoved.connect (step_edit_region_connection, invalidator (*this),
-	                                           boost::bind (&StepEditor::region_removed, this, _1),
+	                                           std::bind (&StepEditor::region_removed, this, _1),
 	                                           gui_context());
 }
 
