@@ -16,53 +16,32 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef __gtkardour_stripable_colorpicker_h__
-#define __gtkardour_stripable_colorpicker_h__
+#pragma once
 
 #include <memory>
 
-#include <gtkmm/colorbutton.h>
-#include <gtkmm/colorselection.h>
+#include <ytkmm/colorbutton.h>
+#include <ytkmm/colorselection.h>
 
-#include "ardour/stripable.h"
+#include "ardour_color_dialog.h"
 
-class StripableColorDialog : public Gtk::ColorSelectionDialog
+namespace ARDOUR {
+	class Stripable;
+}
+
+class StripableColorDialog : public ArdourColorDialog
 {
 public:
-	StripableColorDialog ();
+	StripableColorDialog (std::shared_ptr<ARDOUR::Stripable>);
 	~StripableColorDialog ();
-	void reset ();
-	void popup (std::shared_ptr<ARDOUR::Stripable> s);
-	void popup (const std::string&, uint32_t);
-	sigc::signal<void, uint32_t> ColorChanged;
+	void popup (Gtk::Window*);
 
 private:
-	void initialize_color_palette ();
 	void finish_color_edit (int response);
 	void color_changed ();
 
 	std::shared_ptr<ARDOUR::Stripable> _stripable;
-	ARDOUR::PresentationInfo::color_t _initial_color;
 
-	sigc::connection _color_changed_connection;
-
-
-	static bool palette_initialized;
-	static void palette_changed_hook (const Glib::RefPtr<Gdk::Screen>&, const Gdk::ArrayHandle_Color&);
-	static Gtk::ColorSelection::SlotChangePaletteHook gtk_palette_changed_hook;
+	PBD::ScopedConnectionList _connections;
 };
 
-class ArdourColorButton : public Gtk::ColorButton
-{
-public:
-	ArdourColorButton ();
-
-protected:
-	void on_clicked();
-	void color_selected (uint32_t color);
-
-private:
-	StripableColorDialog _color_picker;
-};
-
-#endif
