@@ -30,9 +30,7 @@
 #include <string>
 #include <list>
 
-#include <boost/smart_ptr/scoped_ptr.hpp>
-
-#include <gtkmm/separator.h>
+#include <ytkmm/separator.h>
 
 #include "pbd/error.h"
 #include "pbd/convert.h"
@@ -88,7 +86,7 @@ uint32_t TimeAxisView::button_height = 0;
 uint32_t TimeAxisView::extra_height = 0;
 int const TimeAxisView::_max_order = 512;
 unsigned int TimeAxisView::name_width_px = 100;
-PBD::Signal1<void,TimeAxisView*> TimeAxisView::CatchDeletion;
+PBD::Signal<void(TimeAxisView*)> TimeAxisView::CatchDeletion;
 Glib::RefPtr<Gtk::SizeGroup> TimeAxisView::controls_meters_size_group = Glib::RefPtr<Gtk::SizeGroup>();
 Glib::RefPtr<Gtk::SizeGroup> TimeAxisView::midi_scroomer_size_group = Glib::RefPtr<Gtk::SizeGroup>();
 
@@ -164,7 +162,7 @@ TimeAxisView::TimeAxisView (ARDOUR::Session* sess, PublicEditor& ed, TimeAxisVie
 	set_tooltip (inactive_label, _("This track is inactive. (right-click to activate)"));
 
 	{
-		boost::scoped_ptr<Gtk::Entry> an_entry (new FocusEntry);
+		const std::unique_ptr<Gtk::Entry> an_entry (new FocusEntry);
 		an_entry->set_name (X_("TrackNameEditor"));
 		Gtk::Requisition req = an_entry->size_request ();
 
@@ -270,10 +268,11 @@ TimeAxisView::~TimeAxisView()
 	delete _canvas_display;
 	_canvas_display = 0;
 
+	delete _size_menu;
+	_size_menu = 0;
+
 	delete display_menu;
 	display_menu = 0;
-
-	delete _size_menu;
 }
 
 void
@@ -317,7 +316,7 @@ TimeAxisView::hide ()
 * @return height of this TimeAxisView.
 */
 guint32
-TimeAxisView::show_at (double y, int& nth, VBox *parent)
+TimeAxisView::show_at (int y, int& nth, VBox *parent)
 {
 	if (control_parent) {
 		control_parent->reorder_child (TOP_LEVEL_WIDGET, nth);
@@ -635,7 +634,7 @@ void
 TimeAxisView::set_height_enum (Height h, bool apply_to_selection)
 {
 	if (apply_to_selection) {
-		_editor.get_selection().tracks.foreach_time_axis (boost::bind (&TimeAxisView::set_height_enum, _1, h, false));
+		_editor.get_selection().tracks.foreach_time_axis (std::bind (&TimeAxisView::set_height_enum, _1, h, false));
 	} else {
 		set_height (preset_height (h));
 	}
@@ -1117,7 +1116,7 @@ TimeAxisView::remove_child (std::shared_ptr<TimeAxisView> child)
  *  @param result Filled in with selectable things.
  */
 void
-TimeAxisView::get_selectables (timepos_t const & start, timepos_t const & end, double top, double bot, list<Selectable*>& results, bool within)
+TimeAxisView::_get_selectables (timepos_t const & start, timepos_t const & end, double top, double bot, list<Selectable*>& results, bool within)
 {
 	for (Children::iterator i = children.begin(); i != children.end(); ++i) {
 		if (!(*i)->hidden()) {
