@@ -19,7 +19,7 @@
 #include <cassert>
 #include <vector>
 
-#include <gtkmm/stock.h>
+#include <ytkmm/stock.h>
 
 #include "pbd/basename.h"
 #include "pbd/file_utils.h"
@@ -219,8 +219,8 @@ TriggerClipPicker::TriggerClipPicker ()
 
 	UIConfiguration::instance ().ColorsChanged.connect (sigc::mem_fun (*this, &TriggerClipPicker::on_theme_changed));
 	UIConfiguration::instance ().ParameterChanged.connect (sigc::mem_fun (*this, &TriggerClipPicker::parameter_changed));
-	Config->ParameterChanged.connect (_config_connection, invalidator (*this), boost::bind (&TriggerClipPicker::parameter_changed, this, _1), gui_context ());
-	LibraryClipAdded.connect (_clip_added_connection, invalidator (*this), boost::bind (&TriggerClipPicker::clip_added, this, _1, _2), gui_context ());
+	Config->ParameterChanged.connect (_config_connection, invalidator (*this), std::bind (&TriggerClipPicker::parameter_changed, this, _1), gui_context ());
+	LibraryClipAdded.connect (_clip_added_connection, invalidator (*this), std::bind (&TriggerClipPicker::clip_added, this, _1, _2), gui_context ());
 
 	/* cache value */
 	_clip_library_dir = clip_library_dir ();
@@ -319,7 +319,7 @@ TriggerClipPicker::refill_dropdown ()
 	/* Custom Paths */
 	assert (_clip_dir_menu.items ().size () > 0);
 	if (!Config->get_sample_lib_path ().empty ()) {
-		_clip_dir_menu.AddMenuElem (Menu_Helpers::SeparatorElem ());
+		_clip_dir_menu.add_menu_elem (Menu_Helpers::SeparatorElem ());
 		Searchpath cpath (Config->get_sample_lib_path ());
 		for (auto const& f : cpath) {
 			maybe_add_dir (f);
@@ -328,10 +328,10 @@ TriggerClipPicker::refill_dropdown ()
 
 	_clip_library_listed = maybe_add_dir (clip_library_dir (false));
 
-	_clip_dir_menu.AddMenuElem (Menu_Helpers::SeparatorElem ());
-	_clip_dir_menu.AddMenuElem (Menu_Helpers::MenuElem (_("Edit..."), sigc::mem_fun (*this, &TriggerClipPicker::edit_path)));
-	_clip_dir_menu.AddMenuElem (Menu_Helpers::MenuElem (_("Other..."), sigc::mem_fun (*this, &TriggerClipPicker::open_dir)));
-	_clip_dir_menu.AddMenuElem (Menu_Helpers::MenuElem (_("Download..."), sigc::mem_fun (*this, &TriggerClipPicker::open_downloader)));
+	_clip_dir_menu.add_menu_elem (Menu_Helpers::SeparatorElem ());
+	_clip_dir_menu.add_menu_elem (Menu_Helpers::MenuElem (_("Edit..."), sigc::mem_fun (*this, &TriggerClipPicker::edit_path)));
+	_clip_dir_menu.add_menu_elem (Menu_Helpers::MenuElem (_("Other..."), sigc::mem_fun (*this, &TriggerClipPicker::open_dir)));
+	_clip_dir_menu.add_menu_elem (Menu_Helpers::MenuElem (_("Download..."), sigc::mem_fun (*this, &TriggerClipPicker::open_downloader)));
 	return false;
 }
 
@@ -405,7 +405,7 @@ TriggerClipPicker::maybe_add_dir (std::string const& dir)
 		return false;
 	}
 
-	_clip_dir_menu.AddMenuElem (Gtkmm2ext::MenuElemNoMnemonic (display_name (dir), sigc::bind (sigc::mem_fun (*this, &TriggerClipPicker::list_dir), dir, (Gtk::TreeNodeChildren*)0)));
+	_clip_dir_menu.add_menu_elem (Gtkmm2ext::MenuElemNoMnemonic (display_name (dir), sigc::bind (sigc::mem_fun (*this, &TriggerClipPicker::list_dir), dir, (Gtk::TreeNodeChildren*)0)));
 
 	/* check if a parent path of the given dir already exists,
 	 * or if this new path is parent to any existing ones.
@@ -506,12 +506,9 @@ TriggerClipPicker::row_selected ()
 			/* TODO: if it's a really big file, we could skip this check */
 			std::shared_ptr<SMFSource> ms;
 			try {
-				ms = std::dynamic_pointer_cast<SMFSource> (
-					SourceFactory::createExternal (DataType::MIDI, *_session,
-												   path, 0, Source::Flag (0), false));
+				ms = std::dynamic_pointer_cast<SMFSource> (SourceFactory::createExternal (DataType::MIDI, *_session, path, 0, Source::Flag (0), false));
 			} catch (const std::exception& e) {
-				error << string_compose(_("Could not read file: %1 (%2)."),
-										path, e.what()) << endmsg;
+				error << string_compose(_("Could not read file: %1 (%2)."), path, e.what()) << endmsg;
 			}
 
 			if (ms) {
@@ -865,9 +862,9 @@ TriggerClipPicker::set_session (Session* s)
 		_gain_control.set_controllable (none);
 	} else {
 		_auditioner_connections.drop_connections ();
-		_session->AuditionActive.connect (_auditioner_connections, invalidator (*this), boost::bind (&TriggerClipPicker::audition_active, this, _1), gui_context ());
-		_session->the_auditioner ()->AuditionProgress.connect (_auditioner_connections, invalidator (*this), boost::bind (&TriggerClipPicker::audition_progress, this, _1, _2), gui_context ());
-		_session->the_auditioner ()->processors_changed.connect (_auditioner_connections, invalidator (*this), boost::bind (&TriggerClipPicker::audition_processors_changed, this), gui_context ());
+		_session->AuditionActive.connect (_auditioner_connections, invalidator (*this), std::bind (&TriggerClipPicker::audition_active, this, _1), gui_context ());
+		_session->the_auditioner ()->AuditionProgress.connect (_auditioner_connections, invalidator (*this), std::bind (&TriggerClipPicker::audition_progress, this, _1, _2), gui_context ());
+		_session->the_auditioner ()->processors_changed.connect (_auditioner_connections, invalidator (*this), std::bind (&TriggerClipPicker::audition_processors_changed, this), gui_context ());
 		audition_processors_changed (); /* set sensitivity */
 
 		_gain_control.set_controllable (_session->the_auditioner ()->gain_control ());
@@ -1095,7 +1092,7 @@ TriggerClipPicker::audition_show_plugin_ui ()
 			_audition_plugnui->set_session (_session);
 			_audition_plugnui->show_all ();
 			_audition_plugnui->set_title (/* generate_processor_title (plugin_insert)*/ _("Audition Synth"));
-			plugin_insert->DropReferences.connect (_processor_connections, invalidator (*this), boost::bind (&TriggerClipPicker::audition_processor_going_away, this), gui_context());
+			plugin_insert->DropReferences.connect (_processor_connections, invalidator (*this), std::bind (&TriggerClipPicker::audition_processor_going_away, this), gui_context());
 
 			_audition_plugnui->signal_map_event ().connect (sigc::hide (sigc::bind (sigc::mem_fun (*this, &TriggerClipPicker::audition_processor_viz), true)));
 			_audition_plugnui->signal_unmap_event ().connect (sigc::hide (sigc::bind (sigc::mem_fun (*this, &TriggerClipPicker::audition_processor_viz), false)));
