@@ -22,7 +22,7 @@
 
 #include <list>
 
-#include <gtkmm/label.h>
+#include <ytkmm/label.h>
 
 #include "pbd/properties.h"
 
@@ -39,14 +39,16 @@
 #include "ardour/region_factory.h"
 #include "ardour/profile.h"
 #include "ardour/smf_source.h"
+#include "ardour/stripable.h"
 
 #include "actions.h"
+#include "application_bar.h"
 #include "ardour_ui.h"
 #include "editor.h"
 #include "gui_thread.h"
 #include "public_editor.h"
+#include "pianoroll.h"
 #include "timers.h"
-
 #include "trigger_page.h"
 #include "trigger_strip.h"
 #include "triggerbox_ui.h"
@@ -64,25 +66,36 @@ using namespace Gtk;
 using namespace std;
 
 TriggerPage::TriggerPage ()
-	: Tabbable (_content, _("Cues"), X_("trigger"))
+	: Tabbable (_("Cues"), X_("trigger"), NULL, true, Tabbable::PaneLayout (Tabbable::PaneRight | Tabbable::PaneBottom))
 	, _cue_area_frame (0.5, 0, 1.0, 0)
 	, _cue_box (16, 16 * TriggerBox::default_triggers_per_box)
 	, _master_widget (16, 16)
 	, _master (_master_widget.root ())
+	, _show_bottom_pane (false)
 	, _selection (*this, *this)
+	, clip_editor_column (-1)
 {
 	load_bindings ();
 	register_actions ();
 
-	/* Match TriggerStrip::_name_button height */
-	ArdourButton* spacer = manage (new ArdourButton (ArdourButton::Text));
-	spacer->set_name ("mixer strip button");
-	spacer->set_sensitive (false);
-	spacer->set_text (" ");
+	/* Spacers to match height of TriggerStrip's input, name and toggle
+	 * rec-enable buttons
+	 */
+
+	ArdourButton* spacer[3];
+
+	for (std::size_t n = 0; n < sizeof (spacer) / sizeof (spacer[0]); ++n) {
+		spacer[n] = manage (new ArdourButton (ArdourButton::Text));
+		spacer[n]->set_name ("mixer strip button");
+		spacer[n]->set_sensitive (false);
+		spacer[n]->set_text (" ");
+	}
 
 	/* left-side, fixed-size cue-box */
 	_cue_area_box.set_spacing (2);
-	_cue_area_box.pack_start (*spacer, Gtk::PACK_SHRINK);
+	_cue_area_box.pack_start (*spacer[0], Gtk::PACK_SHRINK);
+	_cue_area_box.pack_start (*spacer[1], Gtk::PACK_SHRINK);
+	_cue_area_box.pack_start (*spacer[2], Gtk::PACK_SHRINK);
 	_cue_area_box.pack_start (_cue_box, Gtk::PACK_SHRINK);
 	_cue_area_box.pack_start (_master_widget, Gtk::PACK_SHRINK);
 
@@ -90,7 +103,7 @@ TriggerPage::TriggerPage ()
 	 * use Alignment instead of Frame with SHADOW_IN (2px)
 	 * +1px padding for _strip_scroller frame -> 3px top padding
 	 */
-	_cue_area_frame.set_padding (3, 1, 1, 1);
+	_cue_area_frame.set_padding (4, 1, 1, 1);
 	_cue_area_frame.add (_cue_area_box);
 
 	_strip_scroller.add (_strip_packer);
@@ -101,8 +114,9 @@ TriggerPage::TriggerPage ()
 	_no_strips.set_can_focus ();
 	_no_strips.add_events (Gdk::BUTTON_PRESS_MASK | Gdk::BUTTON_RELEASE_MASK);
 	_no_strips.set_size_request (PX_SCALE (20), -1);
-	_no_strips.signal_expose_event ().connect (sigc::bind (sigc::ptr_fun (&ArdourWidgets::ArdourIcon::expose_with_text), &_no_strips, ArdourWidgets::ArdourIcon::ShadedPlusSign,
-			_("Drop a clip here\nto create a new Track")));
+	if (UIConfiguration::instance().get_render_plus_hints ()) {
+		_no_strips.signal_expose_event ().connect (sigc::bind (sigc::ptr_fun (&ArdourWidgets::ArdourIcon::expose_with_text), &_no_strips, ArdourWidgets::ArdourIcon::ShadedPlusSign, _("Drop a clip here\nto create a new Track")));
+	}
 	_no_strips.signal_button_press_event ().connect (sigc::mem_fun (*this, &TriggerPage::no_strip_button_event));
 	_no_strips.signal_button_release_event ().connect (sigc::mem_fun (*this, &TriggerPage::no_strip_button_event));
 	_no_strips.signal_drag_motion ().connect (sigc::mem_fun (*this, &TriggerPage::no_strip_drag_motion));
@@ -119,78 +133,89 @@ TriggerPage::TriggerPage ()
 	_strip_group_box.pack_start (_strip_scroller, true, true);
 
 	/* sidebar */
-	_sidebar_notebook.set_show_tabs (true);
+	_sidebar_notebook.set_show_tabs (false);
 	_sidebar_notebook.set_scrollable (true);
 	_sidebar_notebook.popup_disable ();
-	_sidebar_notebook.set_tab_pos (Gtk::POS_RIGHT);
 
-	_sidebar_vbox.pack_start (_sidebar_notebook);
-	add_sidebar_page (_("Clips"), _trigger_clip_picker);
-	add_sidebar_page (_("Tracks"), _trigger_route_list.widget ());
-	add_sidebar_page (_("Sources"), _trigger_source_list.widget ());
-	add_sidebar_page (_("Regions"), _trigger_region_list.widget ());
+	add_sidebar_page (_("Clips"), _("Clips"), _trigger_clip_picker);
+	add_sidebar_page (_("Tracks"), _("Tracks & Busses"), _trigger_route_list.widget ());
+	add_sidebar_page (_("Sources"), _("Sources"), _trigger_source_list.widget ());
+	add_sidebar_page (_("Regions"), _("Regions"), _trigger_region_list.widget ());
 
-	/* Upper pane ([slot | strips] | file browser) */
-	_pane_upper.add (_strip_group_box);
-	_pane_upper.add (_sidebar_vbox);
+	_sidebar_pager2.set_index (3);
+
+	_midi_editor = new Pianoroll (X_("MIDICueEditor"));
+	_audio_editor = new AudioClipEditor (X_("AudioClipEditor"));
+
+	_audio_editor->get_canvas_viewport()->set_size_request (1, 1);
+	_midi_editor->get_canvas_viewport()->set_size_request (1, 1);
+
+	_audio_editor->get_canvas_viewport()->show ();
+	_midi_editor->get_canvas_viewport()->show ();
 
 	/* Bottom -- Properties of selected Slot/Region */
-	Gtk::Table* table = manage (new Gtk::Table);
-	table->set_homogeneous (false);
-	table->set_spacings (8);  //match to slot_properties_box::set_spacings
-	table->set_border_width (8);
 
-	int col = 0;
-	table->attach (_slot_prop_box, col, col + 1, 0, 1, Gtk::FILL, Gtk::SHRINK | Gtk::FILL);
+	hpacker.set_homogeneous (false);
+	hpacker.set_spacing (8);  //match to slot_properties_box::set_spacings
+	hpacker.set_border_width (1);
 
-	col = 1;
-	table->attach (_audio_trig_box, col, col + 1, 0, 1, Gtk::FILL, Gtk::SHRINK | Gtk::FILL);
-	++col;
+	/* note these are re-packed as needed below. see
+	 * hide_all(), selection_changed(), trigger_arm_changed()
+	 */
+	hpacker.pack_start (_properties_box, true, true);
+	hpacker.pack_start (_midi_trig_box, false, false);
+	hpacker.pack_start (_audio_trig_box, false, false);
+	hpacker.set_no_show_all ();
 
-#ifdef MIDI_PROPERTIES_BOX_IMPLEMENTED
-	col = 2;
-	table->attach (_midi_trig_box, col, col + 1, 0, 1, Gtk::FILL, Gtk::SHRINK);
-	++col;
-#endif
+	_sidebar_notebook.signal_switch_page().connect ([this](GtkNotebookPage*, guint page) {
+			std::string label (_sidebar_notebook.get_tab_label_text (*_sidebar_notebook.get_nth_page (page)));
+			_sidebar_pager1.set_active (label);
+			_sidebar_pager2.set_active (label);
+			//instant_save ();
+			});
 
-	_parameter_box.pack_start (*table);
+	_sidebar_pager1.set_name ("tab button");
+	_sidebar_pager2.set_name ("tab button");
+
+	HBox* tabbox = manage (new HBox (true));
+	tabbox->set_spacing (3);
+	tabbox->pack_start (_sidebar_pager1);
+	tabbox->pack_start (_sidebar_pager2);
+
+	_sidebar_vbox.pack_start (*tabbox, false, false, 2);
+	_sidebar_vbox.pack_start (_sidebar_notebook);
 
 	/* Top-level Layout */
-	_content.pack_start (_pane_upper, true, true);
-	_content.pack_start (_parameter_box, false, false);
-	_content.show ();
+	content_app_bar.add (_application_bar);
+	content_main.add (_strip_group_box);
+	content_att_bottom.add (hpacker);
+	content_att_right.add (_sidebar_vbox);
 
 	/* Show all */
-	_pane_upper.show ();
 	_strip_group_box.show ();
 	_strip_scroller.show ();
 	_strip_packer.show ();
 	_cue_area_frame.show_all ();
 	_trigger_clip_picker.show ();
 	_no_strips.show ();
-	_sidebar_notebook.show_all ();
+	_sidebar_vbox.show_all ();
+	_properties_box.show();
 
 	/* setup keybidings */
-	_content.set_data ("ardour-bindings", bindings);
+	set_widget_bindings (contents(), *bindings, ARDOUR_BINDING_KEY);
 
 	/* subscribe to signals */
-	Config->ParameterChanged.connect (*this, invalidator (*this), boost::bind (&TriggerPage::parameter_changed, this, _1), gui_context ());
-	PresentationInfo::Change.connect (*this, invalidator (*this), boost::bind (&TriggerPage::pi_property_changed, this, _1), gui_context ());
+	Config->ParameterChanged.connect (*this, invalidator (*this), std::bind (&TriggerPage::parameter_changed, this, _1), gui_context ());
+	PresentationInfo::Change.connect (*this, invalidator (*this), std::bind (&TriggerPage::pi_property_changed, this, _1), gui_context ());
 
 	/* init */
 	update_title ();
-
-	/* Restore pane state */
-	float          fract;
-	XMLNode const* settings = ARDOUR_UI::instance ()->trigger_page_settings ();
-	if (!settings || !settings->get_property ("triggerpage-hpane-pos", fract) || fract > 1.0) {
-		fract = 0.75f;
-	}
-	_pane_upper.set_divider (0, fract);
 }
 
 TriggerPage::~TriggerPage ()
 {
+	delete _midi_editor;
+	delete _audio_editor;
 }
 
 Gtk::Window*
@@ -204,7 +229,7 @@ TriggerPage::use_own_window (bool and_fill_it)
 		win->set_name ("TriggerWindow");
 		ARDOUR_UI::instance ()->setup_toplevel_window (*win, _("Cues"), this);
 		win->signal_event ().connect (sigc::bind (sigc::ptr_fun (&Keyboard::catch_user_event_for_pre_dialog_focus), win));
-		win->set_data ("ardour-bindings", bindings);
+		set_widget_bindings (*win, *bindings, ARDOUR_BINDING_KEY);
 		update_title ();
 #if 0 // TODO
 		if (!win->get_focus()) {
@@ -217,25 +242,100 @@ TriggerPage::use_own_window (bool and_fill_it)
 	return win;
 }
 
+void
+TriggerPage::showhide_att_bottom (bool yn)
+{
+	if (_show_bottom_pane == yn) {
+		return;
+	}
+
+	_show_bottom_pane = yn;
+
+	if (!_show_bottom_pane) {
+		Tabbable::showhide_att_bottom (false);
+	} else if (!Editor::instance ().get_selection ().triggers.empty ()) {
+		Tabbable::showhide_att_bottom (true);
+	}
+}
+
 XMLNode&
 TriggerPage::get_state () const
 {
 	XMLNode* node = new XMLNode (X_("TriggerPage"));
 	node->add_child_nocopy (Tabbable::get_state ());
 
-	node->set_property (X_("triggerpage-hpane-pos"), _pane_upper.get_divider ());
 	node->set_property (X_("triggerpage-sidebar-page"), _sidebar_notebook.get_current_page ());
+	node->set_property (X_("triggerpage-sidebar-btn1"), _sidebar_pager1.index ());
+	node->set_property (X_("triggerpage-sidebar-btn2"), _sidebar_pager2.index ());
+
+	node->add_child_nocopy (_midi_editor->get_state());
+	node->add_child_nocopy (_audio_editor->get_state());
+
+	Glib::RefPtr<ToggleAction> act = ActionManager::get_toggle_action ("Cues", "ToggleTriggerList");
+	node->set_property ("show-trigger-list", act->get_active ());
+
+	act = ActionManager::get_toggle_action ("Cues", "ToggleTriggerProps");
+	node->set_property ("show-trigger-properties", act->get_active ());
 
 	return *node;
 }
 
+void
+TriggerPage::focus_on_clock()
+{
+	_application_bar.focus_on_clock();
+}
+
 int
 TriggerPage::set_state (const XMLNode& node, int version)
 {
+	guint index;
+	if (node.get_property (X_("triggerpage-sidebar-btn1"), index)) {
+		_sidebar_pager1.set_index (index);
+	}
+
+	if (node.get_property (X_("triggerpage-sidebar-btn2"), index)) {
+		_sidebar_pager2.set_index (index);
+	}
+
 	int32_t sidebar_page;
 	if (node.get_property (X_("triggerpage-sidebar-page"), sidebar_page)) {
 		_sidebar_notebook.set_current_page (sidebar_page);
+	} else {
+		sidebar_page = _sidebar_notebook.get_current_page ();
 	}
+	std::string label (_sidebar_notebook.get_tab_label_text (*_sidebar_notebook.get_nth_page (sidebar_page)));
+	_sidebar_pager1.set_active (label);
+	_sidebar_pager2.set_active (label);
+
+	XMLNode* mn = node.child (_midi_editor->editor_name().c_str());
+	if (mn) {
+		_midi_editor->set_state (*mn, version);
+	}
+
+	XMLNode* an = node.child (_audio_editor->editor_name().c_str());
+	if (an) {
+		_audio_editor->set_state (*an, version);
+	}
+
+	bool yn = true;
+	node.get_property ("show-trigger-list", yn);
+	{
+		Glib::RefPtr<ToggleAction> tact = ActionManager::get_toggle_action (X_("Cues"), X_("ToggleTriggerList"));
+		/* do it twice to force the change */
+		tact->set_active (!yn);
+		tact->set_active (yn);
+	}
+
+	yn = true; // show properties by default
+	node.get_property ("show-trigger-props", yn);
+	{
+		Glib::RefPtr<ToggleAction> tact = ActionManager::get_toggle_action (X_("Cues"), X_("ToggleTriggerProps"));
+		/* do it twice to force the change */
+		tact->set_active (!yn);
+		tact->set_active (yn);
+	}
+
 	return Tabbable::set_state (node, version);
 }
 
@@ -250,6 +350,12 @@ TriggerPage::set_session (Session* s)
 {
 	SessionHandlePtr::set_session (s);
 
+	if (!_session) {
+		_selection.clear ();
+		return;
+	}
+
+	_application_bar.set_session (_session);
 	_cue_box.set_session (s);
 	_trigger_clip_picker.set_session (s);
 	_master.set_session (s);
@@ -257,31 +363,28 @@ TriggerPage::set_session (Session* s)
 	_trigger_region_list.set_session (s);
 	_trigger_route_list.set_session (s);
 
-	if (!_session) {
-		_selection.clear ();
-		return;
-	}
-
 	XMLNode* node = ARDOUR_UI::instance ()->trigger_page_settings ();
 	set_state (*node, Stateful::loading_state_version);
 
-	_session->DirtyChanged.connect (_session_connections, invalidator (*this), boost::bind (&TriggerPage::update_title, this), gui_context ());
-	_session->StateSaved.connect (_session_connections, invalidator (*this), boost::bind (&TriggerPage::update_title, this), gui_context ());
+	_session->DirtyChanged.connect (_session_connections, invalidator (*this), std::bind (&TriggerPage::update_title, this), gui_context ());
+	_session->StateSaved.connect (_session_connections, invalidator (*this), std::bind (&TriggerPage::update_title, this), gui_context ());
 
-	_session->RouteAdded.connect (_session_connections, invalidator (*this), boost::bind (&TriggerPage::add_routes, this, _1), gui_context ());
-	TriggerStrip::CatchDeletion.connect (*this, invalidator (*this), boost::bind (&TriggerPage::remove_route, this, _1), gui_context ());
+	_session->RouteAdded.connect (_session_connections, invalidator (*this), std::bind (&TriggerPage::add_routes, this, _1), gui_context ());
+	TriggerStrip::CatchDeletion.connect (*this, invalidator (*this), std::bind (&TriggerPage::remove_route, this, _1), gui_context ());
 
-	_session->config.ParameterChanged.connect (_session_connections, invalidator (*this), boost::bind (&TriggerPage::parameter_changed, this, _1), gui_context ());
+	_session->config.ParameterChanged.connect (_session_connections, invalidator (*this), std::bind (&TriggerPage::parameter_changed, this, _1), gui_context ());
 
 	Editor::instance ().get_selection ().TriggersChanged.connect (sigc::mem_fun (*this, &TriggerPage::selection_changed));
+	Trigger::TriggerArmChanged.connect (*this, invalidator (*this), std::bind (&TriggerPage::trigger_arm_changed, this, _1), gui_context());
+	TriggerBox::RegionCaptured.connect (*this, invalidator (*this), std::bind (&TriggerPage::region_captured, this, _1), gui_context());
 
 	initial_track_display ();
 
-	_slot_prop_box.set_session (s);
-
+	_properties_box.set_session (s);
 	_audio_trig_box.set_session (s);
-
 	_midi_trig_box.set_session (s);
+	_midi_editor->set_session (s);
+	_audio_editor->set_session (s);
 
 	update_title ();
 	start_updating ();
@@ -345,14 +448,12 @@ TriggerPage::update_title ()
 }
 
 void
-TriggerPage::add_sidebar_page (string const & name, Gtk::Widget& widget)
+TriggerPage::add_sidebar_page (string const& label, string const& name, Gtk::Widget& widget)
 {
-	EventBox* b = manage (new EventBox);
-	Label* l = manage (new Label (name));
-	l->set_angle (-90);
-	b->add (*l);
-	b->show_all ();
-	_sidebar_notebook.append_page (widget, *b);
+	_sidebar_notebook.append_page (widget, name);
+	using namespace Menu_Helpers;
+	_sidebar_pager1.add_item (label, name, [this, &widget]() {_sidebar_notebook.set_current_page (_sidebar_notebook.page_num (widget)); });
+	_sidebar_pager2.add_item (label, name, [this, &widget]() {_sidebar_notebook.set_current_page (_sidebar_notebook.page_num (widget)); });
 }
 
 void
@@ -376,37 +477,136 @@ TriggerPage::clear_selected_slot ()
 	trigger->set_region (std::shared_ptr<Region>());
 }
 
+void
+TriggerPage::region_captured (Trigger const * trigger)
+{
+	if (!trigger) {
+		return;
+	}
+
+	/* hide everything */
+
+	hide_all ();
+
+	Tabbable::showhide_att_bottom (false);
+
+	hpacker.set_child_packing (_properties_box, false, false);
+
+	TriggerBox& box = trigger->box();
+	TriggerReference ref (trigger->boxptr(), trigger->index());
+
+	if (box.data_type () == DataType::AUDIO) {
+
+		_audio_trig_box.set_trigger (ref);
+		_audio_trig_box.show ();
+
+		_audio_editor->set_trigger (ref);
+		_audio_editor->get_canvas_viewport()->show ();
+
+		hpacker.pack_start (_audio_editor->contents(), true, true);
+		_audio_editor->contents().show_all ();
+
+	} else {
+
+		_midi_trig_box.set_trigger (ref);
+		_midi_trig_box.show ();
+
+		_midi_editor->set_trigger (ref);
+		_midi_editor->get_canvas_viewport()->show ();
+
+		hpacker.pack_start (_midi_editor->contents(), true, true);
+		_midi_editor->contents().show_all ();
+	}
+
+	if (_show_bottom_pane) {
+		Tabbable::showhide_att_bottom (true);
+	}
+}
+
+void
+TriggerPage::trigger_arm_changed (Trigger const * trigger)
+{
+	if (!trigger) {
+		return;
+	}
+	for (auto & strip : _strips) {
+		TriggerBoxWidget& tbw (strip->triggerbox_widget());
+		TriggerBoxUI* ui (tbw.ui());
+
+		if (!ui) {
+			continue;
+		}
+
+		TriggerEntry* entry = ui->entry_by_trigger (*trigger);
+		if (entry) {
+			PublicEditor::instance ().get_selection ().set (entry);
+			break;
+		}
+	}
+}
+
+void
+TriggerPage::hide_all ()
+{
+	_audio_trig_box.hide ();
+	_midi_trig_box.hide ();
+	if (_audio_editor->contents().get_parent()) {
+		_audio_editor->contents().unmap ();
+		_audio_editor->contents().get_parent()->remove (_audio_editor->contents());
+	}
+
+	if (_midi_editor->contents().get_parent()) {
+		_midi_editor->contents().unmap ();
+		_midi_editor->contents().get_parent()->remove (_midi_editor->contents());
+	}
+}
+
 void
 TriggerPage::selection_changed ()
 {
 	Selection& selection (Editor::instance ().get_selection ());
 
-	_slot_prop_box.hide ();
+	hide_all ();
 
-	_audio_trig_box.hide ();
+	Tabbable::showhide_att_bottom (false);
 
-	_midi_trig_box.hide ();
+	if (selection.triggers.empty ()) {
+		hpacker.set_child_packing (_properties_box, true, true);
+		return;
+	}
 
-	_parameter_box.hide ();
+	hpacker.set_child_packing (_properties_box, false, false);
 
-	if (!selection.triggers.empty ()) {
-		TriggerSelection ts      = selection.triggers;
-		TriggerEntry*    entry   = *ts.begin ();
-		TriggerReference ref     = entry->trigger_reference ();
-		TriggerPtr       trigger = entry->trigger ();
+	TriggerReference ref     = selection.triggers.front()->trigger_reference ();
+	std::shared_ptr<TriggerBox> box = ref.box();
 
-		_slot_prop_box.set_slot (ref);
-		_slot_prop_box.show ();
-		if (trigger->region ()) {
-			if (trigger->region ()->data_type () == DataType::AUDIO) {
-				_audio_trig_box.set_trigger (ref);
-				_audio_trig_box.show ();
-			} else {
-				_midi_trig_box.set_trigger (ref);
-				_midi_trig_box.show ();
-			}
-		}
-		_parameter_box.show ();
+	if (box->data_type () == DataType::AUDIO) {
+
+		_audio_trig_box.set_trigger (ref);
+		_audio_trig_box.show ();
+
+		_audio_editor->set_trigger (ref);
+		_audio_editor->get_canvas_viewport()->show ();
+
+		hpacker.pack_start (_audio_editor->contents(), true, true);
+		_audio_editor->contents().show_all ();
+
+	} else {
+
+		_midi_trig_box.set_trigger (ref);
+		_midi_trig_box.show ();
+
+		_midi_editor->set_trigger (ref);
+		_midi_editor->get_canvas_viewport()->show ();
+
+		hpacker.pack_start (_midi_editor->contents(), true, true);
+		_midi_editor->contents().show_all ();
+	}
+
+	hpacker.show ();
+
+	if (_show_bottom_pane) {
+		Tabbable::showhide_att_bottom (true);
 	}
 }
 
@@ -436,8 +636,8 @@ TriggerPage::add_routes (RouteList& rl)
 		TriggerStrip* ts = new TriggerStrip (_session, *r);
 		_strips.push_back (ts);
 
-		(*r)->presentation_info ().PropertyChanged.connect (*this, invalidator (*this), boost::bind (&TriggerPage::stripable_property_changed, this, _1, std::weak_ptr<Stripable> (*r)), gui_context ());
-		(*r)->PropertyChanged.connect (*this, invalidator (*this), boost::bind (&TriggerPage::stripable_property_changed, this, _1, std::weak_ptr<Stripable> (*r)), gui_context ());
+		(*r)->presentation_info ().PropertyChanged.connect (*this, invalidator (*this), std::bind (&TriggerPage::stripable_property_changed, this, _1, std::weak_ptr<Stripable> (*r)), gui_context ());
+		(*r)->PropertyChanged.connect (*this, invalidator (*this), std::bind (&TriggerPage::stripable_property_changed, this, _1, std::weak_ptr<Stripable> (*r)), gui_context ());
 		ts->signal_button_release_event().connect (sigc::bind (sigc::mem_fun(*this, &TriggerPage::strip_button_release_event), ts));
 	}
 	redisplay_track_list ();
@@ -681,7 +881,7 @@ TriggerPage::no_strip_drag_data_received (Glib::RefPtr<Gdk::DragContext> const&
 			                                         Config->get_strict_io () || Profile->get_mixbus (),
 			                                         std::shared_ptr<ARDOUR::PluginInfo>(),
 			                                         (ARDOUR::Plugin::PresetRecord*) 0,
-			                                         (ARDOUR::RouteGroup*) 0, 1, region->name(), PresentationInfo::max_order, Normal, true, true);
+			                                         nullptr, 1, region->name(), PresentationInfo::max_order, Normal, true, true);
 			if (!midi_tracks.empty()) {
 				triggerbox = midi_tracks.front()->triggerbox ();
 			}
@@ -758,7 +958,7 @@ TriggerPage::stop_updating ()
 void
 TriggerPage::fast_update_strips ()
 {
-	if (_content.get_mapped () && _session) {
+	if (contents().get_mapped () && _session) {
 		for (list<TriggerStrip*>::iterator i = _strips.begin (); i != _strips.end (); ++i) {
 			(*i)->fast_update ();
 		}
@@ -770,6 +970,14 @@ TriggerPage::register_actions ()
 {
 	Glib::RefPtr<ActionGroup> trigger_actions = ActionManager::create_action_group (bindings, X_("Cues"));
 
+	/* attachments visibility (editor-mixer-strip, bottom properties, sidebar list) */
+
+	Glib::RefPtr<Action> act = ActionManager::register_toggle_action (trigger_actions, "ToggleTriggerList", _("Cue Page: Show Sidebar List"), sigc::mem_fun (*this, &Tabbable::att_right_button_toggled));
+	right_attachment_button.set_related_action (act);
+
+	act = ActionManager::register_toggle_action (trigger_actions, "ToggleTriggerProps", _("Cue Page: Show Properties Bottom"), sigc::mem_fun (*this, &Tabbable::att_bottom_button_toggled));
+	bottom_attachment_button.set_related_action (act);
+
 	ActionManager::register_action (trigger_actions, "clear-trigger-slot", _("Clear Selected Slot"), sigc::mem_fun (*this, &TriggerPage::clear_selected_slot));
 	ActionManager::register_action (trigger_actions, "clear-trigger-slot-alt", _("Clear Selected Slot"), sigc::mem_fun (*this, &TriggerPage::clear_selected_slot));
 
