@@ -17,8 +17,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef __ardour_gtk_trigger_selection_h__
-#define __ardour_gtk_trigger_selection_h__
+#pragma once
 
 #include <list>
 
@@ -29,4 +28,3 @@ class TriggerSelection : public std::list<TriggerEntry*>
    public:
 };
 
-#endif /* __ardour_gtk_trigger_selection_h__ */
