@@ -16,7 +16,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <gtkmm/box.h>
+#include <ytkmm/box.h>
 
 
 #include "pbd/convert.h"
@@ -26,6 +26,8 @@
 #include "ardour/session.h"
 
 #include "gtkmm2ext/utils.h"
+
+#include "widgets/slider_controller.h"
 #include "widgets/tooltips.h"
 
 #include "ardour_ui.h"
@@ -74,6 +76,7 @@ VirtualKeyboardWindow::VirtualKeyboardWindow ()
 	_piano_velocity.append_text_item ("32");
 	_piano_velocity.append_text_item ("64");
 	_piano_velocity.append_text_item ("82");
+	_piano_velocity.append_text_item ("96");
 	_piano_velocity.append_text_item ("100");
 	_piano_velocity.append_text_item ("127");
 #endif
@@ -157,7 +160,7 @@ VirtualKeyboardWindow::VirtualKeyboardWindow ()
 
 		_cc_key[i].StateChanged.connect (sigc::bind (sigc::mem_fun (*this, &VirtualKeyboardWindow::cc_key_changed), i));
 		_cc[i]->ValueChanged.connect_same_thread (_cc_connections,
-		                                          boost::bind (&VirtualKeyboardWindow::control_change_knob_event_handler, this, i, _1));
+		                                          std::bind (&VirtualKeyboardWindow::control_change_knob_event_handler, this, i, _1));
 
 		update_cc (i, default_cc[i]);
 	}
@@ -200,11 +203,11 @@ VirtualKeyboardWindow::VirtualKeyboardWindow ()
 	/* GUI signals */
 
 	_pitch_adjustment.signal_value_changed ().connect (sigc::mem_fun (*this, &VirtualKeyboardWindow::pitch_slider_adjusted));
-	_pitchbend->ValueChanged.connect_same_thread (_cc_connections, boost::bind (&VirtualKeyboardWindow::pitch_bend_event_handler, this, _1));
+	_pitchbend->ValueChanged.connect_same_thread (_cc_connections, std::bind (&VirtualKeyboardWindow::pitch_bend_event_handler, this, _1));
 	_pitch_slider->StopGesture.connect (sigc::mem_fun (*this, &VirtualKeyboardWindow::pitch_bend_release));
 
 	_modwheel_adjustment.signal_value_changed ().connect (sigc::mem_fun (*this, &VirtualKeyboardWindow::modwheel_slider_adjusted));
-	_modwheel->ValueChanged.connect_same_thread (_cc_connections, boost::bind (&VirtualKeyboardWindow::control_change_event_handler, this, 1, _1));
+	_modwheel->ValueChanged.connect_same_thread (_cc_connections, std::bind (&VirtualKeyboardWindow::control_change_event_handler, this, 1, _1));
 
 	_piano_velocity.StateChanged.connect (sigc::mem_fun (*this, &VirtualKeyboardWindow::update_velocity_settings));
 	_piano_octave_key.StateChanged.connect (sigc::mem_fun (*this, &VirtualKeyboardWindow::update_octave_key));
@@ -614,7 +617,7 @@ VirtualKeyboardWindow::pitch_bend_event_handler (int val)
 }
 
 void
-VirtualKeyboardWindow::pitch_bend_release ()
+VirtualKeyboardWindow::pitch_bend_release (int)
 {
 	_pitch_adjustment.set_value (8192);
 }
