@@ -17,8 +17,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef __ardour_legatize_h__
-#define __ardour_legatize_h__
+#pragma once
 
 #include <string>
 
@@ -53,4 +52,3 @@ private:
 
 } /* namespace */
 
-#endif /* __ardour_legatize_h__ */
