@@ -17,8 +17,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef __libardour_midi_operator_h__
-#define __libardour_midi_operator_h__
+#pragma once
 
 #include <vector>
 #include <string>
@@ -26,6 +25,8 @@
 #include "temporal/beats.h"
 #include "evoral/Sequence.h"
 
+#include "ardour/libardour_visibility.h"
+
 namespace PBD {
 class Command;
 }
@@ -47,4 +48,3 @@ class LIBARDOUR_API MidiOperator {
 
 } /* namespace */
 
-#endif /* __libardour_midi_operator_h__ */
