@@ -21,8 +21,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef __ardour_route_group_h__
-#define __ardour_route_group_h__
+#pragma once
 
 #include <list>
 #include <set>
@@ -70,12 +69,11 @@ class Session;
  *
  * A route can at most be in one group.
  */
-class LIBARDOUR_API RouteGroup : public SessionObject
+class LIBARDOUR_API RouteGroup : public SessionObject, public std::enable_shared_from_this<RouteGroup>
 {
-public:
+  public:
 	static void make_property_quarks();
 
-	RouteGroup (Session& s, const std::string &n);
 	~RouteGroup ();
 
 	bool is_active () const { return _active.val(); }
@@ -117,13 +115,9 @@ public:
 
 	int add (std::shared_ptr<Route>);
 	int remove (std::shared_ptr<Route>);
+	void clear ();
 
-	template<typename Function>
-	void foreach_route (Function f) {
-		for (RouteList::iterator i = routes->begin(); i != routes->end(); ++i) {
-			f (i->get());
-		}
-	}
+	template<typename Function> void foreach_route (Function f) { for (auto & r : *routes) {f (r); } }
 
 	/* to use these, #include "ardour/route_group_specialized.h" */
 
@@ -133,11 +127,6 @@ public:
 
 	void audio_track_group (std::set<std::shared_ptr<AudioTrack> >& at_set);
 
-	void clear () {
-		routes->clear ();
-		changed();
-	}
-
 	bool has_subgroup() const;
 	bool can_subgroup (bool, Placement) const;
 	void make_subgroup (bool, Placement);
@@ -146,9 +135,9 @@ public:
 	std::shared_ptr<RouteList> route_list() { return routes; }
 
 	/** Emitted when a route has been added to this group */
-	PBD::Signal2<void, RouteGroup *, std::weak_ptr<ARDOUR::Route> > RouteAdded;
+	PBD::Signal<void(std::shared_ptr<RouteGroup>, std::weak_ptr<ARDOUR::Route> )> RouteAdded;
 	/** Emitted when a route has been removed from this group */
-	PBD::Signal2<void, RouteGroup *, std::weak_ptr<ARDOUR::Route> > RouteRemoved;
+	static PBD::Signal<void(std::shared_ptr<RouteGroup>, std::weak_ptr<ARDOUR::Route> )> RouteRemoved;
 
 	XMLNode& get_state () const;
 
@@ -168,7 +157,11 @@ public:
 	 * to libardour color */
 	void migrate_rgba (uint32_t color) { _rgba = color; }
 
-private:
+  protected:
+	friend class Session;
+	RouteGroup (Session& s, const std::string &n);
+
+  private:
 	std::shared_ptr<RouteList> routes;
 	std::shared_ptr<Route> _subgroup_bus;
 	std::weak_ptr<VCA> group_master;
@@ -209,4 +202,3 @@ private:
 
 } /* namespace */
 
-#endif /* __ardour_route_group_h__ */
