@@ -28,8 +28,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef __ardour_types_h__
-#define __ardour_types_h__
+#pragma once
 
 #include <bitset>
 #include <cstdint>
@@ -72,9 +71,11 @@ class Source;
 class AudioSource;
 class GraphNode;
 class Route;
+class RouteGroup;
 class Region;
 class Playlist;
 class Stripable;
+class Trigger;
 class VCA;
 class AutomationControl;
 class SlavableAutomationControl;
@@ -103,6 +104,8 @@ typedef std::map<std::shared_ptr<ARDOUR::Region>,AudioIntervalResult> AudioInter
 
 typedef std::list<std::shared_ptr<Region> > RegionList;
 typedef std::set<std::shared_ptr<Playlist> > PlaylistSet;
+typedef std::list<std::shared_ptr<RouteGroup>> RouteGroupList;
+	
 
 struct IOChange {
 
@@ -304,6 +307,7 @@ class AnyTime {
 	enum Type {
 		Timecode,
 		BBT,
+		BBT_Offset,
 		Samples,
 		Seconds
 	};
@@ -311,14 +315,21 @@ class AnyTime {
 	Type type;
 
 	Timecode::Time     timecode;
-	Temporal::BBT_Time bbt;
+	union {
+		Temporal::BBT_Time bbt;
+		Temporal::BBT_Offset bbt_offset;
+	};
 
 	union {
 		samplecnt_t     samples;
 		double         seconds;
 	};
 
-	AnyTime() { type = Samples; samples = 0; }
+	AnyTime () : type (Samples), samples (0) {}
+	AnyTime (Temporal::BBT_Offset bt) : type (BBT_Offset), bbt_offset (bt) {}
+	AnyTime (std::string const &);
+
+	std::string str() const;
 
 	bool operator== (AnyTime const & other) const {
 		if (type != other.type) { return false; }
@@ -328,6 +339,8 @@ class AnyTime {
 			return timecode == other.timecode;
 		case BBT:
 			return bbt == other.bbt;
+		case BBT_Offset:
+			return bbt_offset == other.bbt_offset;
 		case Samples:
 			return samples == other.samples;
 		case Seconds:
@@ -344,6 +357,8 @@ class AnyTime {
 				timecode.seconds != 0 || timecode.frames != 0;
 		case BBT:
 			return bbt.bars != 0 || bbt.beats != 0 || bbt.ticks != 0;
+		case BBT_Offset:
+			return bbt_offset.bars != 0 || bbt_offset.beats != 0 || bbt_offset.ticks != 0;
 		case Samples:
 			return samples != 0;
 		case Seconds:
@@ -741,12 +756,14 @@ enum AppleNSGLViewMode {
  */
 struct RouteProcessorChange {
 	enum Type {
-		NoProcessorChange = 0x0,
-		MeterPointChange  = 0x1,
-		RealTimeChange    = 0x2,
-		GeneralChange     = 0x4,
-		SendReturnChange  = 0x8,
-		CustomPinChange   = 0x10
+		NoProcessorChange   = 0x00,
+		MeterPointChange    = 0x01,
+		RealTimeChange      = 0x02,
+		GeneralChange       = 0x04,
+		SendReturnChange    = 0x08,
+		CustomPinChange     = 0x10,
+		ParameterNameChange = 0x20,
+		PortNameChange      = 0x40
 	};
 
 	RouteProcessorChange () : type (GeneralChange), meter_visibly_changed (true)
@@ -984,6 +1001,20 @@ enum SelectionOperation {
 	SelectionExtend /* UI only operation, not core */
 };
 
+enum RecordState {
+	Disabled = 0,
+	Enabled = 1,
+	Recording = 2
+};
+
+
+/* compare to IEditController */
+enum VST3KnobMode {
+	VST3KnobPluginDefault = -1,
+	VST3KnobCircularMode = 0,
+	VST3KnobRelativCircularMode,
+	VST3KnobLinearMode
+};
 
 } // namespace ARDOUR
 
@@ -991,4 +1022,3 @@ enum SelectionOperation {
 
 using ARDOUR::samplepos_t;
 
-#endif /* __ardour_types_h__ */
