@@ -16,8 +16,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef __ardour_velocity_control_h__
-#define __ardour_velocity_control_h__
+#pragma once
 
 #include <string>
 
@@ -39,4 +38,3 @@ class LIBARDOUR_API VelocityControl : public SlavableAutomationControl {
 
 } /* namespace */
 
-#endif /* __ardour_velocity_control_h__ */
