@@ -24,7 +24,6 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <unistd.h>
 #include <cerrno>
 #include <vector>
 #include <exception>
@@ -54,7 +53,7 @@
 #include "ardour/audioengine.h"
 #include "ardour/search_paths.h"
 #include "ardour/buffer.h"
-#include "ardour/cycle_timer.h"
+#include "ardour/debug.h"
 #include "ardour/internal_send.h"
 #include "ardour/meter.h"
 #include "ardour/midi_port.h"
@@ -238,9 +237,6 @@ AudioEngine::process_callback (pframes_t nframes)
 	Glib::Threads::Mutex::Lock tm (_process_lock, Glib::Threads::TRY_LOCK);
 	Port::set_varispeed_ratio (1.0);
 
-	PT_TIMING_REF;
-	PT_TIMING_CHECK (1);
-
 	/// The number of samples that will have been processed when we've finished
 	pframes_t next_processed_samples;
 
@@ -463,7 +459,12 @@ AudioEngine::process_callback (pframes_t nframes)
 			/* fade out done */
 			PortManager::silence_outputs (nframes);
 			session_deleted = true;
+#ifdef TRACE_SETSESSION_NULL
+			_session_connections.drop_connections ();
+			_session = 0;
+#else
 			SessionHandlePtr::set_session (0);
+#endif
 			session_removal_countdown = -1; // reset to "not in progress"
 			session_remove_pending = false;
 			session_removed.signal(); // wakes up thread that initiated session removal
@@ -605,7 +606,7 @@ AudioEngine::process_callback (pframes_t nframes)
 	}
 
 	if (_silence_countdown == 0 || _session->silent()) {
-		PortManager::silence (nframes);
+		PortManager::silence (nframes, _session);
 	}
 
 #else
@@ -631,8 +632,6 @@ AudioEngine::process_callback (pframes_t nframes)
 
 	_processed_samples = next_processed_samples;
 
-	PT_TIMING_CHECK (2);
-
 	return 0;
 }
 
@@ -767,13 +766,13 @@ AudioEngine::start_hw_event_processing()
 	if (_hw_reset_event_thread == 0) {
 		_hw_reset_request_count.store (0);
 		_stop_hw_reset_processing.store (0);
-		_hw_reset_event_thread = PBD::Thread::create (boost::bind (&AudioEngine::do_reset_backend, this), "EngineWatchdog");
+		_hw_reset_event_thread = PBD::Thread::create (std::bind (&AudioEngine::do_reset_backend, this), "EngineWatchdog");
 	}
 
 	if (_hw_devicelist_update_thread == 0) {
 		_hw_devicelist_update_count.store (0);
 		_stop_hw_devicelist_processing.store (0);
-		_hw_devicelist_update_thread = PBD::Thread::create (boost::bind (&AudioEngine::do_devicelist_update, this), "DeviceList");
+		_hw_devicelist_update_thread = PBD::Thread::create (std::bind (&AudioEngine::do_devicelist_update, this), "DeviceList");
 	}
 }
 
@@ -1317,7 +1316,7 @@ AudioEngine::get_sync_offset (pframes_t& offset) const
 }
 
 int
-AudioEngine::create_process_thread (boost::function<void()> func)
+AudioEngine::create_process_thread (std::function<void()> func)
 {
 	if (!_backend) {
 		return -1;
