@@ -29,8 +29,6 @@
 #include <memory>
 #include <set>
 
-#include <boost/scoped_array.hpp>
-
 #include <glibmm/fileutils.h>
 #include <glibmm/threads.h>
 
@@ -471,7 +469,7 @@ void
 AudioRegion::connect_to_analysis_changed ()
 {
 	for (SourceList::const_iterator i = _sources.begin(); i != _sources.end(); ++i) {
-		(*i)->AnalysisChanged.connect_same_thread (*this, boost::bind (&AudioRegion::maybe_invalidate_transients, this));
+		(*i)->AnalysisChanged.connect_same_thread (*this, std::bind (&AudioRegion::maybe_invalidate_transients, this));
 	}
 }
 
@@ -489,7 +487,7 @@ AudioRegion::connect_to_header_position_offset_changed ()
 			unique_srcs.insert (*i);
 			std::shared_ptr<AudioFileSource> afs = std::dynamic_pointer_cast<AudioFileSource> (*i);
 			if (afs) {
-				afs->HeaderPositionOffsetChanged.connect_same_thread (*this, boost::bind (&AudioRegion::source_offset_changed, this));
+				afs->HeaderPositionOffsetChanged.connect_same_thread (*this, std::bind (&AudioRegion::source_offset_changed, this));
 			}
 		}
 	}
@@ -498,9 +496,9 @@ AudioRegion::connect_to_header_position_offset_changed ()
 void
 AudioRegion::listen_to_my_curves ()
 {
-	_envelope->StateChanged.connect_same_thread (*this, boost::bind (&AudioRegion::envelope_changed, this));
-	_fade_in->StateChanged.connect_same_thread (*this, boost::bind (&AudioRegion::fade_in_changed, this));
-	_fade_out->StateChanged.connect_same_thread (*this, boost::bind (&AudioRegion::fade_out_changed, this));
+	_envelope->StateChanged.connect_same_thread (*this, std::bind (&AudioRegion::envelope_changed, this));
+	_fade_in->StateChanged.connect_same_thread (*this, std::bind (&AudioRegion::fade_in_changed, this));
+	_fade_out->StateChanged.connect_same_thread (*this, std::bind (&AudioRegion::fade_out_changed, this));
 }
 
 void
@@ -521,10 +519,11 @@ AudioRegion::set_fade_before_fx (bool yn)
 		if (!has_region_fx ()) {
 			return;
 		}
+		PropertyChange pc (Properties::region_fx_changed);
 		if (!_invalidated.exchange (true)) {
-			send_change (PropertyChange (Properties::region_fx)); // trigger DiskReader overwrite
+			pc.add (Properties::region_fx); // trigger DiskReader overwrite
 		}
-		RegionFxChanged (); /* EMIT SIGNAL */
+		send_change (pc);
 	}
 }
 
@@ -727,14 +726,33 @@ AudioRegion::read_at (Sample*     buf,
 		}
 	}
 
+	/* Prevent concurrent reads for the same region
+	 * which can happen with shared playlists, or
+	 * after unfreeze of a copied playlist.
+	 *
+	 * Concurrent calls will cause issues when
+	 *  * evaluating gain/fade curves (ControlList lookup_cache)
+	 *  * evaulating regionFX
+	 *
+	 *  This lock is not usually contended, since usually
+	 *  regions are unique.
+	 *
+	 *  Note that AudioSource::read is also exclusive
+	 *  since libsndfile is not thread-safe either.
+	 *  So a more fine-grained lock strategy below
+	 *  (envelope/fades/regionFX) will not make a
+	 *  significant difference.
+	 */
+	Glib::Threads::Mutex::Lock crl (_read_lock);
+
 	Glib::Threads::Mutex::Lock cl (_cache_lock);
 	if (chan_n == 0 && _invalidated.exchange (false)) {
 		_cache_start = _cache_end = -1;
 		_cache_tail  = 0;
 	}
 
-	boost::scoped_array<gain_t> gain_array;
-	boost::scoped_array<Sample> mixdown_array;
+	std::unique_ptr<gain_t[]> gain_array;
+	std::unique_ptr<Sample[]> mixdown_array;
 
 	bool nofx = false; // apply region fades at the end
 
@@ -1041,6 +1059,8 @@ endread:
 		}
 	}
 
+	crl.release ();
+
 	/* MIX OR COPY THE REGION BODY FROM mixdown_buffer INTO buf */
 
 	samplecnt_t const N = to_read - fade_in_limit - fade_out_limit;
@@ -1603,6 +1623,18 @@ AudioRegion::fade_out_is_default () const
 	return _fade_out->size() == 2 && _fade_out->when(true) == 0 && _fade_out->when(false).samples () == 64;
 }
 
+Temporal::timepos_t
+AudioRegion::fade_in_length ()
+{
+	return _fade_in->when(false);
+}
+
+Temporal::timepos_t
+AudioRegion::fade_out_length ()
+{
+	return _fade_out->when(false);
+}
+
 void
 AudioRegion::set_default_fade_in ()
 {
@@ -2260,9 +2292,9 @@ AudioRegion::get_transients (AnalysisFeatureList& results)
 AudioIntervalResult
 AudioRegion::find_silence (Sample threshold, samplecnt_t min_length, samplecnt_t fade_length, InterThreadInfo& itt) const
 {
-	samplecnt_t const block_size = 64 * 1024;
-	boost::scoped_array<Sample> loudest (new Sample[block_size]);
-	boost::scoped_array<Sample> buf (new Sample[block_size]);
+	constexpr samplecnt_t block_size = 64 * 1024;
+	std::unique_ptr<Sample[]> loudest (new Sample[block_size]);
+	std::unique_ptr<Sample[]> buf (new Sample[block_size]);
 
 	assert (fade_length >= 0);
 	assert (min_length > 0);
@@ -2520,7 +2552,7 @@ AudioRegion::_add_plugin (std::shared_ptr<RegionFxPlugin> rfx, std::shared_ptr<R
 						if (SessionEvent::has_per_thread_pool ()) {
 							send_change (PropertyChange (Properties::region_fx)); // trigger DiskReader overwrite
 						} else {
-							_session.butler ()->delegate (boost::bind (&AudioRegion::send_change, this, PropertyChange (Properties::region_fx)));
+							_session.butler ()->delegate (std::bind (&AudioRegion::send_change, this, PropertyChange (Properties::region_fx)));
 						}
 					}
 				});
@@ -2535,8 +2567,8 @@ AudioRegion::_add_plugin (std::shared_ptr<RegionFxPlugin> rfx, std::shared_ptr<R
 				});
 	}
 
-	rfx->LatencyChanged.connect_same_thread (*this, boost::bind (&AudioRegion::fx_latency_changed, this, false));
-	rfx->TailTimeChanged.connect_same_thread (*this, boost::bind (&AudioRegion::fx_tail_changed, this, false));
+	rfx->LatencyChanged.connect_same_thread (*this, std::bind (&AudioRegion::fx_latency_changed, this, false));
+	rfx->TailTimeChanged.connect_same_thread (*this, std::bind (&AudioRegion::fx_tail_changed, this, false));
 	rfx->set_block_size (_session.get_block_size ());
 
 	if (from_set_state) {
@@ -2557,10 +2589,11 @@ AudioRegion::_add_plugin (std::shared_ptr<RegionFxPlugin> rfx, std::shared_ptr<R
 	fx_latency_changed (true);
 	fx_tail_changed (true);
 
+	PropertyChange pc (Properties::region_fx_changed);
 	if (!_invalidated.exchange (true)) {
-		send_change (PropertyChange (Properties::region_fx)); // trigger DiskReader overwrite
+		pc.add (Properties::region_fx); // trigger DiskReader overwrite
 	}
-	RegionFxChanged (); /* EMIT SIGNAL */
+	send_change (pc);
 	return true;
 }
 
@@ -2587,10 +2620,11 @@ AudioRegion::remove_plugin (std::shared_ptr<RegionFxPlugin> fx)
 	fx_latency_changed (true);
 	fx_tail_changed (true);
 
+	PropertyChange pc (Properties::region_fx_changed);
 	if (!_invalidated.exchange (true)) {
-		send_change (PropertyChange (Properties::region_fx)); // trigger DiskReader overwrite
+		pc.add (Properties::region_fx); // trigger DiskReader overwrite
 	}
-	RegionFxChanged (); /* EMIT SIGNAL */
+	send_change (pc);
 	_session.set_dirty ();
 	return true;
 }
@@ -2599,10 +2633,11 @@ void
 AudioRegion::reorder_plugins (RegionFxList const& new_order)
 {
 	Region::reorder_plugins (new_order);
+	PropertyChange pc (Properties::region_fx_changed);
 	if (!_invalidated.exchange (true)) {
-		send_change (PropertyChange (Properties::region_fx)); // trigger DiskReader overwrite
+		pc.add (Properties::region_fx); // trigger DiskReader overwrite
 	}
-	RegionFxChanged (); /* EMIT SIGNAL */
+	send_change (pc);
 }
 
 void
@@ -2656,6 +2691,12 @@ AudioRegion::apply_region_fx (BufferSet& bufs, samplepos_t start_sample, samplep
 		return;
 	}
 
+	ProcessThread* pt = 0;
+	if (!ProcessThread::have_thread_buffers ()) {
+		pt = new ProcessThread ();
+		pt->get_buffers ();
+	}
+
 	pframes_t block_size = _session.get_block_size ();
 	if (_fx_block_size != block_size) {
 		_fx_block_size = block_size;
@@ -2681,7 +2722,7 @@ AudioRegion::apply_region_fx (BufferSet& bufs, samplepos_t start_sample, samplep
 				lm.release ();
 				/* this triggers a re-read */
 				const_cast<AudioRegion*>(this)->remove_plugin (rfx);
-				return;
+				goto out;
 			}
 			remain -= run;
 			offset += run;
@@ -2702,6 +2743,12 @@ AudioRegion::apply_region_fx (BufferSet& bufs, samplepos_t start_sample, samplep
 	}
 	_fx_pos = end_sample;
 	_fx_latent_read = false;
+
+out:
+	if (pt) {
+		pt->drop_buffers ();
+		delete pt;
+	}
 }
 
 void
@@ -2718,4 +2765,3 @@ AudioRegion::ensure_length_sanity ()
 		_length = timecnt_t (timepos_t (_length.val().samples()), _length.val().position());
 	}
 }
-
