@@ -28,7 +28,6 @@
 #include <cmath>
 #include <vector>
 
-#include <unistd.h>
 #include <locale.h>
 #include <errno.h>
 
@@ -63,7 +62,7 @@ using namespace ARDOUR;
 using namespace PBD;
 
 const string                 IO::state_node_name = "IO";
-PBD::Signal1<void,ChanCount> IO::PortCountChanged;
+PBD::Signal<void(ChanCount)> IO::PortCountChanged;
 
 static std::string
 legalize_io_name (std::string n)
@@ -224,8 +223,8 @@ IO::remove_port (std::shared_ptr<Port> port, void* src)
 	ChanCount after = before;
 	after.set (port->type(), after.get (port->type()) - 1);
 
-	boost::optional<bool> const r = PortCountChanging (after); /* EMIT SIGNAL */
-	if (r.value_or (false)) {
+	std::optional<int> const r = PortCountChanging (after); /* EMIT SIGNAL */
+	if (r.value_or (0)) {
 		return -1;
 	}
 
@@ -296,8 +295,8 @@ IO::add_port (string destination, void* src, DataType type)
 	ChanCount after = before;
 	after.set (type, after.get (type) + 1);
 
-	boost::optional<bool> const r = PortCountChanging (after); /* EMIT SIGNAL */
-	if (r.value_or (false)) {
+	std::optional<int> const r = PortCountChanging (after); /* EMIT SIGNAL */
+	if (r.value_or (0)) {
 		return -1;
 	}
 
@@ -501,7 +500,7 @@ IO::reestablish_port_subscriptions ()
 {
 	_port_connections.drop_connections ();
 	for (auto const& p : *ports ()) {
-		p->ConnectedOrDisconnected.connect_same_thread (*this, boost::bind (&IO::connection_change, this, _1, _2));
+		p->ConnectedOrDisconnected.connect_same_thread (*this, std::bind (&IO::connection_change, this, _1, _2));
 	}
 }
 
@@ -1338,7 +1337,6 @@ IO::bundle_changed (Bundle::Change /*c*/)
 string
 IO::build_legal_port_name (std::shared_ptr<PortSet const> ports, DataType type)
 {
-	const int name_size = AudioEngine::instance()->port_name_size();
 	int limit;
 	string suffix;
 
@@ -1372,21 +1370,24 @@ IO::build_legal_port_name (std::shared_ptr<PortSet const> ports, DataType type)
 
 	// allow up to 4 digits for the output port number, plus the slash, suffix and extra space
 
+	uint32_t name_size = AudioEngine::instance()->port_name_size();
 	limit = name_size - AudioEngine::instance()->my_name().length() - (suffix.length() + 5);
 
-	std::vector<char> buf1(name_size+1);
-	std::vector<char> buf2(name_size+1);
+	++name_size; // allow for \0
+
+	std::unique_ptr<char[]> buf1 (new char[name_size]);
+	std::unique_ptr<char[]> buf2 (new char[name_size]);
 
 	/* colons are illegal in port names, so fix that */
 
 	string nom = legalize_io_name (_name.val());
 
-	snprintf (&buf1[0], name_size+1, ("%.*s/%s"), limit, nom.c_str(), suffix.c_str());
+	std::snprintf (buf1.get(), name_size, ("%.*s/%s"), limit, nom.c_str(), suffix.c_str());
 
-	int port_number = find_port_hole (ports, &buf1[0]);
-	snprintf (&buf2[0], name_size+1, "%s %d", &buf1[0], port_number);
+	int port_number = find_port_hole (ports, buf1.get ());
+	std::snprintf (buf2.get(), name_size, "%s %d", buf1.get (), port_number);
 
-	return string (&buf2[0]);
+	return string (buf2.get ());
 }
 
 int32_t
@@ -1400,17 +1401,17 @@ IO::find_port_hole (std::shared_ptr<PortSet const> ports, const char* base)
 		return 1;
 	}
 
-	/* we only allow up to 4 characters for the port number
-	 */
+	uint32_t const name_size = AudioEngine::instance()->port_name_size() + 1;
 
+	/* we only allow up to 4 characters for the port number */
 	for (n = 1; n < 9999; ++n) {
-		std::vector<char> buf (AudioEngine::instance()->port_name_size());
 		PortSet::const_iterator i = ports->begin ();
 
-		snprintf (&buf[0], buf.size()+1, _("%s %u"), base, n);
+		std::unique_ptr<char[]> buf (new char[name_size]);
+		std::snprintf (buf.get (), name_size, "%s %u", base, n);
 
 		for ( ; i != ports->end (); ++i) {
-			if (string (i->name()) == string (&buf[0])) {
+			if (string (i->name()) == string (buf.get ())) {
 				break;
 			}
 		}
@@ -1506,7 +1507,7 @@ IO::bundles_connected ()
 IO::UserBundleInfo::UserBundleInfo (IO* io, std::shared_ptr<UserBundle> b)
 {
 	bundle = b;
-	b->Changed.connect_same_thread (changed, boost::bind (&IO::bundle_changed, io, _1));
+	b->Changed.connect_same_thread (changed, std::bind (&IO::bundle_changed, io, _1));
 }
 
 std::string
@@ -1526,13 +1527,13 @@ IO::bundle_channel_name (uint32_t c, uint32_t n, DataType t) const
 		case 2:
 			return c == 0 ? _("L") : _("R");
 		default:
-			snprintf (buf, sizeof(buf), "%d", (c + 1));
+			std::snprintf (buf, sizeof(buf), "%d", (c + 1));
 			return buf;
 		}
 
 	} else {
 
-		snprintf (buf, sizeof(buf), "%d", (c + 1));
+		std::snprintf (buf, sizeof(buf), "%d", (c + 1));
 		return buf;
 
 	}
