@@ -20,7 +20,6 @@
 #include <iostream>
 #include <errno.h>
 #include <sys/types.h>
-#include <unistd.h>
 
 #include "pbd/error.h"
 #include "pbd/failed_constructor.h"
@@ -63,7 +62,7 @@ LTC_TransportMaster::LTC_TransportMaster (std::string const & name)
 {
 	memset (&prev_frame, 0, sizeof(LTCFrameExt));
 
-	AudioEngine::instance()->Xrun.connect_same_thread (port_connection, boost::bind (&LTC_TransportMaster::resync_xrun, this));
+	AudioEngine::instance()->Xrun.connect_same_thread (port_connection, std::bind (&LTC_TransportMaster::resync_xrun, this));
 
 }
 
@@ -115,8 +114,8 @@ LTC_TransportMaster::set_session (Session *s)
 
 		fps_detected = false;
 
-		_session->config.ParameterChanged.connect_same_thread (session_connections, boost::bind (&LTC_TransportMaster::parameter_changed, this, _1));
-		_session->LatencyUpdated.connect_same_thread (session_connections, boost::bind (&LTC_TransportMaster::resync_latency, this, _1));
+		_session->config.ParameterChanged.connect_same_thread (session_connections, std::bind (&LTC_TransportMaster::parameter_changed, this, _1));
+		_session->LatencyUpdated.connect_same_thread (session_connections, std::bind (&LTC_TransportMaster::resync_latency, this, _1));
 	} else {
 		_filter_enable = false;
 	}
@@ -564,7 +563,7 @@ LTC_TransportMaster::process_ltc(samplepos_t const now)
 }
 
 void
-LTC_TransportMaster::pre_process (ARDOUR::pframes_t nframes, samplepos_t now, boost::optional<samplepos_t> session_pos)
+LTC_TransportMaster::pre_process (ARDOUR::pframes_t nframes, samplepos_t now, std::optional<samplepos_t> session_pos)
 {
 	if (!_port) {
 		reset (true);
