@@ -118,8 +118,9 @@
 #include <Carbon/Carbon.h>
 #endif
 
-#ifdef VST3_SUPPORT
 #include "ardour/system_exec.h"
+
+#ifdef VST3_SUPPORT
 #include "ardour/vst3_module.h"
 #include "ardour/vst3_plugin.h"
 #include "ardour/vst3_scan.h"
@@ -330,7 +331,7 @@ PluginManager::PluginManager ()
 
 	BootMessage (_("Discovering Plugins"));
 
-	LuaScripting::instance().scripts_changed.connect_same_thread (lua_refresh_connection, boost::bind (&PluginManager::lua_refresh_cb, this));
+	LuaScripting::instance().scripts_changed.connect_same_thread (lua_refresh_connection, std::bind (&PluginManager::lua_refresh_cb, this));
 }
 
 
@@ -360,7 +361,7 @@ PluginManager::cache_valid () const
 uint32_t
 PluginManager::cache_version ()
 {
-	return 1000 * atoi (X_(PROGRAM_VERSION)) + 2;
+	return 7002; // 1000 * atoi (X_(PROGRAM_VERSION)) + 2;
 }
 
 struct PluginInfoPtrNameSorter {
@@ -610,18 +611,8 @@ PluginManager::refresh (bool cache_only)
 }
 
 void
-PluginManager::detect_ambiguities ()
+PluginManager::get_all_plugins (PluginInfoList& all_plugs) const
 {
-	detect_name_ambiguities (_windows_vst_plugin_info);
-	detect_name_ambiguities (_lxvst_plugin_info);
-	detect_name_ambiguities (_mac_vst_plugin_info);
-	detect_name_ambiguities (_au_plugin_info);
-	detect_name_ambiguities (_ladspa_plugin_info);
-	detect_name_ambiguities (_lv2_plugin_info);
-	detect_name_ambiguities (_lua_plugin_info);
-	detect_name_ambiguities (_vst3_plugin_info);
-
-	PluginInfoList all_plugs;
 	if (_windows_vst_plugin_info) {
 		all_plugs.insert(all_plugs.end(), _windows_vst_plugin_info->begin(), _windows_vst_plugin_info->end());
 	}
@@ -646,6 +637,22 @@ PluginManager::detect_ambiguities ()
 	if (_lua_plugin_info) {
 		all_plugs.insert(all_plugs.end(), _lua_plugin_info->begin(), _lua_plugin_info->end());
 	}
+}
+
+void
+PluginManager::detect_ambiguities ()
+{
+	detect_name_ambiguities (_windows_vst_plugin_info);
+	detect_name_ambiguities (_lxvst_plugin_info);
+	detect_name_ambiguities (_mac_vst_plugin_info);
+	detect_name_ambiguities (_au_plugin_info);
+	detect_name_ambiguities (_ladspa_plugin_info);
+	detect_name_ambiguities (_lv2_plugin_info);
+	detect_name_ambiguities (_lua_plugin_info);
+	detect_name_ambiguities (_vst3_plugin_info);
+
+	PluginInfoList all_plugs;
+	get_all_plugins (all_plugs);
 	detect_type_ambiguities (all_plugs);
 
 	save_scanlog ();
@@ -1079,6 +1086,14 @@ PluginManager::get_ladspa_category (uint32_t plugin_id)
 void
 PluginManager::lv2_plugin (std::string const& uri, PluginScanLogEntry::PluginScanResult sr, std::string const& msg, bool reset)
 {
+	if (reset && msg.empty ()) {
+		PluginScanLog::iterator j = _plugin_scan_log.find (PSLEPtr (new PluginScanLogEntry (LV2, uri)));
+		if (j != _plugin_scan_log.end ()) {
+			_plugin_scan_log.erase (j);
+		}
+		return;
+	}
+
 	PSLEPtr psle (scan_log_entry (LV2, uri));
 	if (reset) {
 		psle->reset ();
@@ -1190,7 +1205,7 @@ PluginManager::run_auv2_scanner_app (CAComponentDescription const& desc, AUv2Des
 	stringstream scan_log;
 	ARDOUR::SystemExec scanner (auv2_scanner_bin_path, argp);
 	PBD::ScopedConnection c;
-	scanner.ReadStdout.connect_same_thread (c, boost::bind (&auv2_scanner_log, _1, &scan_log));
+	scanner.ReadStdout.connect_same_thread (c, std::bind (&auv2_scanner_log, _1, &scan_log));
 
 	if (scanner.start (ARDOUR::SystemExec::MergeWithStdin)) {
 		psle->msg (PluginScanLogEntry::Error, string_compose (_("Cannot launch AU scanner app '%1': %2"), auv2_scanner_bin_path, strerror (errno)));
@@ -1486,7 +1501,7 @@ PluginManager::run_vst2_scanner_app (std::string path, PSLEPtr psle) const
 	stringstream scan_log;
 	ARDOUR::SystemExec scanner (vst2_scanner_bin_path, argp);
 	PBD::ScopedConnection c;
-	scanner.ReadStdout.connect_same_thread (c, boost::bind (&vst2_scanner_log, _1, &scan_log));
+	scanner.ReadStdout.connect_same_thread (c, std::bind (&vst2_scanner_log, _1, &scan_log));
 
 	if (scanner.start (ARDOUR::SystemExec::MergeWithStdin)) {
 		psle->msg (PluginScanLogEntry::Error, string_compose (_("Cannot launch VST scanner app '%1': %2"), vst2_scanner_bin_path, strerror (errno)));
@@ -1787,13 +1802,14 @@ PluginManager::windows_vst_discover_from_path (string path, bool cache_only)
 void
 PluginManager::mac_vst_refresh (bool cache_only)
 {
+	std::set<std::string> scanned_paths;
 	if (_mac_vst_plugin_info) {
 		_mac_vst_plugin_info->clear ();
 	} else {
 		_mac_vst_plugin_info = new ARDOUR::PluginInfoList();
 	}
 
-	mac_vst_discover_from_path ("~/Library/Audio/Plug-Ins/VST:/Library/Audio/Plug-Ins/VST", cache_only);
+	mac_vst_discover_from_path ("~/Library/Audio/Plug-Ins/VST:/Library/Audio/Plug-Ins/VST", scanned_paths, cache_only);
 	if (!cache_only) {
 		/* ensure that VST path is flushed to disk */
 		Config->save_state();
@@ -1810,7 +1826,7 @@ static bool mac_vst_filter (const string& str)
 }
 
 int
-PluginManager::mac_vst_discover_from_path (string path, bool cache_only)
+PluginManager::mac_vst_discover_from_path (string path, std::set<std::string>& scanned_paths, bool cache_only)
 {
 	vector<string> plugin_objects;
 	vector<string>::iterator x;
@@ -1820,6 +1836,11 @@ PluginManager::mac_vst_discover_from_path (string path, bool cache_only)
 		return -1;
 	}
 
+	if (scanned_paths.find (path) != scanned_paths.end ()) {
+		return 0;
+	}
+	scanned_paths.insert (path);
+
 	Searchpath paths (path);
 	/* customized version of run_functor_for_paths() */
 	for (vector<string>::const_iterator i = paths.begin(); i != paths.end(); ++i) {
@@ -1846,7 +1867,7 @@ PluginManager::mac_vst_discover_from_path (string path, bool cache_only)
 				}
 
 				/* recurse */
-				mac_vst_discover_from_path (fullpath, cache_only);
+				mac_vst_discover_from_path (fullpath, scanned_paths, cache_only);
 			}
 		} catch (Glib::FileError& err) { }
 	}
@@ -2241,7 +2262,7 @@ PluginManager::run_vst3_scanner_app (std::string bundle_path, PSLEPtr psle) cons
 	stringstream scan_log;
 	ARDOUR::SystemExec scanner (vst3_scanner_bin_path, argp);
 	PBD::ScopedConnection c;
-	scanner.ReadStdout.connect_same_thread (c, boost::bind (&vst3_scanner_log, _1, &scan_log));
+	scanner.ReadStdout.connect_same_thread (c, std::bind (&vst3_scanner_log, _1, &scan_log));
 
 	if (scanner.start (ARDOUR::SystemExec::MergeWithStdin)) {
 		psle->msg (PluginScanLogEntry::Error, string_compose (_("Cannot launch VST scanner app '%1': %2"), vst3_scanner_bin_path, strerror (errno)));
@@ -2890,12 +2911,25 @@ PluginManager::get_all_tags (TagFilter tag_filter) const
 {
 	std::vector<std::string> ret;
 
+	PluginInfoList all_plugs;
+	get_all_plugins (all_plugs);
+
+	std::map<PluginType, std::set<std::string>> nfos;
+	for (auto const& nfo : all_plugs) {
+		nfos[to_generic_vst (nfo->type)].insert (nfo->unique_id);
+	}
+
 	PluginTagList::const_iterator pt;
 	for (pt = ptags.begin(); pt != ptags.end(); ++pt) {
 		if ((*pt).tags.empty ()) {
 			continue;
 		}
 
+		if (nfos[(*pt).type].find ((*pt).unique_id) == nfos[(*pt).type].end ()) {
+			/* Plugin is not installed */
+			continue;
+		}
+
 		/* if favorites_only then we need to check the info ptr and maybe skip */
 		if (tag_filter == OnlyFavorites) {
 			PluginStatus stat ((*pt).type, (*pt).unique_id);
@@ -2983,8 +3017,11 @@ PluginManager::ladspa_plugin_info ()
 const ARDOUR::PluginInfoList&
 PluginManager::lv2_plugin_info ()
 {
+#ifdef LV2_SUPPORT
 	assert(_lv2_plugin_info);
 	return *_lv2_plugin_info;
+#endif
+	return _empty_plugin_info;
 }
 
 const ARDOUR::PluginInfoList&
