@@ -37,6 +37,7 @@
 #include "ardour/route.h"
 #include "ardour/route_group.h"
 #include "ardour/session.h"
+#include "ardour/surround_send.h"
 #include "ardour/vca.h"
 #include "ardour/vca_manager.h"
 
@@ -54,6 +55,7 @@ namespace ARDOUR {
 		PropertyDescriptor<bool> group_mute;
 		PropertyDescriptor<bool> group_solo;
 		PropertyDescriptor<bool> group_recenable;
+		PropertyDescriptor<bool> group_sursend_enable;
 		PropertyDescriptor<bool> group_select;
 		PropertyDescriptor<bool> group_route_active;
 		PropertyDescriptor<bool> group_color;
@@ -62,6 +64,8 @@ namespace ARDOUR {
 	}
 }
 
+PBD::Signal<void(std::shared_ptr<RouteGroup>, std::weak_ptr<ARDOUR::Route> )> RouteGroup::RouteRemoved;
+
 void
 RouteGroup::make_property_quarks ()
 {
@@ -78,6 +82,8 @@ RouteGroup::make_property_quarks ()
 	DEBUG_TRACE (DEBUG::Properties, string_compose ("quark for solo = %1\n", Properties::group_solo.property_id));
 	Properties::group_recenable.property_id = g_quark_from_static_string (X_("recenable"));
 	DEBUG_TRACE (DEBUG::Properties, string_compose ("quark for recenable = %1\n", Properties::group_recenable.property_id));
+	Properties::group_sursend_enable.property_id = g_quark_from_static_string (X_("sursend_enable"));
+	DEBUG_TRACE (DEBUG::Properties, string_compose ("quark for sursend_enable = %1\n", Properties::group_sursend_enable.property_id));
 	Properties::group_select.property_id = g_quark_from_static_string (X_("select"));
 	DEBUG_TRACE (DEBUG::Properties, string_compose ("quark for select = %1\n", Properties::group_select.property_id));
 	Properties::group_route_active.property_id = g_quark_from_static_string (X_("route-active"));
@@ -97,6 +103,7 @@ RouteGroup::make_property_quarks ()
 	, _mute (Properties::group_mute, true) \
 	, _solo (Properties::group_solo, true) \
 	, _recenable (Properties::group_recenable, true) \
+	, _sursend_enable (Properties::group_sursend_enable, true) \
 	, _select (Properties::group_select, true) \
 	, _route_active (Properties::group_route_active, true) \
 	, _color (Properties::group_color, true) \
@@ -110,6 +117,7 @@ RouteGroup::RouteGroup (Session& s, const string &n)
 	, _solo_group (new ControlGroup (SoloAutomation))
 	, _mute_group (new ControlGroup (MuteAutomation))
 	, _rec_enable_group (new ControlGroup (RecEnableAutomation))
+	, _sursend_enable_group (new ControlGroup (BusSendEnable))
 	, _gain_group (new GainControlGroup ())
 	, _monitoring_group (new ControlGroup (MonitoringAutomation))
 	, _rgba (0)
@@ -124,11 +132,14 @@ RouteGroup::RouteGroup (Session& s, const string &n)
 	add_property (_mute);
 	add_property (_solo);
 	add_property (_recenable);
+	add_property (_sursend_enable);
 	add_property (_select);
 	add_property (_route_active);
 	add_property (_color);
 	add_property (_monitoring);
 	add_property (_group_master_number);
+
+	s.SurroundMasterAddedOrRemoved.connect_same_thread (*this, std::bind (&RouteGroup::update_surround_sends, this));
 }
 
 RouteGroup::~RouteGroup ()
@@ -137,6 +148,7 @@ RouteGroup::~RouteGroup ()
 	_mute_group->clear ();
 	_gain_group->clear ();
 	_rec_enable_group->clear ();
+	_sursend_enable_group->clear ();
 	_monitoring_group->clear ();
 
 	std::shared_ptr<VCA> vca (group_master.lock());
@@ -184,8 +196,12 @@ RouteGroup::add (std::shared_ptr<Route> r)
 		_monitoring_group->add_control (trk->monitoring_control());
 	}
 
-	r->set_route_group (this);
-	r->DropReferences.connect_same_thread (*this, boost::bind (&RouteGroup::remove_when_going_away, this, std::weak_ptr<Route> (r)));
+	if (r->surround_send ()) {
+		_sursend_enable_group->add_control (r->surround_send ()->send_enable_control ());
+	}
+
+	r->set_route_group (shared_from_this());
+	r->DropReferences.connect_same_thread (*this, std::bind (&RouteGroup::remove_when_going_away, this, std::weak_ptr<Route> (r)));
 
 	std::shared_ptr<VCA> vca (group_master.lock());
 
@@ -194,7 +210,7 @@ RouteGroup::add (std::shared_ptr<Route> r)
 	}
 
 	_session.set_dirty ();
-	RouteAdded (this, std::weak_ptr<Route> (r)); /* EMIT SIGNAL */
+	RouteAdded (shared_from_this(), std::weak_ptr<Route> (r)); /* EMIT SIGNAL */
 	return 0;
 }
 
@@ -208,6 +224,17 @@ RouteGroup::remove_when_going_away (std::weak_ptr<Route> wr)
 	}
 }
 
+void
+RouteGroup::update_surround_sends ()
+{
+	for (auto const& r : *routes) {
+		if (r->surround_send ()) {
+			_sursend_enable_group->add_control (r->surround_send ()->send_enable_control ());
+		}
+		// Note: ctrl is removed via DropReferences
+	}
+}
+
 void
 RouteGroup::unset_subgroup_bus ()
 {
@@ -217,6 +244,18 @@ RouteGroup::unset_subgroup_bus ()
 	_subgroup_bus.reset ();
 }
 
+void
+RouteGroup::clear ()
+{
+	RouteList copy (*routes);
+
+	for (auto & r : copy) {
+		remove (r);
+	}
+
+	changed ();
+}
+
 int
 RouteGroup::remove (std::shared_ptr<Route> r)
 {
@@ -239,9 +278,17 @@ RouteGroup::remove (std::shared_ptr<Route> r)
 			_rec_enable_group->remove_control (trk->rec_enable_control());
 			_monitoring_group->remove_control (trk->monitoring_control());
 		}
+		if (r->surround_send ()) {
+			_sursend_enable_group->remove_control (r->surround_send ()->send_enable_control ());
+		}
 		routes->erase (i);
+		if (routes->empty()) {
+			_subgroup_bus.reset ();
+			group_master.reset ();
+			_group_master_number = -1;
+		}
 		_session.set_dirty ();
-		RouteRemoved (this, std::weak_ptr<Route> (r)); /* EMIT SIGNAL */
+		RouteRemoved (shared_from_this(), std::weak_ptr<Route> (r)); /* EMIT SIGNAL */
 		return 0;
 	}
 
@@ -325,7 +372,7 @@ RouteGroup::set_state (const XMLNode& node, int version)
 		std::shared_ptr<Route> r = _session.route_by_id (subgroup_id);
 		if (r) {
 			_subgroup_bus = r;
-			_subgroup_bus->DropReferences.connect_same_thread (*this, boost::bind (&RouteGroup::unset_subgroup_bus, this));
+			_subgroup_bus->DropReferences.connect_same_thread (*this, std::bind (&RouteGroup::unset_subgroup_bus, this));
 		}
 	}
 
@@ -419,6 +466,17 @@ RouteGroup::set_recenable (bool yn)
 	send_change (PropertyChange (Properties::group_recenable));
 }
 
+void
+RouteGroup::set_sursend_enable (bool yn)
+{
+	if (is_sursend_enable() == yn) {
+		return;
+	}
+	_sursend_enable = yn;
+	_sursend_enable_group->set_active (yn);
+	send_change (PropertyChange (Properties::group_sursend_enable));
+}
+
 void
 RouteGroup::set_select (bool yn)
 {
@@ -652,7 +710,7 @@ RouteGroup::make_subgroup (bool aux, Placement placement)
 
 	_subgroup_bus = rl.front();
 	_subgroup_bus->set_name (_name);
-	_subgroup_bus->DropReferences.connect_same_thread (*this, boost::bind (&RouteGroup::unset_subgroup_bus, this));
+	_subgroup_bus->DropReferences.connect_same_thread (*this, std::bind (&RouteGroup::unset_subgroup_bus, this));
 
 	if (aux) {
 
@@ -722,13 +780,14 @@ RouteGroup::push_to_groups ()
 		_solo_group->set_active (is_solo());
 		_mute_group->set_active (is_mute());
 		_rec_enable_group->set_active (is_recenable());
+		_sursend_enable_group->set_active (is_sursend_enable());
 		_monitoring_group->set_active (is_monitoring());
 	} else {
 		_gain_group->set_active (false);
 		_solo_group->set_active (false);
 		_mute_group->set_active (false);
-
 		_rec_enable_group->set_active (false);
+		_sursend_enable_group->set_active (false);
 		_monitoring_group->set_active (false);
 	}
 }
