@@ -29,8 +29,6 @@
 #include <memory>
 #include <string>
 
-#include <unistd.h>
-
 #include <glibmm/main.h>
 
 #include "midi++/mmc.h"
@@ -207,21 +205,14 @@ Session::mmc_step (MIDI::MachineControl &/*mmc*/, int steps)
 		return;
 	}
 
-	struct timeval now;
-	struct timeval diff = { 0, 0 };
+	int64_t now  = g_get_monotonic_time ();
+	int64_t diff = now - _last_mmc_step;
 
-	gettimeofday (&now, 0);
-
-	timersub (&now, &last_mmc_step, &diff);
-
-	gettimeofday (&now, 0);
-	timersub (&now, &last_mmc_step, &diff);
-
-	if (last_mmc_step.tv_sec != 0 && (diff.tv_usec + (diff.tv_sec * 1000000)) < _engine.usecs_per_cycle()) {
+	if (_last_mmc_step != 0 && diff < _engine.usecs_per_cycle()) {
 		return;
 	}
 
-	double diff_secs = diff.tv_sec + (diff.tv_usec / 1000000.0);
+	double diff_secs = diff * 1e-6;
 	double cur_speed = (((steps * 0.5) * timecode_frames_per_second()) / diff_secs) / timecode_frames_per_second();
 
 	if (_transport_fsm->transport_speed() == 0 || cur_speed * _transport_fsm->transport_speed() < 0) {
@@ -243,7 +234,7 @@ Session::mmc_step (MIDI::MachineControl &/*mmc*/, int steps)
 #endif
 
 	request_transport_speed_nonzero (step_speed);
-	last_mmc_step = now;
+	_last_mmc_step = now;
 
 	if (!step_queued) {
 		if (midi_control_ui) {
@@ -654,15 +645,9 @@ Session::send_immediate_mmc (MachineControlCommand c)
 bool
 Session::mmc_step_timeout ()
 {
-	struct timeval now;
-	struct timeval diff;
-	double diff_usecs;
-	gettimeofday (&now, 0);
+	int64_t diff_usecs = g_get_monotonic_time () - _last_mmc_step;
 
-	timersub (&now, &last_mmc_step, &diff);
-	diff_usecs = diff.tv_sec * 1000000 + diff.tv_usec;
-
-	if (diff_usecs > 1000000.0 || fabs (_transport_fsm->transport_speed()) < 0.0000001) {
+	if (diff_usecs > 1000000 || fabs (_transport_fsm->transport_speed()) < 0.0000001) {
 		/* too long or too slow, stop transport */
 		request_stop ();
 		step_queued = false;
@@ -830,7 +815,7 @@ Session::rewire_selected_midi (std::shared_ptr<MidiTrack> new_midi_target)
 			/* connect it to the new target */
 			new_midi_target->input()->connect (new_midi_target->input()->nth(0), (*p), this);
 			/* and grouped tracks */
-			RouteGroup* group = new_midi_target->route_group ();
+			std::shared_ptr<RouteGroup> group = new_midi_target->route_group ();
 			if (group && group->is_active () && group->is_select ()) {
 				for (auto const& r : *group->route_list ()) {
 					if (dynamic_pointer_cast<MidiTrack> (r)) {
@@ -874,7 +859,7 @@ Session::rewire_midi_selection_ports ()
 		disconnect_port_for_rewire (*p);
 		target->input()->connect (target->input()->nth (0), (*p), this);
 
-		RouteGroup* group = target->route_group ();
+		std::shared_ptr<RouteGroup> group = target->route_group ();
 		if (group && group->is_active () && group->is_select ()) {
 			for (auto const& r : *group->route_list ()) {
 				if (dynamic_pointer_cast<MidiTrack> (r)) {
