@@ -30,7 +30,6 @@
 
 #include <cmath>
 #include <cerrno>
-#include <unistd.h>
 
 #include "pbd/atomic.h"
 #include "pbd/error.h"
@@ -153,6 +152,10 @@ Session::realtime_stop (bool abort, bool clear_state)
 		waiting_for_sync_offset = true;
 	}
 
+	if (todo & PostTransportClearSubstate) {
+		roll_started_loop = false;
+	}
+
 	if (todo) {
 		TFSM_EVENT (TransportFSM::ButlerRequired);
 	}
@@ -190,7 +193,7 @@ Session::locate (samplepos_t target_sample, bool for_loop_end, bool force, bool
 
 	// Update Timecode time
 	_transport_sample = target_sample;
-	_nominal_jack_transport_sample = boost::none;
+	_nominal_jack_transport_sample = std::nullopt;
 
 	/* Note that loop wrap-around locates do not need to call "seek" */
 	if (force || !for_loop_end) {
@@ -475,6 +478,17 @@ Session::start_transport (bool after_loop)
 	ENSURE_PROCESS_THREAD;
 	DEBUG_TRACE (DEBUG::Transport, "start_transport\n");
 
+	if (!after_loop && !roll_started_loop && !_exporting
+	    && Config->get_roll_will_loop ()
+	    && !get_play_loop ()
+	    && !transport_master_is_external ()
+	    && _locations->auto_loop_location ()) {
+		roll_started_loop = true;
+		SessionEvent* ev = new SessionEvent (SessionEvent::SetLoop, SessionEvent::Add, SessionEvent::Immediate, 0, _transport_fsm->default_speed(), true, true);
+		queue_event (ev);
+		return;
+	}
+
 	if (Config->get_loop_is_mode() && get_play_loop ()) {
 
 		Location *location = _locations->auto_loop_location();
@@ -782,9 +796,16 @@ bool
 Session::should_ignore_transport_request (TransportRequestSource src, TransportRequestType type)
 {
 	if (config.get_external_sync()) {
+		if (src != TRS_UI) {
+			/* always allow requests from the Master */
+			return false;
+		}
 		if (TransportMasterManager::instance().current()->allow_request (src, type)) {
 			/* accepting a command means dropping external sync first */
 			config.set_external_sync (false);
+			return false;
+		} else {
+			/* not allowed, ignore event */
 			return true;
 		}
 	}
@@ -899,8 +920,27 @@ Session::request_stop (bool abort, bool clear_state, TransportRequestSource orig
 		solo_selection ( _soloSelection, false );
 	}
 
-	SessionEvent* ev = new SessionEvent (SessionEvent::EndRoll, SessionEvent::Add, SessionEvent::Immediate, audible_sample(), 0.0, abort, clear_state);
-	DEBUG_TRACE (DEBUG::Transport, string_compose ("Request transport stop, audible %3 transport %4 abort = %1, clear state = %2\n", abort, clear_state, audible_sample(), _transport_sample));
+	SessionEvent *ev;
+
+	if (Config->get_stop_on_grid() && _global_quantization.type == AnyTime::BBT_Offset && _transport_sample != 0) {
+		/* XXX for now this only does anything if we are quantized to
+		 * Beats. Other quantization settings require moving
+		 * Editor::snap_to() code into libardour, which is not in-scope
+		 * at the time this work is occuring.
+		 */
+
+		TempoMap::SharedPtr tmap (TempoMap::use());
+		BBT_Argument now = tmap->bbt_at (timepos_t (_transport_sample));
+		BBT_Argument rounded = tmap->round_up_to_bar (now);
+		samplepos_t samples = tmap->sample_at (rounded);
+
+		ev = new SessionEvent (SessionEvent::EndRoll, SessionEvent::Add, samples, samples, 0.0, abort, clear_state);
+		DEBUG_TRACE (DEBUG::Transport, string_compose ("Request transport stop @ %4 snapped to %1 => %2 => %3\n", samples, now, rounded, _transport_sample));
+	} else {
+		ev = new SessionEvent (SessionEvent::EndRoll, SessionEvent::Add, SessionEvent::Immediate, audible_sample(), 0.0, abort, clear_state);
+		DEBUG_TRACE (DEBUG::Transport, string_compose ("Request transport stop, audible %3 transport %4 abort = %1, clear state = %2\n", abort, clear_state, audible_sample(), _transport_sample));
+	}
+
 	queue_event (ev);
 }
 
@@ -960,6 +1000,21 @@ Session::force_locate (samplepos_t target_sample, LocateTransportDisposition ltd
 	queue_event (ev);
 }
 
+bool
+Session::request_locate_to_mark (std::string const& name, LocateTransportDisposition ltd, TransportRequestSource origin)
+{
+	for (auto const& l : locations()->list()) {
+		if (!l->is_mark() || l->is_hidden() || l->is_session_range()) {
+			continue;
+		}
+		if (l->name () == name) {
+			request_locate (l->start_sample(), false, ltd, origin);
+			return true;
+		}
+	}
+	return false;
+}
+
 void
 Session::unset_preroll_record_trim ()
 {
@@ -1522,7 +1577,9 @@ Session::non_realtime_stop (bool abort, int on_entry, bool& finished, bool will_
 
 	if (ptw & (PostTransportClearSubstate|PostTransportStop)) {
 		if (!Config->get_loop_is_mode() && get_play_loop() && !loop_changing) {
-			unset_play_loop ();
+			if (!Config->get_roll_will_loop () || (ptw & PostTransportClearSubstate)) {
+				unset_play_loop ();
+			}
 		}
 	}
 
@@ -1598,6 +1655,10 @@ Session::non_realtime_stop (bool abort, int on_entry, bool& finished, bool will_
 		}
 	}
 
+	if (!abort && did_record) {
+		RecordPassCompleted (); /* EMIT SIGNAL */
+	}
+
 	/* save the current state of things if appropriate */
 
 	if (did_record && !saved) {
@@ -1869,6 +1930,17 @@ Session::engine_running ()
 {
 	_transport_fsm->start ();
 	reset_xrun_count ();
+
+	if (_engine_state && Config->get_restore_hardware_connections ()) {
+		/* Note this restores the connections from the most recent [pending] save.
+		 * Which may or may not be idendical to the ones used before the engine 
+		 * re-started.
+		 */
+		std::shared_ptr<AudioBackend> backend = _engine.current_backend();
+		for (auto const& s: _engine_state->children ()) {
+			backend->set_state (*s, Stateful::loading_state_version);
+		}
+	}
 }
 
 void
@@ -1923,21 +1995,25 @@ Session::route_processors_changed (RouteProcessorChange c)
 		return;
 	}
 
-	if (c.type == RouteProcessorChange::MeterPointChange) {
-		/* sort rec-armed routes first */
+	if (c.type == RouteProcessorChange::NoProcessorChange) {
+		return;
+	}
+
+	if (c.type & RouteProcessorChange::MeterPointChange) {
+		/* sort rec-armed routes to be processed first */
 		resort_routes ();
 		set_dirty ();
 		return;
 	}
 
-	if (c.type == RouteProcessorChange::RealTimeChange) {
+	if (c.type & RouteProcessorChange::RealTimeChange) {
 		set_dirty ();
 		return;
 	}
 
 	resort_routes ();
 
-	if (c.type == RouteProcessorChange::SendReturnChange) {
+	if (c.type & RouteProcessorChange::SendReturnChange) {
 		update_latency_compensation (true, false);
 	} else {
 		update_latency_compensation (false, false);
@@ -2034,7 +2110,7 @@ Session::sync_source_changed (SyncSource type, samplepos_t pos, pframes_t cycle_
 	std::shared_ptr<MTC_TransportMaster> mtc_master = std::dynamic_pointer_cast<MTC_TransportMaster> (master);
 
 	if (mtc_master) {
-		mtc_master->ActiveChanged.connect_same_thread (mtc_status_connection, boost::bind (&Session::mtc_status_changed, this, _1));
+		mtc_master->ActiveChanged.connect_same_thread (mtc_status_connection, std::bind (&Session::mtc_status_changed, this, _1));
 		MTCSyncStateChanged(mtc_master->locked() );
 	} else {
 		int canderef (1);
@@ -2047,7 +2123,7 @@ Session::sync_source_changed (SyncSource type, samplepos_t pos, pframes_t cycle_
 	std::shared_ptr<LTC_TransportMaster> ltc_master = std::dynamic_pointer_cast<LTC_TransportMaster> (master);
 
 	if (ltc_master) {
-		ltc_master->ActiveChanged.connect_same_thread (ltc_status_connection, boost::bind (&Session::ltc_status_changed, this, _1));
+		ltc_master->ActiveChanged.connect_same_thread (ltc_status_connection, std::bind (&Session::ltc_status_changed, this, _1));
 		LTCSyncStateChanged (ltc_master->locked() );
 	} else {
 		int canderef (1);
@@ -2166,7 +2242,8 @@ Session::flush_cue_recording ()
 
 	while (TriggerBox::cue_records.read (&cr, 1) == 1) {
 		BBT_Argument bbt = tmap->bbt_at (timepos_t (cr.when));
-		bbt = BBT_Argument (bbt.reference(), bbt.round_up_to_bar ());
+		Meter const & meter (tmap->meter_at (timepos_t (cr.when)));
+		bbt = BBT_Argument (bbt.reference(), meter.round_up_to_bar (bbt));
 
 		const timepos_t when (tmap->quarters_at (bbt));
 
