@@ -141,17 +141,17 @@ Track::init ()
 		set_name (name ());
 	}
 
-	_session.config.ParameterChanged.connect_same_thread (*this, boost::bind (&Track::parameter_changed, this, _1));
-	_session.RecordStateChanged.connect_same_thread (*this, boost::bind (&Track::update_input_meter, this));
-	_session.TransportStateChange.connect_same_thread (*this, boost::bind (&Track::update_input_meter, this));
+	_session.config.ParameterChanged.connect_same_thread (*this, std::bind (&Track::parameter_changed, this, _1));
+	_session.RecordStateChanged.connect_same_thread (*this, std::bind (&Track::update_input_meter, this));
+	_session.TransportStateChange.connect_same_thread (*this, std::bind (&Track::update_input_meter, this));
 
-	_monitoring_control->Changed.connect_same_thread (*this, boost::bind (&Track::monitoring_changed, this, _1, _2));
-	_record_safe_control->Changed.connect_same_thread (*this, boost::bind (&Track::record_safe_changed, this, _1, _2));
-	_record_enable_control->Changed.connect_same_thread (*this, boost::bind (&Track::record_enable_changed, this, _1, _2));
+	_monitoring_control->Changed.connect_same_thread (*this, std::bind (&Track::monitoring_changed, this, _1, _2));
+	_record_safe_control->Changed.connect_same_thread (*this, std::bind (&Track::record_safe_changed, this, _1, _2));
+	_record_enable_control->Changed.connect_same_thread (*this, std::bind (&Track::record_enable_changed, this, _1, _2));
 
-	_input->changed.connect_same_thread (*this, boost::bind (&Track::input_changed, this));
+	_input->changed.connect_same_thread (*this, std::bind (&Track::input_changed, this));
 
-	_disk_reader->ConfigurationChanged.connect_same_thread (*this, boost::bind (&Track::chan_count_changed, this));
+	_disk_reader->ConfigurationChanged.connect_same_thread (*this, std::bind (&Track::chan_count_changed, this));
 
 	return 0;
 }
@@ -334,7 +334,7 @@ Track::prep_record_enabled (bool yn)
 		return -1;
 	}
 
-	if (!can_be_record_enabled()) {
+	if (yn && !can_be_record_enabled()) {
 		return -1;
 	}
 
@@ -410,7 +410,9 @@ Track::update_input_meter ()
 void
 Track::record_enable_changed (bool, Controllable::GroupControlDisposition)
 {
-	_disk_writer->set_record_enabled (_record_enable_control->get_value());
+	bool yn = _record_enable_control->get_value();
+
+	_disk_writer->set_record_enabled (yn);
 }
 
 void
@@ -428,7 +430,7 @@ Track::can_be_record_safe ()
 bool
 Track::can_be_record_enabled ()
 {
-	return !_record_safe_control->get_value() && _disk_writer && !_disk_writer->record_safe() && _session.writable() && (_freeze_record.state != Frozen);
+	return !_record_safe_control->get_value() && _disk_writer && !_disk_writer->record_safe() && _session.writable() && (_freeze_record.state != Frozen) && (!_triggerbox || !_triggerbox->record_enabled());
 }
 
 void
@@ -582,6 +584,12 @@ Track::last_capture_sources ()
 	return _disk_writer->last_capture_sources ();
 }
 
+void
+Track::reset_last_capture_sources ()
+{
+	_disk_writer->reset_last_capture_sources ();
+}
+
 std::string
 Track::steal_write_source_name()
 {
@@ -589,9 +597,9 @@ Track::steal_write_source_name()
 }
 
 void
-Track::reset_write_sources (bool r, bool force)
+Track::reset_write_sources (bool mark_write_complete)
 {
-	_disk_writer->reset_write_sources (r, force);
+	_disk_writer->reset_write_sources (mark_write_complete);
 }
 
 float
@@ -1096,8 +1104,12 @@ Track::use_captured_midi_sources (SourceList& srcs, CaptureInfos const & capture
 
 		std::shared_ptr<Region> rx (RegionFactory::create (srcs, plist));
 
+		const timepos_t np (capture_info.front()->start);
+		rx->set_tempo (Temporal::TempoMap::use()->tempo_at (np));
+		rx->set_meter (Temporal::TempoMap::use()->meter_at (np));
+
 		midi_region = std::dynamic_pointer_cast<MidiRegion> (rx);
-		midi_region->special_set_position (timepos_t (capture_info.front()->start));
+		midi_region->special_set_position (np);
 	}
 
 	catch (failed_constructor& err) {
@@ -1176,6 +1188,7 @@ Track::use_captured_midi_sources (SourceList& srcs, CaptureInfos const & capture
 			if (preroll_off > 0) {
 				midi_region->trim_front (timepos_t ((*ci)->start - initial_capture + preroll_off));
 			}
+
 		}
 
 		catch (failed_constructor& err) {
@@ -1185,9 +1198,14 @@ Track::use_captured_midi_sources (SourceList& srcs, CaptureInfos const & capture
 
 		if (time_domain() == Temporal::BeatTime) {
 			const timepos_t b ((*ci)->start + preroll_off);
+			midi_region->set_tempo (Temporal::TempoMap::use()->tempo_at (b.beats()));
+			midi_region->set_meter (Temporal::TempoMap::use()->meter_at (b.beats()));
 			pl->add_region (midi_region, timepos_t (b.beats()), 1, rmode == RecNonLayered);
 		} else {
-			pl->add_region (midi_region, timepos_t ((*ci)->start + preroll_off), 1, rmode == RecNonLayered);
+			const timepos_t p ((*ci)->start + preroll_off);
+			midi_region->set_tempo (Temporal::TempoMap::use()->tempo_at (p));
+			midi_region->set_meter (Temporal::TempoMap::use()->meter_at (p));
+			pl->add_region (midi_region, p, 1, rmode == RecNonLayered);
 		}
 	}
 
@@ -1232,8 +1250,12 @@ Track::use_captured_audio_sources (SourceList& srcs, CaptureInfos const & captur
 		rx->set_automatic (true);
 		rx->set_whole_file (true);
 
+		const timepos_t np (afs->natural_position());
+		rx->set_tempo (Temporal::TempoMap::use()->tempo_at (np));
+		rx->set_meter (Temporal::TempoMap::use()->meter_at (np));
+
 		region = std::dynamic_pointer_cast<AudioRegion> (rx);
-		region->special_set_position (timepos_t (afs->natural_position()));
+		region->special_set_position (np);
 	}
 
 
@@ -1289,7 +1311,10 @@ Track::use_captured_audio_sources (SourceList& srcs, CaptureInfos const & captur
 			continue; /* XXX is this OK? */
 		}
 
-		pl->add_region (region, timepos_t ((*ci)->start + preroll_off), 1, RecNonLayered == rmode);
+		const timepos_t p ((*ci)->start + preroll_off);
+		region->set_tempo (Temporal::TempoMap::use()->tempo_at (p));
+		region->set_meter (Temporal::TempoMap::use()->meter_at (p));
+		pl->add_region (region, p, 1, RecNonLayered == rmode);
 		pl->set_layer (region, DBL_MAX);
 
 		buffer_position += (*ci)->samples;
