@@ -47,7 +47,7 @@
 using namespace std;
 using namespace Steinberg;
 
-#define ARDOUR_VST3_CACHE_FILE_VERSION 2
+#define ARDOUR_VST3_CACHE_FILE_VERSION 3
 
 static const char* fmt_media (Vst::MediaType m) {
 	switch (m) {
@@ -74,7 +74,7 @@ static const char* fmt_type (Vst::BusType t) {
 }
 
 static int32
-count_channels (Vst::IComponent* c, Vst::MediaType media, Vst::BusDirection dir, Vst::BusType type, bool verbose = false)
+count_channels (Vst::IComponent* c, Vst::MediaType media, Vst::BusDirection dir, Vst::BusType type, bool verbose = false, bool can_fail = true)
 {
 	/* see also libs/ardour/vst3_plugin.cc VST3PI::count_channels */
 	int32 n_busses = c->getBusCount (media, dir);
@@ -100,13 +100,67 @@ count_channels (Vst::IComponent* c, Vst::MediaType media, Vst::BusDirection dir,
 			} else {
 				n_channels += bus.channelCount;
 			}
-		} else if (verbose && rv != kResultTrue) {
-			PBD::info << "VST3: \\ error getting busInfo for bus: " << i << " rv: " << rv << ", got type: " << fmt_type (bus.busType) << endmsg;
+		} else if (rv != kResultTrue) {
+			if (verbose) {
+				PBD::info << "VST3: \\ error getting busInfo for bus: " << i << " rv: " << rv << ", got type: " << fmt_type (bus.busType) << endmsg;
+			}
+			if (!can_fail) {
+				return -1;
+			}
 		}
 	}
 	return n_channels;
 }
 
+static bool
+count_all_count_channels (ARDOUR::VST3Info& nfo, Vst::IComponent* c, bool verbose, bool require_result)
+{
+	nfo.n_inputs       = count_channels (c, Vst::kAudio, Vst::kInput,  Vst::kMain, verbose, require_result);
+	nfo.n_aux_inputs   = count_channels (c, Vst::kAudio, Vst::kInput,  Vst::kAux, verbose);
+	nfo.n_outputs      = count_channels (c, Vst::kAudio, Vst::kOutput, Vst::kMain, verbose, require_result);
+	nfo.n_aux_outputs  = count_channels (c, Vst::kAudio, Vst::kOutput, Vst::kAux, verbose);
+	nfo.n_midi_inputs  = count_channels (c, Vst::kEvent, Vst::kInput,  Vst::kMain, verbose);
+	nfo.n_midi_outputs = count_channels (c, Vst::kEvent, Vst::kOutput, Vst::kMain, verbose);
+
+	if (nfo.n_inputs < 0 || nfo.n_outputs < 0) {
+		/* failed to get info */
+		return false;
+	}
+
+	if (0 == (nfo.n_outputs + nfo.n_aux_outputs + nfo.n_midi_outputs)) {
+		/* no oututs at all, try to set Bus/SpeakerArrangement */
+		return false;
+	}
+
+	return true;
+}
+
+static void
+set_speaker_arrangement (Vst::IComponent* c, IPtr<Vst::IAudioProcessor> p)
+{
+	Vst::SpeakerArrangement null_arrangement = {};
+	typedef std::vector<Vst::SpeakerArrangement> VSTSpeakerArrangements;
+	VSTSpeakerArrangements sa_in;
+	VSTSpeakerArrangements sa_out;
+
+	/* assume stereo by default */
+	int n_bus_in  = c->getBusCount (Vst::kAudio, Vst::kInput);
+	int n_bus_out = c->getBusCount (Vst::kAudio, Vst::kOutput);
+
+	while (sa_in.size () < (VSTSpeakerArrangements::size_type) n_bus_in) {
+		Vst::SpeakerArrangement sa = Vst::SpeakerArr::kStereo;
+		sa_in.push_back (sa);
+	}
+	while (sa_out.size () < (VSTSpeakerArrangements::size_type) n_bus_out) {
+		Vst::SpeakerArrangement sa = Vst::SpeakerArr::kStereo;
+		sa_out.push_back (sa);
+	}
+
+	p->setBusArrangements (sa_in.size () > 0 ? &sa_in[0] : &null_arrangement, sa_in.size (),
+	                       sa_out.size () > 0 ? &sa_out[0] : &null_arrangement, sa_out.size ());
+
+}
+
 static bool
 discover_vst3 (std::shared_ptr<ARDOUR::VST3PluginModule> m, std::vector<ARDOUR::VST3Info>& rv, bool verbose)
 {
@@ -209,12 +263,15 @@ discover_vst3 (std::shared_ptr<ARDOUR::VST3PluginModule> m, std::vector<ARDOUR::
 				continue;
 			}
 
-			nfo.n_inputs       = count_channels (component, Vst::kAudio, Vst::kInput,  Vst::kMain, verbose);
-			nfo.n_aux_inputs   = count_channels (component, Vst::kAudio, Vst::kInput,  Vst::kAux, verbose);
-			nfo.n_outputs      = count_channels (component, Vst::kAudio, Vst::kOutput, Vst::kMain, verbose);
-			nfo.n_aux_outputs  = count_channels (component, Vst::kAudio, Vst::kOutput, Vst::kAux, verbose);
-			nfo.n_midi_inputs  = count_channels (component, Vst::kEvent, Vst::kInput,  Vst::kMain, verbose);
-			nfo.n_midi_outputs = count_channels (component, Vst::kEvent, Vst::kOutput, Vst::kMain, verbose);
+			/* first try to get default layout ..*/
+			if (!count_all_count_channels (nfo, component, verbose, false)) {
+				if (verbose) {
+					PBD::info << "Bus/Channel detection failed, setting speaker arrangement, and re-scan" << endmsg;
+				}
+				/* some plugins e.g. Altiverb require a valid Bus/SpeakerArrangement */
+				set_speaker_arrangement (component, processor);
+				count_all_count_channels (nfo, component, verbose, true);
+			}
 
 			processor->setProcessing (false);
 			component->setActive (false);
@@ -325,9 +382,12 @@ ARDOUR::module_path_vst3 (string const& path)
 	 * (on macOS/X the binary name may differ from the bundle name)
 	 */
 	string plist = Glib::build_filename (path, "Contents", "Info.plist");
+	string macos = Glib::build_filename (path, "Contents", "MacOS");
 	if (Glib::file_test (Glib::path_get_dirname (module_path), Glib::FILE_TEST_IS_DIR) &&
 	    Glib::file_test (Glib::build_filename (path, "Contents", "Info.plist"), Glib::FILE_TEST_IS_REGULAR)) {
-		return plist;
+		return path;
+	} else if (Glib::file_test (macos, Glib::FILE_TEST_IS_DIR)){
+		return path;
 	} else {
 		cerr << "VST3 not a valid bundle: '" << path << "'\n";
 		return "";
@@ -474,7 +534,7 @@ vst3_save_cache_file (std::string const& module_path, XMLNode* root, bool verbos
 }
 
 bool
-ARDOUR::vst3_scan_and_cache (std::string const& module_path, std::string const& bundle_path, boost::function<void (std::string const&, std::string const&, VST3Info const&)> cb, bool verbose)
+ARDOUR::vst3_scan_and_cache (std::string const& module_path, std::string const& bundle_path, std::function<void (std::string const&, std::string const&, VST3Info const&)> cb, bool verbose)
 {
 	XMLNode* root = new XMLNode ("VST3Cache");
 	root->set_property ("version", ARDOUR_VST3_CACHE_FILE_VERSION);
