@@ -17,7 +17,6 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <regex.h>
 #include <sys/mman.h>
 #include <sys/time.h>
 
@@ -108,8 +107,6 @@ CoreAudioBackend::CoreAudioBackend (AudioEngine& e, AudioBackendInfo& info)
 	, _midi_driver_option(_("CoreMidi"))
 	, _samplerate (48000)
 	, _samples_per_period (1024)
-	, _n_inputs (0)
-	, _n_outputs (0)
 	, _systemic_audio_input_latency (0)
 	, _systemic_audio_output_latency (0)
 	, _hw_audio_input_latency (0)
@@ -270,18 +267,6 @@ CoreAudioBackend::available_buffer_sizes2 (const std::string& input_device, cons
 	}
 }
 
-uint32_t
-CoreAudioBackend::available_input_channel_count (const std::string&) const
-{
-	return 128; // TODO query current device
-}
-
-uint32_t
-CoreAudioBackend::available_output_channel_count (const std::string&) const
-{
-	return 128; // TODO query current device
-}
-
 bool
 CoreAudioBackend::can_change_sample_rate_when_running () const
 {
@@ -361,20 +346,6 @@ CoreAudioBackend::set_interleaved (bool yn)
 	return -1;
 }
 
-int
-CoreAudioBackend::set_input_channels (uint32_t cc)
-{
-	_n_inputs = cc;
-	return 0;
-}
-
-int
-CoreAudioBackend::set_output_channels (uint32_t cc)
-{
-	_n_outputs = cc;
-	return 0;
-}
-
 int
 CoreAudioBackend::set_systemic_input_latency (uint32_t sl)
 {
@@ -426,18 +397,6 @@ CoreAudioBackend::interleaved () const
 	return false;
 }
 
-uint32_t
-CoreAudioBackend::input_channels () const
-{
-	return _n_inputs;
-}
-
-uint32_t
-CoreAudioBackend::output_channels () const
-{
-	return _n_outputs;
-}
-
 uint32_t
 CoreAudioBackend::systemic_input_latency () const
 {
@@ -602,24 +561,6 @@ CoreAudioBackend::_start (bool for_latency_measurement)
 		return error_code;
 	}
 
-	if (_n_outputs != _pcmio->n_playback_channels ()) {
-		if (_n_outputs == 0) {
-			_n_outputs = _pcmio->n_playback_channels ();
-		} else {
-			_n_outputs = std::min (_n_outputs, _pcmio->n_playback_channels ());
-		}
-		PBD::info << _("CoreAudioBackend: adjusted output channel count to match device.") << endmsg;
-	}
-
-	if (_n_inputs != _pcmio->n_capture_channels ()) {
-		if (_n_inputs == 0) {
-			_n_inputs = _pcmio->n_capture_channels ();
-		} else {
-			_n_inputs = std::min (_n_inputs, _pcmio->n_capture_channels ());
-		}
-		PBD::info << _("CoreAudioBackend: adjusted input channel count to match device.") << endmsg;
-	}
-
 	if (_pcmio->sample_rate() != _samplerate) {
 		_samplerate = _pcmio->sample_rate();
 		engine.sample_rate_change (_samplerate);
@@ -663,7 +604,7 @@ CoreAudioBackend::_start (bool for_latency_measurement)
 		return PortReconnectError;
 	}
 
-	if (pthread_create (&_freeewheel_thread, NULL, pthread_freewheel, this))
+	if (pbd_pthread_create (PBD_RT_STACKSIZE_PROC, &_freeewheel_thread, pthread_freewheel, this))
 	{
 		PBD::error << _("CoreAudioBackend: failed to create process thread.") << endmsg;
 		delete _pcmio; _pcmio = 0;
@@ -861,7 +802,7 @@ CoreAudioBackend::coreaudio_process_thread (void *arg)
 	}
 #endif
 
-	boost::function<void ()> f = td->f;
+	std::function<void ()> f = td->f;
 	f ();
 
 #if MAC_OS_X_VERSION_MAX_ALLOWED >= 110000
@@ -874,7 +815,7 @@ CoreAudioBackend::coreaudio_process_thread (void *arg)
 }
 
 int
-CoreAudioBackend::create_process_thread (boost::function<void()> func)
+CoreAudioBackend::create_process_thread (std::function<void()> func)
 {
 	pthread_t   thread_id;
 	ThreadData* td = new ThreadData (this, func, PBD_RT_STACKSIZE_PROC, 1e9 * _samples_per_period / _samplerate);
@@ -887,7 +828,7 @@ CoreAudioBackend::create_process_thread (boost::function<void()> func)
 	}
 #endif
 
-	if (pbd_realtime_pthread_create (PBD_SCHED_FIFO, PBD_RT_PRI_PROC, PBD_RT_STACKSIZE_PROC,
+	if (pbd_realtime_pthread_create ("CoreAudio Proc", PBD_SCHED_FIFO, PBD_RT_PRI_PROC, PBD_RT_STACKSIZE_PROC,
 	                              &thread_id, coreaudio_process_thread, td)) {
 		if (pbd_pthread_create (PBD_RT_STACKSIZE_PROC, &thread_id, coreaudio_process_thread, td)) {
 			PBD::error << _("AudioEngine: cannot create process thread.") << endmsg;
@@ -965,8 +906,8 @@ CoreAudioBackend::register_system_audio_ports()
 {
 	LatencyRange lr;
 
-	const uint32_t a_ins = _n_inputs;
-	const uint32_t a_out = _n_outputs;
+	const uint32_t a_ins = _pcmio->n_capture_channels ();
+	const uint32_t a_out = _pcmio->n_playback_channels ();
 
 	const uint32_t coreaudio_reported_input_latency = _pcmio->get_latency(name_to_id(_input_audio_device, Input), true);
 	const uint32_t coreaudio_reported_output_latency = _pcmio->get_latency(name_to_id(_output_audio_device, Output), false);
@@ -1067,7 +1008,7 @@ CoreAudioBackend::coremidi_rediscover()
 			continue;
 		}
 		LatencyRange lr;
-		lr.min = lr.max = _samples_per_period; // TODO add per-port midi-systemic latency
+		lr.min = lr.max = 0; // TODO add per-port midi-systemic latency
 		set_latency_range (p, false, lr);
 		BackendPortPtr pp = std::dynamic_pointer_cast<BackendPort>(p);
 		pp->set_hw_port_name(_midiio->port_name(i, true));
@@ -1090,7 +1031,7 @@ CoreAudioBackend::coremidi_rediscover()
 			continue;
 		}
 		LatencyRange lr;
-		lr.min = lr.max = _samples_per_period; // TODO add per-port midi-systemic latency
+		lr.min = lr.max = 0; // TODO add per-port midi-systemic latency
 		set_latency_range (p, false, lr);
 		BackendPortPtr pp = std::dynamic_pointer_cast<BackendPort>(p);
 		pp->set_hw_port_name(_midiio->port_name(i, false));
@@ -1098,7 +1039,6 @@ CoreAudioBackend::coremidi_rediscover()
 		_port_change_flag.store (1);
 	}
 
-
 	assert(_system_midi_out.size() == _midiio->n_midi_outputs());
 	assert(_system_midi_in.size() == _midiio->n_midi_inputs());
 
@@ -1217,7 +1157,7 @@ CoreAudioBackend::set_latency_range (PortEngine::PortHandle port_handle, bool fo
 {
 	std::shared_ptr<BackendPort> port = std::dynamic_pointer_cast<BackendPort> (port_handle);
 	if (!valid_port (port)) {
-		DEBUG_TRACE (PBD::DEBUG::BackendPorts, "BackendPort::set_latency_range (): invalid port.");
+		DEBUG_TRACE (PBD::DEBUG::BackendPorts, "CoreAudioBackend::set_latency_range (): invalid port.");
 		return;
 	}
 	port->set_latency_range (latency_range, for_playback);
@@ -1229,21 +1169,32 @@ CoreAudioBackend::get_latency_range (PortEngine::PortHandle port_handle, bool fo
 	std::shared_ptr<BackendPort> port = std::dynamic_pointer_cast<BackendPort> (port_handle);
 	LatencyRange r;
 	if (!valid_port (port)) {
-		DEBUG_TRACE (PBD::DEBUG::BackendPorts, "BackendPort::get_latency_range (): invalid port.");
+		DEBUG_TRACE (PBD::DEBUG::BackendPorts, "CoreAudioBackend::get_latency_range (): invalid port.");
 		r.min = 0;
 		r.max = 0;
 		return r;
 	}
 
 	r = port->latency_range (for_playback);
-	if (port->is_physical() && port->is_terminal() && port->type() == DataType::AUDIO) {
-		if (port->is_input() && for_playback) {
-			r.min += _samples_per_period + _hw_audio_input_latency;
-			r.max += _samples_per_period + _hw_audio_input_latency;
-		}
-		if (port->is_output() && !for_playback) {
-			r.min += _samples_per_period + _hw_audio_output_latency;
-			r.max += _samples_per_period + _hw_audio_output_latency;
+	if (port->is_physical() && port->is_terminal()) {
+		if (port->type() == DataType::AUDIO) {
+			if (port->is_input() && for_playback) {
+				r.min += _samples_per_period + _hw_audio_input_latency;
+				r.max += _samples_per_period + _hw_audio_input_latency;
+			}
+			if (port->is_output() && !for_playback) {
+				r.min += _samples_per_period + _hw_audio_output_latency;
+				r.max += _samples_per_period + _hw_audio_output_latency;
+			}
+		} else {
+			if (port->is_input() && for_playback) {
+				//r.min += _samples_per_period;
+				//r.max += _samples_per_period;
+			}
+			if (port->is_output() && !for_playback) {
+				r.min += _samples_per_period;
+				r.max += _samples_per_period;
+			}
 		}
 	}
 	return r;
@@ -1272,12 +1223,7 @@ CoreAudioBackend::pre_process ()
 		if (!_port_connection_queue.empty ()) {
 			connections_changed = true;
 		}
-		while (!_port_connection_queue.empty ()) {
-			PortConnectData *c = _port_connection_queue.back ();
-			manager.connect_callback (c->a, c->b, c->c);
-			_port_connection_queue.pop_back ();
-			delete c;
-		}
+		process_connection_queue_locked (manager);
 		pthread_mutex_unlock (&_port_callback_mutex);
 	}
 	if (ports_changed) {
@@ -1440,11 +1386,12 @@ CoreAudioBackend::process_callback (const uint32_t n_samples, const uint64_t hos
 	/* port-connection change */
 	pre_process();
 
-	// cycle-length in usec
-	const double nominal_time = 1e6 * n_samples / _samplerate;
-
 	clock1 = g_get_monotonic_time();
 
+	//_midiio->start_cycle (AudioGetCurrentHostTime (), 1e9 * n_samples / _samplerate);
+	_midiio->start_cycle (host_time, 1e9 * n_samples / _samplerate);
+	_last_process_start = host_time;
+
 	/* get midi */
 	i=0;
 	for (std::vector<BackendPortPtr>::const_iterator it = _system_midi_in.begin (); it != _system_midi_in.end (); ++it, ++i) {
@@ -1458,7 +1405,7 @@ CoreAudioBackend::process_callback (const uint32_t n_samples, const uint64_t hos
 
 		port->clear_events ();
 
-		while (_midiio->recv_event (i, nominal_time, time_ns, data, size)) {
+		while (_midiio->recv_event (i, time_ns, data, size)) {
 			pframes_t time = floor((float) time_ns * _samplerate * 1e-9);
 			assert (time < n_samples);
 			port->parse_events (time, data, size);
@@ -1477,9 +1424,6 @@ CoreAudioBackend::process_callback (const uint32_t n_samples, const uint64_t hos
 		memset ((*it)->get_buffer (n_samples), 0, n_samples * sizeof (Sample));
 	}
 
-	_midiio->start_cycle();
-	_last_process_start = host_time;
-
 	if (engine.process_callback (n_samples)) {
 		fprintf(stderr, "ENGINE PROCESS ERROR\n");
 		//_pcmio->pcm_stop ();
@@ -1498,7 +1442,7 @@ CoreAudioBackend::process_callback (const uint32_t n_samples, const uint64_t hos
 	for (std::vector<BackendPortPtr>::const_iterator it = _system_midi_out.begin (); it != _system_midi_out.end (); ++it, ++i) {
 		const CoreMidiBuffer *src = std::dynamic_pointer_cast<CoreMidiPort>(*it)->const_buffer();
 		for (CoreMidiBuffer::const_iterator mit = src->begin (); mit != src->end (); ++mit) {
-			_midiio->send_event (i, mit->timestamp (), mit->data (), mit->size ());
+			_midiio->send_event (i, mit->timestamp () * 1e9 / _samplerate , mit->data (), mit->size ());
 		}
 	}
 
