@@ -17,7 +17,6 @@
  */
 
 #include <math.h>
-#include <regex.h>
 #include <stdlib.h>
 #include <sys/mman.h>
 #include <sys/time.h>
@@ -584,7 +583,7 @@ PulseAudioBackend::_start (bool /*for_latency_measurement*/)
 	_run = true;
 	_port_change_flag.store (0);
 
-	if (pbd_realtime_pthread_create (PBD_SCHED_FIFO, PBD_RT_PRI_MAIN, PBD_RT_STACKSIZE_PROC,
+	if (pbd_realtime_pthread_create ("PulseAudio Main", PBD_SCHED_FIFO, PBD_RT_PRI_MAIN, PBD_RT_STACKSIZE_PROC,
 	                                 &_main_thread, pthread_process, this)) {
 		if (pbd_pthread_create (PBD_RT_STACKSIZE_PROC, &_main_thread, pthread_process, this)) {
 			PBD::error << _("PulseAudioBackend: failed to create process thread.") << endmsg;
@@ -691,19 +690,19 @@ void*
 PulseAudioBackend::pulse_process_thread (void* arg)
 {
 	ThreadData*             td = reinterpret_cast<ThreadData*> (arg);
-	boost::function<void()> f  = td->f;
+	std::function<void()> f  = td->f;
 	delete td;
 	f ();
 	return 0;
 }
 
 int
-PulseAudioBackend::create_process_thread (boost::function<void()> func)
+PulseAudioBackend::create_process_thread (std::function<void()> func)
 {
 	pthread_t   thread_id;
 	ThreadData* td = new ThreadData (this, func, PBD_RT_STACKSIZE_PROC);
 
-	if (pbd_realtime_pthread_create (PBD_SCHED_FIFO, PBD_RT_PRI_PROC, PBD_RT_STACKSIZE_PROC,
+	if (pbd_realtime_pthread_create ("PulseAudio Proc", PBD_SCHED_FIFO, PBD_RT_PRI_PROC, PBD_RT_STACKSIZE_PROC,
 	                                 &thread_id, pulse_process_thread, td)) {
 		if (pbd_pthread_create (PBD_RT_STACKSIZE_PROC, &thread_id, pulse_process_thread, td)) {
 			PBD::error << _("AudioEngine: cannot create process thread.") << endmsg;
@@ -895,7 +894,7 @@ PulseAudioBackend::set_latency_range (PortEngine::PortHandle port_handle, bool f
 {
 	BackendPortPtr port = std::dynamic_pointer_cast<BackendPort> (port_handle);
 	if (!valid_port (port)) {
-		PBD::error << _("PulsePort::set_latency_range (): invalid port.") << endmsg;
+		PBD::error << _("PulseAudioBackend::set_latency_range (): invalid port.") << endmsg;
 	}
 	port->set_latency_range (latency_range, for_playback);
 }
@@ -907,7 +906,7 @@ PulseAudioBackend::get_latency_range (PortEngine::PortHandle port_handle, bool f
 	LatencyRange r;
 
 	if (!valid_port (port)) {
-		PBD::error << _("PulsePort::get_latency_range (): invalid port.") << endmsg;
+		PBD::error << _("PulseAudioBackend::get_latency_range (): invalid port.") << endmsg;
 		r.min = 0;
 		r.max = 0;
 		return r;
