@@ -23,14 +23,12 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "pbd/pthread_utils.h"
 #include "pbd/memento_command.h"
 
 #include "temporal/tempo.h"
 
 #include "ardour/session.h"
 #include "ardour/location.h"
-#include "ardour/tempo.h"
 #include "ardour/transport_master_manager.h"
 #include "ardour/utils.h"
 
@@ -41,7 +39,7 @@
 using namespace ARDOUR;
 using namespace Temporal;
 
-PBD::Signal2<void,std::string,std::string> BasicUI::AccessAction;
+PBD::Signal<void(std::string,std::string)> BasicUI::AccessAction;
 
 BasicUI::BasicUI (Session& s)
 	: session (&s),
@@ -152,10 +150,10 @@ BasicUI::goto_end ()
 }
 
 void
-BasicUI::add_marker (const std::string& markername)
+BasicUI::add_marker (const std::string& markername, Location::Flags flags)
 {
 	timepos_t where (session->audible_sample());
-	Location *location = new Location (*session, where, where, markername, Location::IsMark);
+	Location *location = new Location (*session, where, where, markername, flags);
 	session->begin_reversible_command (_("add marker"));
 	XMLNode &before = session->locations()->get_state();
 	session->locations()->add (location, true);
@@ -369,7 +367,7 @@ void
 BasicUI::rec_enable_toggle ()
 {
 	switch (session->record_status()) {
-	case Session::Disabled:
+	case Disabled:
 		if (session->ntracks() == 0) {
 			// string txt = _("Please create 1 or more track\nbefore trying to record.\nCheck the Session menu.");
 			// MessageDialog msg (*editor, txt);
@@ -378,8 +376,8 @@ BasicUI::rec_enable_toggle ()
 		}
 		session->maybe_enable_record ();
 		break;
-	case Session::Recording:
-	case Session::Enabled:
+	case Recording:
+	case Enabled:
 		session->disable_record (false, true);
 	}
 }
@@ -760,8 +758,8 @@ void BasicUI::zoom_1_min() { access_action("Editor/zoom_1_min"); }
 void BasicUI::zoom_5_min() { access_action("Editor/zoom_5_min"); }
 void BasicUI::zoom_10_min() { access_action("Editor/zoom_10_min"); }
 void BasicUI::zoom_to_session() { access_action("Editor/zoom-to-session"); }
-void BasicUI::temporal_zoom_in() { access_action("Editor/temporal-zoom-in"); }
-void BasicUI::temporal_zoom_out() { access_action("Editor/temporal-zoom-out"); }
+void BasicUI::temporal_zoom_in() { access_action("Editing/temporal-zoom-in"); }
+void BasicUI::temporal_zoom_out() { access_action("Editing/temporal-zoom-out"); }
 
 void BasicUI::scroll_up_1_track() { access_action("Editor/step-tracks-up"); }
 void BasicUI::scroll_dn_1_track() { access_action("Editor/step-tracks-down"); }
@@ -781,6 +779,12 @@ BasicUI::locked ()
 	return session->transport_locked ();
 }
 
+bool
+BasicUI::session_empty () const
+{
+	return session->empty ();
+}
+
 ARDOUR::samplecnt_t
 BasicUI::timecode_frames_per_hour ()
 {
@@ -889,7 +893,7 @@ BasicUI::trigger_display_at (int x, int y)
 		ARDOUR::TriggerPtr current = tb->currently_playing ();
 		TriggerPtr tp = tb->trigger (_tbank_start_row + y);
 		if (tp) {
-			if (!tp->region()) {
+			if (!tp->playable()) {
 				disp.state = -1;
 			} else if (tp == current) {
 				disp.state = 1;
