@@ -31,14 +31,17 @@
 #include "pbd/gstdio_compat.h"
 #include <glibmm.h>
 
-#include <curl/curl.h>
-
+#include "pbd/ccurl.h"
 #include "pbd/failed_constructor.h"
 #include "pbd/file_archive.h"
 #include "pbd/file_utils.h"
 #include "pbd/pthread_utils.h"
 #include "pbd/progress.h"
 
+#ifdef COMPILER_MSVC
+#include <io.h> // For read, close
+#endif
+
 using namespace PBD;
 
 static size_t
@@ -60,19 +63,19 @@ static void*
 get_url (void* arg)
 {
 	FileArchive::Request* r = (FileArchive::Request*) arg;
-	CURL* curl;
+	PBD::CCurl ccurl;
+	CURL* curl = ccurl.curl ();
 
-	curl = curl_easy_init ();
 	curl_easy_setopt (curl, CURLOPT_URL, r->url);
 	curl_easy_setopt (curl, CURLOPT_FOLLOWLOCATION, 1L);
 
 	/* get size */
 	if (r->mp.query_length) {
-		double content_length = 0;
+		curl_off_t content_length = 0;
 		curl_easy_setopt(curl, CURLOPT_NOBODY, 1L);
 		curl_easy_setopt(curl, CURLOPT_HEADER, 0L);
 		curl_easy_perform (curl);
-		if (CURLE_OK == curl_easy_getinfo (curl, CURLINFO_CONTENT_LENGTH_DOWNLOAD, &content_length) && content_length > 0) {
+		if (CURLE_OK == curl_easy_getinfo (curl, CURLINFO_CONTENT_LENGTH_DOWNLOAD_T, &content_length) && content_length > 0) {
 			r->mp.length = content_length;
 		}
 	}
@@ -81,7 +84,6 @@ get_url (void* arg)
 	curl_easy_setopt (curl, CURLOPT_WRITEFUNCTION, write_callback);
 	curl_easy_setopt (curl, CURLOPT_WRITEDATA, (void*) &r->mp);
 	curl_easy_perform (curl);
-	curl_easy_cleanup (curl);
 
 	r->mp.lock ();
 	r->mp.done = 1;
@@ -190,7 +192,8 @@ FileArchive::fetch (const std::string & url, const std::string & destdir) const
 		return std::string();
 	}
 
-	CURL* curl = curl_easy_init ();
+	PBD::CCurl ccurl;
+	CURL* curl = ccurl.curl ();
 
 	if (!curl) {
 		return std::string ();
@@ -199,7 +202,6 @@ FileArchive::fetch (const std::string & url, const std::string & destdir) const
 	curl_easy_setopt (curl, CURLOPT_URL, url.c_str ());
 	curl_easy_setopt (curl, CURLOPT_FOLLOWLOCATION, 1L);
 	CURLcode res = curl_easy_perform (curl);
-	curl_easy_cleanup (curl);
 
 	g_chdir (pwd.c_str());
 	if (res != CURLE_OK) {
@@ -524,13 +526,19 @@ FileArchive::create (const std::map<std::string, std::string>& filemap, Compress
 		archive_write_set_options (a, buf);
 	}
 
-	archive_write_open_filename (a, _req.url);
+	if (ARCHIVE_OK != archive_write_open_filename (a, _req.url)) {
+		archive_write_free (a);
+		return -2;
+	}
+
 	entry = archive_entry_new ();
 
 #ifndef NDEBUG
 	  const int64_t archive_start_time = g_get_monotonic_time();
 #endif
 
+		bool error = false;
+
 	for (std::map<std::string, std::string>::const_iterator f = filemap.begin (); f != filemap.end (); ++f) {
 		char buf[8192];
 		const char* filepath = f->first.c_str ();
@@ -564,7 +572,10 @@ FileArchive::create (const std::map<std::string, std::string>& filemap, Compress
 		ssize_t len = read (fd, buf, sizeof (buf));
 		while (len > 0) {
 			read_bytes += len;
-			archive_write_data (a, buf, len);
+			if (len != archive_write_data (a, buf, len)) {
+				error = true;
+				break;
+			}
 			if (_progress) {
 				_progress->set_progress ((float)read_bytes / total_bytes);
 				if (_progress->cancelled ()) {
@@ -574,16 +585,19 @@ FileArchive::create (const std::map<std::string, std::string>& filemap, Compress
 			len = read (fd, buf, sizeof (buf));
 		}
 		close (fd);
-		if (_progress && _progress->cancelled ()) {
+		if (error || (_progress && _progress->cancelled ())) {
 			break;
 		}
 	}
 
 	archive_entry_free (entry);
-	archive_write_close (a);
-	archive_write_free (a);
 
-	if (_progress) {
+	error |= archive_write_close (a) == ARCHIVE_FATAL;
+	error |= archive_write_free (a) == ARCHIVE_FATAL;
+
+	if (error) {
+		g_unlink (_req.url);
+	} else if (_progress) {
 		if (_progress->cancelled ()) {
 			g_unlink (_req.url);
 		} else {
@@ -596,7 +610,7 @@ FileArchive::create (const std::map<std::string, std::string>& filemap, Compress
 	std::cerr << "archived in " << std::fixed << std::setprecision (2) << elapsed_time_us / 1000000. << " sec\n";
 #endif
 
-	return 0;
+	return error ? -3 : 0;
 }
 
 struct archive*
