@@ -16,8 +16,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef __libpbd_property_list_impl_h__
-#define __libpbd_property_list_impl_h__
+#pragma once
 
 #include "pbd/property_list.h"
 #include "pbd/properties.h"
@@ -39,4 +38,3 @@ PropertyList::remove (PropertyDescriptor<T> pid) {
 
 }
 
-#endif /* __libpbd_property_list_impl_h__ */
