@@ -69,7 +69,7 @@ using namespace std;
 
 #include "pbd/i18n.h"
 
-#include "pbd/abstract_ui.cc" // instantiate template
+#include "pbd/abstract_ui.inc.cc" // instantiate template
 
 CC121::CC121 (Session& s)
 	: ControlProtocol (s, _("Steinberg CC121"))
@@ -117,7 +117,7 @@ CC121::CC121 (Session& s)
 
 
 	/* Catch port connections and disconnections */
-	ARDOUR::AudioEngine::instance()->PortConnectedOrDisconnected.connect (port_connection, MISSING_INVALIDATOR, boost::bind (&CC121::connection_handler, this, _1, _2, _3, _4, _5), this);
+	ARDOUR::AudioEngine::instance()->PortConnectedOrDisconnected.connect (port_connection, MISSING_INVALIDATOR, std::bind (&CC121::connection_handler, this, _1, _2, _3, _4, _5), this);
 	buttons.insert (std::make_pair (EButton, Button (*this, _("EButton"), EButton)));
 	buttons.insert (std::make_pair (OpenVST, Button (*this, _("OpenVST"), OpenVST)));
 	buttons.insert (std::make_pair (InputMonitor, Button (*this, _("InputMonitor"), InputMonitor)));
@@ -153,30 +153,30 @@ CC121::CC121 (Session& s)
 	buttons.insert (std::make_pair (Footswitch, Button (*this, _("Footswitch"), Footswitch)));
 	buttons.insert (std::make_pair (FaderTouch, Button (*this, _("Fader (touch)"), FaderTouch)));
 
-	get_button (Left).set_action ( boost::bind (&CC121::left, this), true);
-	get_button (Right).set_action ( boost::bind (&CC121::right, this), true);
+	get_button (Left).set_action ( std::bind (&CC121::left, this), true);
+	get_button (Right).set_action ( std::bind (&CC121::right, this), true);
 
-	get_button (FP_Read).set_action (boost::bind (&CC121::read, this), true);
-	get_button (FP_Write).set_action (boost::bind (&CC121::write, this), true);
-	get_button (EButton).set_action (boost::bind (&CC121::touch, this), true);
-	get_button (OpenVST).set_action (boost::bind (&CC121::off, this), true);
+	get_button (FP_Read).set_action (std::bind (&CC121::read, this), true);
+	get_button (FP_Write).set_action (std::bind (&CC121::write, this), true);
+	get_button (EButton).set_action (std::bind (&CC121::touch, this), true);
+	get_button (OpenVST).set_action (std::bind (&CC121::off, this), true);
 
-	get_button (Play).set_action (boost::bind (&BasicUI::transport_play, this, true), true);
-	get_button (ToStart).set_action (boost::bind (&BasicUI::prev_marker, this), true);
-	get_button (ToEnd).set_action (boost::bind (&BasicUI::next_marker, this), true);
-	get_button (RecEnable).set_action (boost::bind (&BasicUI::rec_enable_toggle, this), true);
-	get_button (Stop).set_action (boost::bind (&BasicUI::transport_stop, this), true);
-	get_button (Ffwd).set_action (boost::bind (&BasicUI::ffwd, this), true);
+	get_button (Play).set_action (std::bind (&BasicUI::transport_play, this, true), true);
+	get_button (ToStart).set_action (std::bind (&BasicUI::prev_marker, this), true);
+	get_button (ToEnd).set_action (std::bind (&BasicUI::next_marker, this), true);
+	get_button (RecEnable).set_action (std::bind (&BasicUI::rec_enable_toggle, this), true);
+	get_button (Stop).set_action (std::bind (&BasicUI::transport_stop, this), true);
+	get_button (Ffwd).set_action (std::bind (&BasicUI::ffwd, this), true);
 
-	get_button (Rewind).set_action (boost::bind (&BasicUI::rewind, this), true);
-	get_button (Loop).set_action (boost::bind (&BasicUI::loop_toggle, this), true);
+	get_button (Rewind).set_action (std::bind (&BasicUI::rewind, this), true);
+	get_button (Loop).set_action (std::bind (&BasicUI::loop_toggle, this), true);
 
-	get_button (Jog).set_action (boost::bind (&CC121::jog, this), true);
-	get_button (Mute).set_action (boost::bind (&CC121::mute, this), true);
-	get_button (Solo).set_action (boost::bind (&CC121::solo, this), true);
-	get_button (Rec).set_action (boost::bind (&CC121::rec_enable, this), true);
+	get_button (Jog).set_action (std::bind (&CC121::jog, this), true);
+	get_button (Mute).set_action (std::bind (&CC121::mute, this), true);
+	get_button (Solo).set_action (std::bind (&CC121::solo, this), true);
+	get_button (Rec).set_action (std::bind (&CC121::rec_enable, this), true);
 
-	get_button (InputMonitor).set_action (boost::bind (&CC121::input_monitor, this), true);
+	get_button (InputMonitor).set_action (std::bind (&CC121::input_monitor, this), true);
 }
 
 CC121::~CC121 ()
@@ -207,13 +207,13 @@ void
 CC121::start_midi_handling ()
 {
 	/* handle buttons press */
-        _input_port->parser()->channel_note_on[0].connect_same_thread (midi_connections, boost::bind (&CC121::button_press_handler, this, _1, _2));
+        _input_port->parser()->channel_note_on[0].connect_same_thread (midi_connections, std::bind (&CC121::button_press_handler, this, _1, _2));
 	/* handle buttons release*/
-        _input_port->parser()->channel_note_off[0].connect_same_thread (midi_connections, boost::bind (&CC121::button_release_handler, this, _1, _2));
+        _input_port->parser()->channel_note_off[0].connect_same_thread (midi_connections, std::bind (&CC121::button_release_handler, this, _1, _2));
 	/* handle fader */
-        _input_port->parser()->pitchbend.connect_same_thread (midi_connections, boost::bind (&CC121::fader_handler, this, _1, _2));
+        _input_port->parser()->pitchbend.connect_same_thread (midi_connections, std::bind (&CC121::fader_handler, this, _1, _2));
 	/* handle encoder */
-	_input_port->parser()->controller.connect_same_thread (midi_connections, boost::bind (&CC121::encoder_handler, this, _1, _2));
+	_input_port->parser()->controller.connect_same_thread (midi_connections, std::bind (&CC121::encoder_handler, this, _1, _2));
 
 	/* This connection means that whenever data is ready from the input
 	 * port, the relevant thread will invoke our ::midi_input_handler()
@@ -631,13 +631,13 @@ CC121::map_recenable_state ()
 	bool onoff;
 
 	switch (session->record_status()) {
-	case Session::Disabled:
+	case Disabled:
 		onoff = false;
 		break;
-	case Session::Enabled:
+	case Enabled:
 		onoff = blink_state;
 		break;
-	case Session::Recording:
+	case Recording:
 		if (session->have_rec_enabled_track ()) {
 			onoff = true;
 		} else {
@@ -679,8 +679,8 @@ CC121::map_transport_state ()
 void
 CC121::connect_session_signals()
 {
-	session->RecordStateChanged.connect(session_connections, MISSING_INVALIDATOR, boost::bind (&CC121::map_recenable_state, this), this);
-	session->TransportStateChange.connect(session_connections, MISSING_INVALIDATOR, boost::bind (&CC121::map_transport_state, this), this);
+	session->RecordStateChanged.connect(session_connections, MISSING_INVALIDATOR, std::bind (&CC121::map_recenable_state, this), this);
+	session->TransportStateChange.connect(session_connections, MISSING_INVALIDATOR, std::bind (&CC121::map_transport_state, this), this);
 }
 
 bool
@@ -942,7 +942,7 @@ CC121::Button::get_action (bool press, CC121::ButtonState bs)
 }
 
 void
-CC121::Button::set_action (boost::function<void()> f, bool when_pressed, CC121::ButtonState bs)
+CC121::Button::set_action (std::function<void()> f, bool when_pressed, CC121::ButtonState bs)
 {
 	ToDo todo;
 	todo.type = InternalFunction;
@@ -1059,26 +1059,26 @@ CC121::set_current_stripable (std::shared_ptr<Stripable> r)
 	_current_stripable = r;
 
 	if (_current_stripable) {
-		_current_stripable->DropReferences.connect (stripable_connections, MISSING_INVALIDATOR, boost::bind (&CC121::drop_current_stripable, this), this);
+		_current_stripable->DropReferences.connect (stripable_connections, MISSING_INVALIDATOR, std::bind (&CC121::drop_current_stripable, this), this);
 
-		_current_stripable->mute_control()->Changed.connect (stripable_connections, MISSING_INVALIDATOR, boost::bind (&CC121::map_mute, this), this);
-		_current_stripable->solo_control()->Changed.connect (stripable_connections, MISSING_INVALIDATOR, boost::bind (&CC121::map_solo, this), this);
+		_current_stripable->mute_control()->Changed.connect (stripable_connections, MISSING_INVALIDATOR, std::bind (&CC121::map_mute, this), this);
+		_current_stripable->solo_control()->Changed.connect (stripable_connections, MISSING_INVALIDATOR, std::bind (&CC121::map_solo, this), this);
 
 		std::shared_ptr<Track> t = std::dynamic_pointer_cast<Track> (_current_stripable);
 		if (t) {
-			t->rec_enable_control()->Changed.connect (stripable_connections, MISSING_INVALIDATOR, boost::bind (&CC121::map_recenable, this), this);
-			t->monitoring_control()->Changed.connect (stripable_connections, MISSING_INVALIDATOR, boost::bind (&CC121::map_monitoring, this), this);
+			t->rec_enable_control()->Changed.connect (stripable_connections, MISSING_INVALIDATOR, std::bind (&CC121::map_recenable, this), this);
+			t->monitoring_control()->Changed.connect (stripable_connections, MISSING_INVALIDATOR, std::bind (&CC121::map_monitoring, this), this);
 		}
 
 		std::shared_ptr<AutomationControl> control = _current_stripable->gain_control ();
 		if (control) {
-			control->Changed.connect (stripable_connections, MISSING_INVALIDATOR, boost::bind (&CC121::map_gain, this), this);
-			control->alist()->automation_state_changed.connect (stripable_connections, MISSING_INVALIDATOR, boost::bind (&CC121::map_auto, this), this);
+			control->Changed.connect (stripable_connections, MISSING_INVALIDATOR, std::bind (&CC121::map_gain, this), this);
+			control->alist()->automation_state_changed.connect (stripable_connections, MISSING_INVALIDATOR, std::bind (&CC121::map_auto, this), this);
 		}
 
 		std::shared_ptr<MonitorProcessor> mp = _current_stripable->monitor_control();
 		if (mp) {
-			mp->cut_control()->Changed.connect (stripable_connections, MISSING_INVALIDATOR, boost::bind (&CC121::map_cut, this), this);
+			mp->cut_control()->Changed.connect (stripable_connections, MISSING_INVALIDATOR, std::bind (&CC121::map_cut, this), this);
 		}
 	}
 
