@@ -42,10 +42,10 @@ class ControllerButton : public Controller
   public:
 	ControllerButton (Console1* console1,
 	                  ControllerID id,
-	                  boost::function<void (uint32_t)> action,
-	                  boost::function<void (uint32_t)> shift_action = 0,
-	                  boost::function<void (uint32_t)> plugin_action = 0,
-                      boost::function<void (uint32_t)> plugin_shift_action = 0 )
+	                  std::function<void (uint32_t)> action,
+	                  std::function<void (uint32_t)> shift_action = 0,
+	                  std::function<void (uint32_t)> plugin_action = 0,
+                      std::function<void (uint32_t)> plugin_shift_action = 0 )
 	  : Controller (console1, id)
 	  , action (action)
 	  , shift_action (shift_action)
@@ -57,8 +57,9 @@ class ControllerButton : public Controller
 
 	ControllerType get_type () { return CONTROLLER_BUTTON; }
 
-	void set_plugin_action (boost::function<void (uint32_t)> action) { plugin_action = action; }
-	void set_plugin_shift_action (boost::function<void (uint32_t)> action) { plugin_shift_action = action; }
+	void set_action (std::function<void (uint32_t)> new_action) { action = new_action; }
+	void set_plugin_action (std::function<void (uint32_t)> new_action) { plugin_action = new_action; }
+	void set_plugin_shift_action (std::function<void (uint32_t)> new_action) { plugin_shift_action = new_action; }
 
 	virtual void set_led_state (bool onoff)
 	{
@@ -81,10 +82,10 @@ class ControllerButton : public Controller
 
 		console1->write (buf, 3);
 	}
-	boost::function<void (uint32_t)> action;
-	boost::function<void (uint32_t)> shift_action;
-	boost::function<void (uint32_t)> plugin_action;
-	boost::function<void (uint32_t)> plugin_shift_action;
+	std::function<void (uint32_t)> action;
+	std::function<void (uint32_t)> shift_action;
+	std::function<void (uint32_t)> plugin_action;
+	std::function<void (uint32_t)> plugin_shift_action;
 };
 
 class MultiStateButton : public Controller
@@ -93,10 +94,10 @@ class MultiStateButton : public Controller
 	MultiStateButton (Console1* console1,
 	                  ControllerID id,
 	                  std::vector<uint32_t> state_values,
-	                  boost::function<void (uint32_t)> action,
-	                  boost::function<void (uint32_t)> shift_action = 0,
-	                  boost::function<void (uint32_t)> plugin_action = 0,
-	                  boost::function<void (uint32_t)> plugin_shift_action = 0
+	                  std::function<void (uint32_t)> action,
+	                  std::function<void (uint32_t)> shift_action = 0,
+	                  std::function<void (uint32_t)> plugin_action = 0,
+	                  std::function<void (uint32_t)> plugin_shift_action = 0
                       )
 	  : Controller (console1, id)
 	  , action (action)
@@ -122,15 +123,16 @@ class MultiStateButton : public Controller
 		console1->write (buf, 3);
 	}
 
-	void set_plugin_action (boost::function<void (uint32_t)> action) { plugin_action = action; }
-	void set_plugin_shift_action (boost::function<void (uint32_t)> action) { plugin_shift_action = action; }
+	void set_action (std::function<void (uint32_t)> new_action) { action = new_action; }
+	void set_plugin_action (std::function<void (uint32_t)> new_action) { plugin_action = new_action; }
+	void set_plugin_shift_action (std::function<void (uint32_t)> new_action) { plugin_shift_action = new_action; }
 
 	uint32_t state_count () { return state_values.size (); }
 
-	boost::function<void (uint32_t)> action;
-	boost::function<void (uint32_t)> shift_action;
-	boost::function<void (uint32_t)> plugin_action;
-	boost::function<void (uint32_t)> plugin_shift_action;
+	std::function<void (uint32_t)> action;
+	std::function<void (uint32_t)> shift_action;
+	std::function<void (uint32_t)> plugin_action;
+	std::function<void (uint32_t)> plugin_shift_action;
 
   private:
 	std::vector<uint32_t> state_values;
@@ -141,8 +143,8 @@ class Meter : public Controller
   public:
 	Meter (Console1* console1,
 	       ControllerID id,
-	       boost::function<void ()> action,
-	       boost::function<void ()> shift_action = 0)
+	       std::function<void ()> action,
+	       std::function<void ()> shift_action = 0)
 	  : Controller (console1, id)
 	  , action (action)
 	  , shift_action (shift_action)
@@ -161,8 +163,8 @@ class Meter : public Controller
 
 		console1->write (buf, 3);
 	}
-	boost::function<void ()> action;
-	boost::function<void ()> shift_action;
+	std::function<void ()> action;
+	std::function<void ()> shift_action;
 };
 
 class Encoder : public Controller
@@ -170,10 +172,10 @@ class Encoder : public Controller
   public:
 	Encoder (Console1* console1,
 	         ControllerID id,
-	         boost::function<void (uint32_t)> action,
-	         boost::function<void (uint32_t)> shift_action = 0,
-	         boost::function<void (uint32_t)> plugin_action = 0,
-             boost::function<void (uint32_t)> plugin_shift_action = 0)
+	         std::function<void (uint32_t)> action,
+	         std::function<void (uint32_t)> shift_action = 0,
+	         std::function<void (uint32_t)> plugin_action = 0,
+             std::function<void (uint32_t)> plugin_shift_action = 0)
 	  : Controller (console1, id)
 	  , action (action)
 	  , shift_action (shift_action)
@@ -185,8 +187,9 @@ class Encoder : public Controller
 
 	ControllerType get_type () { return ENCODER; }
 
-	void set_plugin_action (boost::function<void (uint32_t)> action) { plugin_action = action; }
-	void set_plugin_shift_action (boost::function<void (uint32_t)> action) { plugin_shift_action = action; }
+	void set_action (std::function<void (uint32_t)> new_action) { action = new_action; }
+	void set_plugin_action (std::function<void (uint32_t)> new_action) { plugin_action = new_action; }
+	void set_plugin_shift_action (std::function<void (uint32_t)> new_action) { plugin_shift_action = new_action; }
 
 	virtual void set_value (uint32_t value)
 	{
@@ -197,12 +200,12 @@ class Encoder : public Controller
 
 		console1->write (buf, 3);
 	}
-	boost::function<void (uint32_t)> action;
-	boost::function<void (uint32_t val)> shift_action;
-	boost::function<void (uint32_t val)> plugin_action;
-	boost::function<void (uint32_t val)> plugin_shift_action;
+	std::function<void (uint32_t)> action;
+	std::function<void (uint32_t val)> shift_action;
+	std::function<void (uint32_t val)> plugin_action;
+	std::function<void (uint32_t val)> plugin_shift_action;
 
-	PBD::Signal1<void, uint32_t>* plugin_signal;
+	PBD::Signal<void(uint32_t)>* plugin_signal;
 };
 
 }
