@@ -22,14 +22,14 @@
 #include <vector>
 #include <string>   
 
-#include <gtkmm/box.h>
-#include <gtkmm/combobox.h>
-#include <gtkmm/checkbutton.h>
-#include <gtkmm/image.h>
-#include <gtkmm/table.h>
-#include <gtkmm/treestore.h>
-#include <gtkmm/spinbutton.h>
-#include <gtkmm/notebook.h>
+#include <ytkmm/box.h>
+#include <ytkmm/combobox.h>
+#include <ytkmm/checkbutton.h>
+#include <ytkmm/image.h>
+#include <ytkmm/table.h>
+#include <ytkmm/treestore.h>
+#include <ytkmm/spinbutton.h>
+#include <ytkmm/notebook.h>
 
 namespace Gtk {
 	class CellRendererCombo;
@@ -57,6 +57,7 @@ private:
 	Gtk::ComboBox output_combo;
 	Gtk::Image image;
 	Gtk::CheckButton swap_solo_mute_cb;
+	Gtk::CheckButton band_q_as_send_cb;
 	Gtk::CheckButton create_plugin_stubs_btn;
 
 	void update_port_combos ();
@@ -80,8 +81,8 @@ private:
 	void active_port_changed (Gtk::ComboBox*,bool for_input);
 
 	void set_swap_solo_mute ();
-	void set_create_mapping_stubs ();
-
+	void set_band_q_as_send();
+	void set_create_mapping_stubs();
 };
 
 }
