@@ -62,7 +62,7 @@ using namespace ArdourSurface::FP_NAMESPACE::FP8Types;
 
 #include "pbd/i18n.h"
 
-#include "pbd/abstract_ui.cc" // instantiate template
+#include "pbd/abstract_ui.inc.cc" // instantiate template
 
 #ifndef NDEBUG
 //#define VERBOSE_DEBUG
@@ -108,7 +108,7 @@ FaderPort8::probe (std::string& i, std::string& o)
 	AudioEngine::instance()->get_ports ("", DataType::MIDI, PortFlags (IsInput|IsTerminal), midi_outputs);
 
 	if (midi_outputs.size () == 0)
-		DEBUG_TRACE (DEBUG::FaderPort8, "prope got no output midi ports at all - perhaps an audio backend problem?\n");
+		DEBUG_TRACE (DEBUG::FaderPort8, "probe got no output midi ports at all - perhaps an audio backend problem?\n");
 	// midi_inputs will never be empty - there is always at least x-virtual-keyboard
 
 	const string needle =
@@ -130,13 +130,13 @@ FaderPort8::probe (std::string& i, std::string& o)
 	auto po = std::find_if (midi_outputs.begin (), midi_outputs.end (), has_fp8);
 
 	if (pi == midi_inputs.end () || po == midi_outputs.end ()) {
-		DEBUG_TRACE (DEBUG::FaderPort8, string_compose ("prope did not find the '%1' midi ports\n", needle));
+		DEBUG_TRACE (DEBUG::FaderPort8, string_compose ("probe did not find the '%1' midi ports\n", needle));
 		return false;
 	}
 
 	i = *pi;
 	o = *po;
-	DEBUG_TRACE (DEBUG::FaderPort8, string_compose ("prope found midi ports '%1' and '%2'\n", i, o));
+	DEBUG_TRACE (DEBUG::FaderPort8, string_compose ("probe found midi ports '%1' and '%2'\n", i, o));
 	return true;
 }
 
@@ -212,15 +212,15 @@ FaderPort8::FaderPort8 (Session& s)
 		session->engine().make_port_name_non_relative (outp->name())
 		);
 
-	ARDOUR::AudioEngine::instance()->PortConnectedOrDisconnected.connect (port_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::connection_handler, this, _2, _4), this);
-	ARDOUR::AudioEngine::instance()->Stopped.connect (port_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::engine_reset, this), this);
-	ARDOUR::Port::PortDrop.connect (port_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::engine_reset, this), this);
+	ARDOUR::AudioEngine::instance()->PortConnectedOrDisconnected.connect (port_connections, MISSING_INVALIDATOR, std::bind (&FaderPort8::connection_handler, this, _2, _4), this);
+	ARDOUR::AudioEngine::instance()->Stopped.connect (port_connections, MISSING_INVALIDATOR, std::bind (&FaderPort8::engine_reset, this), this);
+	ARDOUR::Port::PortDrop.connect (port_connections, MISSING_INVALIDATOR, std::bind (&FaderPort8::engine_reset, this), this);
 
 	/* bind button events to call libardour actions */
 	setup_actions ();
 
-	_ctrls.FaderModeChanged.connect_same_thread (modechange_connections, boost::bind (&FaderPort8::notify_fader_mode_changed, this));
-	_ctrls.MixModeChanged.connect_same_thread (modechange_connections, boost::bind (&FaderPort8::assign_strips, this));
+	_ctrls.FaderModeChanged.connect_same_thread (modechange_connections, std::bind (&FaderPort8::notify_fader_mode_changed, this));
+	_ctrls.MixModeChanged.connect_same_thread (modechange_connections, std::bind (&FaderPort8::assign_strips, this));
 
 	std::string  pn_in, pn_out;
 	if (probe (pn_in, pn_out)) {
@@ -569,14 +569,14 @@ FaderPort8::midi_input_handler (Glib::IOCondition ioc, std::weak_ptr<ARDOUR::Asy
 void
 FaderPort8::start_midi_handling ()
 {
-	_input_port->parser()->sysex.connect_same_thread (midi_connections, boost::bind (&FaderPort8::sysex_handler, this, _1, _2, _3));
-	_input_port->parser()->poly_pressure.connect_same_thread (midi_connections, boost::bind (&FaderPort8::polypressure_handler, this, _1, _2));
+	_input_port->parser()->sysex.connect_same_thread (midi_connections, std::bind (&FaderPort8::sysex_handler, this, _1, _2, _3));
+	_input_port->parser()->poly_pressure.connect_same_thread (midi_connections, std::bind (&FaderPort8::polypressure_handler, this, _1, _2));
 	for (uint8_t i = 0; i < 16; ++i) {
-	_input_port->parser()->channel_pitchbend[i].connect_same_thread (midi_connections, boost::bind (&FaderPort8::pitchbend_handler, this, _1, i, _2));
+	_input_port->parser()->channel_pitchbend[i].connect_same_thread (midi_connections, std::bind (&FaderPort8::pitchbend_handler, this, _1, i, _2));
 	}
-	_input_port->parser()->controller.connect_same_thread (midi_connections, boost::bind (&FaderPort8::controller_handler, this, _1, _2));
-	_input_port->parser()->note_on.connect_same_thread (midi_connections, boost::bind (&FaderPort8::note_on_handler, this, _1, _2));
-	_input_port->parser()->note_off.connect_same_thread (midi_connections, boost::bind (&FaderPort8::note_off_handler, this, _1, _2));
+	_input_port->parser()->controller.connect_same_thread (midi_connections, std::bind (&FaderPort8::controller_handler, this, _1, _2));
+	_input_port->parser()->note_on.connect_same_thread (midi_connections, std::bind (&FaderPort8::note_on_handler, this, _1, _2));
+	_input_port->parser()->note_off.connect_same_thread (midi_connections, std::bind (&FaderPort8::note_off_handler, this, _1, _2));
 
 	/* This connection means that whenever data is ready from the input
 	 * port, the relevant thread will invoke our ::midi_input_handler()
@@ -1076,17 +1076,17 @@ FaderPort8::assign_stripables (bool select_only)
 
 		_assigned_strips[*s] = id;
 		(*s)->DropReferences.connect (assigned_stripable_connections, MISSING_INVALIDATOR,
-				boost::bind (&FaderPort8::notify_stripable_added_or_removed, this), this);
+				std::bind (&FaderPort8::notify_stripable_added_or_removed, this), this);
 
 		(*s)->PropertyChanged.connect (assigned_stripable_connections, MISSING_INVALIDATOR,
-				boost::bind (&FaderPort8::notify_stripable_property_changed, this, std::weak_ptr<Stripable> (*s), _1), this);
+				std::bind (&FaderPort8::notify_stripable_property_changed, this, std::weak_ptr<Stripable> (*s), _1), this);
 		(*s)->presentation_info ().PropertyChanged.connect (assigned_stripable_connections, MISSING_INVALIDATOR,
-				boost::bind (&FaderPort8::notify_stripable_property_changed, this, std::weak_ptr<Stripable> (*s), _1), this);
+				std::bind (&FaderPort8::notify_stripable_property_changed, this, std::weak_ptr<Stripable> (*s), _1), this);
 
 		if (std::shared_ptr<Route> r = std::dynamic_pointer_cast<Route>(*s)) {
 			if (r->panner_shell()) {
 				r->panner_shell()->Changed.connect (assigned_stripable_connections, MISSING_INVALIDATOR,
-				boost::bind (&FaderPort8::notify_stripable_property_changed, this, std::weak_ptr<Stripable> (*s), PropertyChange()), this);
+				std::bind (&FaderPort8::notify_stripable_property_changed, this, std::weak_ptr<Stripable> (*s), PropertyChange()), this);
 			}
 		}
 
@@ -1101,7 +1101,7 @@ FaderPort8::assign_stripables (bool select_only)
 			_ctrls.strip(id).set_stripable (*s, _ctrls.fader_mode() == ModePan);
 		}
 
-		 boost::function<void ()> cb (boost::bind (&FaderPort8::select_strip, this, std::weak_ptr<Stripable> (*s)));
+		 std::function<void ()> cb (std::bind (&FaderPort8::select_strip, this, std::weak_ptr<Stripable> (*s)));
 		 _ctrls.strip(id).set_select_cb (cb);
 
 		if (++id == N_STRIPS) {
@@ -1149,7 +1149,7 @@ FaderPort8::lock_link ()
 	if (!ac) {
 		return;
 	}
-	ac->DropReferences.connect (link_locked_connection, MISSING_INVALIDATOR, boost::bind (&FaderPort8::unlock_link, this, true), this);
+	ac->DropReferences.connect (link_locked_connection, MISSING_INVALIDATOR, std::bind (&FaderPort8::unlock_link, this, true), this);
 
 	// stop watching for focus events
 	link_connection.disconnect ();
@@ -1182,7 +1182,7 @@ FaderPort8::start_link ()
 	_ctrls.button (FP8Controls::BtnLock).set_active (true);
 	nofity_focus_control (_link_control); // update BtnLink, BtnLock colors
 
-	PBD::Controllable::GUIFocusChanged.connect (link_connection, MISSING_INVALIDATOR, boost::bind (&FaderPort8::nofity_focus_control, this, _1), this);
+	PBD::Controllable::GUIFocusChanged.connect (link_connection, MISSING_INVALIDATOR, std::bind (&FaderPort8::nofity_focus_control, this, _1), this);
 }
 
 
@@ -1295,7 +1295,7 @@ FaderPort8::assign_plugin_presets (std::shared_ptr<PluginInsert> pi)
 	uint8_t id = 0;
 	for (size_t i = _parameter_off; i < (size_t)n_parameters; ++i) {
 		_ctrls.strip(id).unset_controllables (FP8Strip::CTRL_ALL & ~FP8Strip::CTRL_TEXT01 & ~FP8Strip::CTRL_TEXT3 & ~FP8Strip::CTRL_SELECT);
-		 boost::function<void ()> cb (boost::bind (&FaderPort8::select_plugin_preset, this, i));
+		 std::function<void ()> cb (std::bind (&FaderPort8::select_plugin_preset, this, i));
 		_ctrls.strip(id).set_select_cb (cb);
 		_ctrls.strip(id).select_button ().set_active (true);
 		if (active != presets.at(i)) {
@@ -1322,7 +1322,7 @@ FaderPort8::assign_plugin_presets (std::shared_ptr<PluginInsert> pi)
 	// pin clear-preset to the last slot
 	assert (id == (N_STRIPS - 1));
 	_ctrls.strip(id).unset_controllables (FP8Strip::CTRL_ALL & ~FP8Strip::CTRL_TEXT0 & ~FP8Strip::CTRL_TEXT3 & ~FP8Strip::CTRL_SELECT);
-	 boost::function<void ()> cb (boost::bind (&FaderPort8::select_plugin_preset, this, SIZE_MAX));
+	 std::function<void ()> cb (std::bind (&FaderPort8::select_plugin_preset, this, SIZE_MAX));
 	_ctrls.strip(id).set_select_cb (cb);
 	_ctrls.strip(id).select_button ().set_blinking (false);
 	_ctrls.strip(id).select_button ().set_color (active.uri.empty() ? 0x00ffffff : 0x0000ffff);
@@ -1361,6 +1361,8 @@ FaderPort8::build_well_known_processor_ctrls (std::shared_ptr<Stripable> s, int
 			break;
 		case 2:
 			PUSH_BACK_NON_NULL ("Comp In", s->mapped_control (Comp_Enable));
+			PUSH_BACK_NON_NULL ("RMS/Peak", s->mapped_control (Comp_RMSPeak));
+			PUSH_BACK_NON_NULL ("Fast Attk", s->mapped_control (Comp_FastAttack));
 			PUSH_BACK_NON_NULL ("Threshold", s->mapped_control (Comp_Threshold));
 			PUSH_BACK_NON_NULL ("Makeup", s->mapped_control (Comp_Makeup));
 			PUSH_BACK_NON_NULL ("Mode", s->mapped_control (Comp_Mode));
@@ -1368,10 +1370,12 @@ FaderPort8::build_well_known_processor_ctrls (std::shared_ptr<Stripable> s, int
 			PUSH_BACK_NON_NULL ("Attack", s->mapped_control (Comp_Attack));
 			PUSH_BACK_NON_NULL ("Release", s->mapped_control (Comp_Release));
 			PUSH_BACK_NON_NULL ("Emphasis", s->mapped_control (Comp_KeyFilterFreq));
+			PUSH_BACK_NON_NULL ("Mix", s->mapped_control (Comp_Mix));
 			break;
 		case 3:
 			PUSH_BACK_NON_NULL ("Gate In", s->mapped_control (Gate_Enable));
 			PUSH_BACK_NON_NULL ("Exp", s->mapped_control (Gate_Mode));
+			PUSH_BACK_NON_NULL ("Fast Attk", s->mapped_control (Gate_FastAttack));
 			PUSH_BACK_NON_NULL ("Threshold", s->mapped_control (Gate_Threshold));
 			PUSH_BACK_NON_NULL ("Depth", s->mapped_control (Gate_Depth));
 			PUSH_BACK_NON_NULL ("Attack", s->mapped_control (Gate_Attack));
@@ -1419,7 +1423,7 @@ FaderPort8::select_plugin (int num)
 
 	if (num < 0) {
 		processor_connections.drop_connections ();
-		r->DropReferences.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FP8Controls::set_fader_mode, &_ctrls, ModeTrack), this);
+		r->DropReferences.connect (processor_connections, MISSING_INVALIDATOR, std::bind (&FP8Controls::set_fader_mode, &_ctrls, ModeTrack), this);
 
 		build_well_known_processor_ctrls (r, -num);
 		assign_processor_ctrls ();
@@ -1461,12 +1465,12 @@ FaderPort8::select_plugin (int num)
 		_plugin_insert = std::weak_ptr<ARDOUR::PluginInsert> (pi);
 		std::shared_ptr<ARDOUR::Plugin> plugin = pi->plugin ();
 
-		plugin->PresetAdded.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::preset_changed, this), this);
-		plugin->PresetRemoved.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::preset_changed, this), this);
-		plugin->PresetLoaded.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::preset_changed, this), this);
-		plugin->PresetDirty.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::preset_changed, this), this);
+		plugin->PresetAdded.connect (processor_connections, MISSING_INVALIDATOR, std::bind (&FaderPort8::preset_changed, this), this);
+		plugin->PresetRemoved.connect (processor_connections, MISSING_INVALIDATOR, std::bind (&FaderPort8::preset_changed, this), this);
+		plugin->PresetLoaded.connect (processor_connections, MISSING_INVALIDATOR, std::bind (&FaderPort8::preset_changed, this), this);
+		plugin->PresetDirty.connect (processor_connections, MISSING_INVALIDATOR, std::bind (&FaderPort8::preset_changed, this), this);
 
-		r->MappedControlsChanged.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::stripable_selection_changed, this), this);
+		r->MappedControlsChanged.connect (processor_connections, MISSING_INVALIDATOR, std::bind (&FaderPort8::stripable_selection_changed, this), this);
 
 		if (_auto_pluginui) {
 			pi->ShowUI (); /* EMIT SIGNAL */
@@ -1485,7 +1489,7 @@ FaderPort8::select_plugin (int num)
 
 	// disconnect signals from spill_plugins: processors_changed and ActiveChanged
 	processor_connections.drop_connections ();
-	r->DropReferences.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FP8Controls::set_fader_mode, &_ctrls, ModeTrack), this);
+	r->DropReferences.connect (processor_connections, MISSING_INVALIDATOR, std::bind (&FP8Controls::set_fader_mode, &_ctrls, ModeTrack), this);
 
 	std::shared_ptr<PluginInsert> pi = std::dynamic_pointer_cast<PluginInsert> (proc);
 	assert (pi); // nth_plugin() always returns a PI.
@@ -1497,13 +1501,13 @@ FaderPort8::select_plugin (int num)
 #endif
 	{
 		_plugin_insert = std::weak_ptr<ARDOUR::PluginInsert> (pi);
-		pi->ActiveChanged.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::notify_plugin_active_changed, this), this);
+		pi->ActiveChanged.connect (processor_connections, MISSING_INVALIDATOR, std::bind (&FaderPort8::notify_plugin_active_changed, this), this);
 		std::shared_ptr<ARDOUR::Plugin> plugin = pi->plugin ();
 
-		plugin->PresetAdded.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::preset_changed, this), this);
-		plugin->PresetRemoved.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::preset_changed, this), this);
-		plugin->PresetLoaded.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::preset_changed, this), this);
-		plugin->PresetDirty.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::preset_changed, this), this);
+		plugin->PresetAdded.connect (processor_connections, MISSING_INVALIDATOR, std::bind (&FaderPort8::preset_changed, this), this);
+		plugin->PresetRemoved.connect (processor_connections, MISSING_INVALIDATOR, std::bind (&FaderPort8::preset_changed, this), this);
+		plugin->PresetLoaded.connect (processor_connections, MISSING_INVALIDATOR, std::bind (&FaderPort8::preset_changed, this), this);
+		plugin->PresetDirty.connect (processor_connections, MISSING_INVALIDATOR, std::bind (&FaderPort8::preset_changed, this), this);
 
 		if (_auto_pluginui) {
 			pi->ShowUI (); /* EMIT SIGNAL */
@@ -1512,7 +1516,7 @@ FaderPort8::select_plugin (int num)
 
 	// switching to "Mode Track" -> calls FaderPort8::notify_fader_mode_changed()
 	// which drops the references, disconnects the signal and re-spills tracks
-	proc->DropReferences.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FP8Controls::set_fader_mode, &_ctrls, ModeTrack), this);
+	proc->DropReferences.connect (processor_connections, MISSING_INVALIDATOR, std::bind (&FP8Controls::set_fader_mode, &_ctrls, ModeTrack), this);
 
 	// build params
 	_proc_params.clear();
@@ -1570,10 +1574,10 @@ FaderPort8::spill_plugins ()
 
 	// switching to "Mode Track" -> calls FaderPort8::notify_fader_mode_changed()
 	// which drops the references, disconnects the signal and re-spills tracks
-	r->DropReferences.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FP8Controls::set_fader_mode, &_ctrls, ModeTrack), this);
+	r->DropReferences.connect (processor_connections, MISSING_INVALIDATOR, std::bind (&FP8Controls::set_fader_mode, &_ctrls, ModeTrack), this);
 
 	// update when processor change
-	r->processors_changed.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::spill_plugins, this), this);
+	r->processors_changed.connect (processor_connections, MISSING_INVALIDATOR, std::bind (&FaderPort8::spill_plugins, this), this);
 
 	// count available
 	std::shared_ptr<Processor> proc;
@@ -1644,7 +1648,7 @@ FaderPort8::spill_plugins ()
 			break;
 		}
 		std::shared_ptr<PluginInsert> pi = std::dynamic_pointer_cast<PluginInsert> (proc);
-		boost::function<void ()> cb (boost::bind (&FaderPort8::select_plugin, this, procs[i]));
+		std::function<void ()> cb (std::bind (&FaderPort8::select_plugin, this, procs[i]));
 
 		_ctrls.strip(id).unset_controllables (FP8Strip::CTRL_ALL & ~FP8Strip::CTRL_TEXT & ~FP8Strip::CTRL_SELECT);
 		_ctrls.strip(id).set_select_cb (cb);
@@ -1656,7 +1660,7 @@ FaderPort8::spill_plugins ()
 		_ctrls.strip(id).set_text_line (2, PluginManager::plugin_type_name (pi->type()));
 		_ctrls.strip(id).set_text_line (3, "");
 
-		pi->ActiveChanged.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::spill_plugins, this), this);
+		pi->ActiveChanged.connect (processor_connections, MISSING_INVALIDATOR, std::bind (&FaderPort8::spill_plugins, this), this);
 
 		if (++id == spillwidth) {
 			break;
@@ -1669,7 +1673,7 @@ FaderPort8::spill_plugins ()
 
 	if (have_well_known_gate) {
 			assert (id < N_STRIPS);
-		 boost::function<void ()> cb (boost::bind (&FaderPort8::select_plugin, this, -3));
+		 std::function<void ()> cb (std::bind (&FaderPort8::select_plugin, this, -3));
 		 _ctrls.strip(id).unset_controllables (FP8Strip::CTRL_ALL & ~FP8Strip::CTRL_TEXT & ~FP8Strip::CTRL_SELECT);
 		 _ctrls.strip(id).set_select_cb (cb);
 		 _ctrls.strip(id).select_button ().set_color (0xffff00ff);
@@ -1683,7 +1687,7 @@ FaderPort8::spill_plugins ()
 	}
 	if (have_well_known_eq) {
 			assert (id < N_STRIPS);
-		 boost::function<void ()> cb (boost::bind (&FaderPort8::select_plugin, this, -1));
+		 std::function<void ()> cb (std::bind (&FaderPort8::select_plugin, this, -1));
 		 _ctrls.strip(id).unset_controllables (FP8Strip::CTRL_ALL & ~FP8Strip::CTRL_TEXT & ~FP8Strip::CTRL_SELECT);
 		 _ctrls.strip(id).set_select_cb (cb);
 		 _ctrls.strip(id).select_button ().set_color (0xffff00ff);
@@ -1697,7 +1701,7 @@ FaderPort8::spill_plugins ()
 	}
 	if (have_well_known_comp) {
 			assert (id < N_STRIPS);
-		 boost::function<void ()> cb (boost::bind (&FaderPort8::select_plugin, this, -2));
+		 std::function<void ()> cb (std::bind (&FaderPort8::select_plugin, this, -2));
 		 _ctrls.strip(id).unset_controllables (FP8Strip::CTRL_ALL & ~FP8Strip::CTRL_TEXT & ~FP8Strip::CTRL_SELECT);
 		 _ctrls.strip(id).set_select_cb (cb);
 		 _ctrls.strip(id).select_button ().set_color (0xffff00ff);
@@ -1735,7 +1739,7 @@ FaderPort8::assign_sends ()
 	}
 
 	drop_ctrl_connections ();
-	s->DropReferences.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FP8Controls::set_fader_mode, &_ctrls, ModeTrack), this);
+	s->DropReferences.connect (processor_connections, MISSING_INVALIDATOR, std::bind (&FP8Controls::set_fader_mode, &_ctrls, ModeTrack), this);
 
 	set_periodic_display_mode (FP8Strip::SendDisplay);
 
@@ -2060,16 +2064,16 @@ FaderPort8::subscribe_to_strip_signals ()
 		std::shared_ptr<AutomationControl> ac;
 		ac = s->gain_control();
 		if (ac && ac->alist()) {
-			ac->alist()->automation_state_changed.connect (route_state_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::notify_route_state_changed, this), this);
+			ac->alist()->automation_state_changed.connect (route_state_connections, MISSING_INVALIDATOR, std::bind (&FaderPort8::notify_route_state_changed, this), this);
 		}
 		ac = s->pan_azimuth_control();
 		if (ac && ac->alist()) {
-			ac->alist()->automation_state_changed.connect (route_state_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::notify_route_state_changed, this), this);
+			ac->alist()->automation_state_changed.connect (route_state_connections, MISSING_INVALIDATOR, std::bind (&FaderPort8::notify_route_state_changed, this), this);
 		}
 #ifdef FADERPORT2
 		ac = s->rec_enable_control();
 		if (ac) {
-			ac->Changed.connect (route_state_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::notify_route_state_changed, this), this);
+			ac->Changed.connect (route_state_connections, MISSING_INVALIDATOR, std::bind (&FaderPort8::notify_route_state_changed, this), this);
 		}
 #endif
 	}
