@@ -25,6 +25,7 @@
 
 #include <sstream>
 #include <algorithm>
+#include <regex>
 
 #ifdef COMPILER_MSVC
 #include <io.h> // Microsoft's nearest equivalent to <unistd.h>
@@ -66,7 +67,7 @@
 #include "midifunction.h"
 #include "midiaction.h"
 
-#include "pbd/abstract_ui.cc" // instantiate template
+#include "pbd/abstract_ui.inc.cc" // instantiate template
 
 #include "pbd/i18n.h"
 
@@ -125,23 +126,23 @@ GenericMidiControlProtocol::GenericMidiControlProtocol (Session& s)
 	 * thread
 	 */
 
-	Controllable::StartLearning.connect_same_thread (*this, boost::bind (&GenericMidiControlProtocol::start_learning, this, _1));
-	Controllable::StopLearning.connect_same_thread (*this, boost::bind (&GenericMidiControlProtocol::stop_learning, this, _1));
+	Controllable::StartLearning.connect_same_thread (*this, std::bind (&GenericMidiControlProtocol::start_learning, this, _1));
+	Controllable::StopLearning.connect_same_thread (*this, std::bind (&GenericMidiControlProtocol::stop_learning, this, _1));
 
 	/* this signal is emitted by the process() callback, and if
 	 * send_feedback() is going to do anything, it should do it in the
 	 * context of the process() callback itself.
 	 */
 
-	Session::SendFeedback.connect_same_thread (*this, boost::bind (&GenericMidiControlProtocol::send_feedback, this));
+	Session::SendFeedback.connect_same_thread (*this, std::bind (&GenericMidiControlProtocol::send_feedback, this));
 
 	/* this one is cross-thread */
 
-	PresentationInfo::Change.connect (*this, MISSING_INVALIDATOR, boost::bind (&GenericMidiControlProtocol::reset_controllables, this), this);
+	PresentationInfo::Change.connect (*this, MISSING_INVALIDATOR, std::bind (&GenericMidiControlProtocol::reset_controllables, this), this);
 
 	/* Catch port connections and disconnections (cross-thread) */
 	ARDOUR::AudioEngine::instance()->PortConnectedOrDisconnected.connect (_port_connection, MISSING_INVALIDATOR,
-	                                                                      boost::bind (&GenericMidiControlProtocol::connection_handler, this, _1, _2, _3, _4, _5),
+	                                                                      std::bind (&GenericMidiControlProtocol::connection_handler, this, _1, _2, _3, _4, _5),
 	                                                                      this);
 
 	reload_maps ();
@@ -463,7 +464,7 @@ GenericMidiControlProtocol::start_learning (std::weak_ptr <Controllable> wc)
 		Glib::Threads::Mutex::Lock lm (pending_lock);
 
 		MIDIPendingControllable* element = new MIDIPendingControllable (mc, own_mc);
-		c->LearningFinished.connect_same_thread (element->connection, boost::bind (&GenericMidiControlProtocol::learning_stopped, this, mc));
+		c->LearningFinished.connect_same_thread (element->connection, std::bind (&GenericMidiControlProtocol::learning_stopped, this, mc));
 
 		pending_controllables.push_back (element);
 	}
@@ -1029,24 +1030,13 @@ GenericMidiControlProtocol::lookup_controllable (const string & str, MIDIControl
 	int id = 1;
 	string name;
 
-	static regex_t compiled_pattern;
-	static bool compiled = false;
-
-	if (!compiled) {
-		const char * const pattern = "^[BS]?[0-9]+";
-		/* this pattern compilation is not going to fail */
-		regcomp (&compiled_pattern, pattern, REG_EXTENDED|REG_NOSUB);
-		/* leak compiled pattern */
-		compiled = true;
-	}
-
 	/* Step 3: identify what "rest" looks like - name, or simple nueric, or
 	 * banked/selection specifier
 	 */
 
-	bool matched = (regexec (&compiled_pattern, rest[0].c_str(), 0, 0, 0) == 0);
+	static const std::regex pattern ("^[BS]?[0-9]+", std::regex::extended);
 
-	if (matched) {
+	if (std::regex_search (rest[0], pattern)) {
 		bool banked = false;
 
 		if (rest[0][0] == 'B') {
