@@ -130,7 +130,7 @@ public:
 	void toggle_rid_selection (int rid);
 	void remove_rid_from_selection (int rid);
 
-	PBD::Signal0<void> ConnectionChange;
+	PBD::Signal<void()> ConnectionChange;
 
 	CONTROL_PROTOCOL_THREADS_NEED_TEMPO_MAP_DECL();
 
