@@ -51,7 +51,6 @@
 
 class OSCControllable;
 class OSCRouteObserver;
-class OSCGlobalObserver;
 class OSCSelectObserver;
 class OSCCueObserver;
 
@@ -68,6 +67,8 @@ class ZeroConf;
 
 namespace ArdourSurface {
 
+class OSCGlobalObserver;
+
 struct OSCUIRequest : public BaseUI::BaseRequestObject {
   public:
 	OSCUIRequest () {}
@@ -80,8 +81,6 @@ class OSC : public ARDOUR::ControlProtocol, public AbstractUI<OSCUIRequest>
 	OSC (ARDOUR::Session&, uint32_t port);
 	virtual ~OSC();
 
-	static OSC* instance() { return _instance; }
-
 	XMLNode& get_state () const;
 	int set_state (const XMLNode&, int version);
 
@@ -767,8 +766,6 @@ class OSC : public ARDOUR::ControlProtocol, public AbstractUI<OSCUIRequest>
 
 	void debugmsg (const char *prefix, const char *path, const char* types, lo_arg **argv, int argc);
 
-	static OSC* _instance;
-
 	mutable void *gui;
 	void build_gui ();
 };
