@@ -16,8 +16,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef __libtemporal_timeline_h__
-#define __libtemporal_timeline_h__
+#pragma once
 
 #include <ostream>
 #include <exception>
@@ -40,8 +39,16 @@ class timecnt_t;
 
 void dump_stats (std::ostream&);
 
-/* 62 bit positional time value. Theoretically signed, but the intent is for to
- * always be positive. If the flag bit is set (i.e. ::flagged() is true), the
+/* A timepos_t designates an absolute position on the global timeline. It is
+ * measured since time zero, and it can thus only be positive. It is in one of
+ * two TimeDomains: AudioTime (wall time measured using superclock,
+ * proportional to sample count) or BeatTime (counting musical ticks, which are
+ * subdivided quarternotes or Beats). The ratio between these two is the tempo,
+ * which might change over time. Conversion between these time domains is thus
+ * non-trivial and will use the global TempoMap.
+ *
+ * Implemented using a 62 bit positional time value, a flag bit, and a sign bit.
+ * It is is intended to always be positive. If the flag bit is set (i.e. ::flagged() is true), the
  * numerical value counts musical ticks; otherwise it counts superclocks.
  */
 
@@ -57,7 +64,7 @@ class LIBTEMPORAL_API timepos_t : public int62_t  {
 
 	explicit timepos_t (timecnt_t const &); /* will throw() if val is negative */
 
-	/* superclock_t and samplepos_t are the same underlying primitive type,
+	/* ticks are int64_t, and superclock_t and samplepos_t are both typedefs of int64_t,
 	 * which means we cannot use polymorphism to differentiate them. But it
 	 * turns out that we more or less never construct timepos_t from an
 	 * integer representing superclocks. So, there's a normal constructor
@@ -110,7 +117,7 @@ class LIBTEMPORAL_API timepos_t : public int62_t  {
 
 	/* don't provide operator+(samplepos_t) or operator+(superclock_t)
 	 * because the compiler can't disambiguate them and neither can we.
-	 * to add such types, create a timepo_t and then add that.
+	 * to add such types, create a timepos_t and then add that.
 	 */
 
 	/* operator-() poses severe and thorny problems for a class that represents position on a timeline.
@@ -239,11 +246,6 @@ class LIBTEMPORAL_API timepos_t : public int62_t  {
 	explicit timepos_t (bool b, int64_t v) : int62_t (b, v) {}
 	explicit timepos_t (int62_t const & v) : int62_t (v) {}
 
-	/* these can only be called after verifying that the time domain does
-	 * not match the relevant one i.e. call _beats() to get a Beats value
-	 * when this is using the audio time domain
-	 */
-
 	/* these three methods are to be called ONLY when we have already that
 	 * the time domain of this timepos_t does not match the desired return
 	 * type, and so we will need to go to the tempo map to convert
@@ -277,12 +279,11 @@ class LIBTEMPORAL_API timepos_t : public int62_t  {
 };
 
 
-/**
- * a timecnt_t measures a duration in a specified time domain and starting at a
- * specific position.
- *
- * It can be freely converted between time domains, as well as used as the
- * subject of most arithmetic operations.
+/* A timecnt_t (time count) designates a time distance (duration) with origin
+ * at a given absolute position on the global timeline (a timepos_t). It thus
+ * also designates an absolute end position. Both distance and position can
+ * independently be in one of two TimeDomains: AudioTime or BeatTime.
+ * Conversion between these time domains will use the global TempoMap.
  *
  * An important distinction between timepos_t and timecnt_t can be thought of
  * this way: a timepos_t ALWAYS refers to a position relative to the origin of
@@ -306,7 +307,7 @@ class LIBTEMPORAL_API timecnt_t {
 	timecnt_t (TimeDomain td) : _distance (td != AudioTime, 0), _position (td) {}
 	timecnt_t (timecnt_t const &other) : _distance (other.distance()), _position (other.position()) {}
 
-	/* construct from sample count (position doesn't matter due to linear nature * of audio time */
+	/* construct from sample count (position doesn't matter due to linear nature of audio time) */
 	explicit timecnt_t (samplepos_t s, timepos_t const & pos);
 	explicit timecnt_t (samplepos_t s);
 
@@ -338,7 +339,6 @@ class LIBTEMPORAL_API timecnt_t {
 	int64_t magnitude() const { return _distance.val(); }
 	int62_t const & distance() const { return _distance; }
 	timepos_t const & position() const { return _position; }
-	timepos_t const & origin() const { return _position; } /* alias */
 	timepos_t end (TimeDomain) const;
 	timepos_t end () const { return end (time_domain()); }
 
@@ -498,4 +498,3 @@ inline static bool operator>= (Temporal::Beats const & b, Temporal::timecnt_t co
 
 #undef TEMPORAL_DOMAIN_WARNING
 
-#endif /* __libtemporal_timeline_h__ */
