@@ -230,52 +230,6 @@ gdk_window_impl_quartz_init (GdkWindowImplQuartz *impl)
   impl->type_hint = GDK_WINDOW_TYPE_HINT_NORMAL;
 }
 
-static void
-_gdk_window_quartz_clear_region (GdkWindow *window, const GdkRegion* region, bool ignored)
-{
-  if (gdk_drawable_get_colormap (window) != gdk_screen_get_rgba_colormap (_gdk_screen)) {
-
-	  /* Window is opaque. We no longer use backing store on Quartz, so the code that fill the backing store with the background
-	   * color is no longer in use. We do that here, if there is a background color.
-	   */
-
-	  GdkWindowObject *private = GDK_WINDOW_OBJECT(window);
-	  GdkWindowImplQuartz *impl = GDK_WINDOW_IMPL_QUARTZ (private->impl);
-
-	  GdkColor bg_color = private->bg_color;
-	  CGContextRef cg_context = [[NSGraphicsContext currentContext] graphicsPort];
-	  CGContextSaveGState (cg_context);
-
-	  if (g_getenv ("GDK_HARLEQUIN_DEBUGGING")) {
-		  CGContextSetRGBFillColor (cg_context,
-		                            (random() % 65535) / 65335.0,
-		                            (random() % 65535) / 65335.0,
-		                            (random() % 65535) / 65335.0,
-		                            1.0);
-	  } else {
-		  CGContextSetRGBFillColor (cg_context,
-		                            bg_color.red / 65335.0,
-		                            bg_color.green / 65335.0,
-		                            bg_color.blue / 65335.0,
-		                            1.0);
-	  }
-
-	  GdkRectangle *rects;
-	  gint n_rects, i;
-
-	  gdk_region_get_rectangles (region, &rects, &n_rects);
-
-	  for (i = 0; i < n_rects; i++)
-	  {
-		  CGRect cg_rect = CGRectMake (rects[i].x + 0.5, rects[i].y + 0.5, rects[i].width, rects[i].height);
-
-		  CGContextFillRect (cg_context, cg_rect);
-	  }
-
-	  CGContextRestoreGState (cg_context);
-  }
-}
-
 void
 _gdk_quartz_window_set_needs_display_in_rect (GdkWindow    *window,
                                               GdkRectangle *rect)
