@@ -20,12 +20,10 @@
 
 #include <cmath>
 
-#include <boost/scoped_array.hpp>
-
 #include <cairomm/cairomm.h>
 
 #include <glibmm/threads.h>
-#include <gdkmm/general.h>
+#include <ydkmm/general.h>
 
 #include "pbd/base_ui.h"
 #include "pbd/compose.h"
@@ -68,8 +66,8 @@ WaveView::Shape WaveView::_global_shape = WaveView::Normal;
 bool WaveView::_global_show_waveform_clipping = true;
 double WaveView::_global_clip_level = 0.98853;
 
-PBD::Signal0<void> WaveView::VisualPropertiesChanged;
-PBD::Signal0<void> WaveView::ClipLevelChanged;
+PBD::Signal<void()> WaveView::VisualPropertiesChanged;
+PBD::Signal<void()> WaveView::ClipLevelChanged;
 
 /* NO_THREAD_WAVEVIEWS is defined by the top level wscript
  * if --no-threaded-waveviws is provided at the configure step.
@@ -116,9 +114,9 @@ WaveView::init ()
 	_props->outline_color = _outline_color;
 
 	VisualPropertiesChanged.connect_same_thread (
-	    invalidation_connection, boost::bind (&WaveView::handle_visual_property_change, this));
+	    invalidation_connection, std::bind (&WaveView::handle_visual_property_change, this));
 	ClipLevelChanged.connect_same_thread (invalidation_connection,
-	                                      boost::bind (&WaveView::handle_clip_level_change, this));
+	                                      std::bind (&WaveView::handle_clip_level_change, this));
 }
 
 WaveView::~WaveView ()
@@ -304,11 +302,24 @@ WaveView::get_item_and_draw_rect_in_window_coords (Rect const& canvas_rect, Rect
 	 * So let's start by determining the area covered by the region, in
 	 * window coordinates. It begins at zero (in item coordinates for this
 	 * waveview, and extends to region_length() / _samples_per_pixel.
+	 *
+	 * Use same rounding as UI's TimeAxisViewItem::set_samples_per_pixel,
+	 * TimeAxisViewItem::reset_width_dependent_items
 	 */
+	double spp         = _props->samples_per_pixel;
+	double end_pixel   = round ((_region->position () + _region->length ()).samples () / spp);
+	double start_pixel = round (_region->position ().samples () / spp);
+	double const width = end_pixel - start_pixel;
 
-	double const width = region_length() / _props->samples_per_pixel;
 	item_rect = item_to_window (Rect (0.0, 0.0, width, _props->height), false);
 
+	/* do round actual start/end clip-mask, to match TimeAxisViewItem frame */
+	double rx0 = round (item_rect.x0);
+	double rx1 = round (item_rect.x1);
+
+	/* don't round item, this way sample-positions from pixels remain consistent
+	 * (waveform does not jitter when region is split)
+	 */
 	item_rect.x0 = floor (item_rect.x0);
 	item_rect.x1 = ceil  (item_rect.x1);
 	item_rect.y0 = round (item_rect.y0);
@@ -328,8 +339,8 @@ WaveView::get_item_and_draw_rect_in_window_coords (Rect const& canvas_rect, Rect
 	 * We round down in case we were asked to draw "between" pixels at the start
 	 * and/or end.
 	 */
-	draw_rect.x0 = floor (draw_rect.x0);
-	draw_rect.x1 = ceil (draw_rect.x1);
+	draw_rect.x0 = max (floor (draw_rect.x0), rx0);
+	draw_rect.x1 = min (ceil (draw_rect.x1), rx1);
 
 	return true;
 }
@@ -475,7 +486,7 @@ WaveView::draw_image (Cairo::RefPtr<Cairo::ImageSurface>& image, PeakData* peaks
 	clip_context->set_antialias (Cairo::ANTIALIAS_NONE);
 	zero_context->set_antialias (Cairo::ANTIALIAS_NONE);
 
-	boost::scoped_array<LineTips> tips (new LineTips[n_peaks]);
+	std::unique_ptr<LineTips[]> tips (new LineTips[n_peaks]);
 
 	/* Clip level nominally set to -0.9dBFS to account for inter-sample
 	   interpolation possibly clipping (value may be too low).
@@ -898,7 +909,7 @@ WaveView::process_draw_request (std::shared_ptr<WaveViewDrawRequest> req)
 
 	assert (n_peaks > 0 && n_peaks < 32767);
 
-	boost::scoped_array<ARDOUR::PeakData> peaks (new PeakData[n_peaks]);
+	std::unique_ptr<ARDOUR::PeakData[]> peaks (new PeakData[n_peaks]);
 
 	/* Note that Region::read_peaks() takes a start position based on an
 	   offset into the Region's **SOURCE**, rather than an offset into
@@ -1155,7 +1166,10 @@ void
 WaveView::compute_bounding_box () const
 {
 	if (_region) {
-		_bounding_box = Rect (0.0, 0.0, region_length() / _props->samples_per_pixel, _props->height);
+		double spp         = _props->samples_per_pixel;
+		double end_pixel   = round ((_region->position () + _region->length ()).samples () / spp);
+		double start_start = round (_region->position ().samples () / spp);
+		_bounding_box = Rect (0.0, 0.0, end_pixel - start_start, _props->height);
 	} else {
 		_bounding_box = Rect ();
 	}
