@@ -25,12 +25,11 @@
 #include <stdlib.h>
 
 #include <glibmm.h>
-#include <gdkmm.h>
 
 #include "gtkmm2ext/utils.h"
 #include "widgets/fastmeter.h"
 
-#include "widgets/ui_config.h"
+#include "gtkmm2ext/ui_config.h"
 
 
 #define UINT_TO_RGB(u,r,g,b) { (*(r)) = ((u)>>16)&0xff; (*(g)) = ((u)>>8)&0xff; (*(b)) = (u)&0xff; }
